package com.cusc.nirvana.user.rnr.common.config;

import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.user.rnr.mg.constants.RnrMgMqConstant;
import com.cusc.nirvana.user.rnr.mg.service.TimingSendService;
import com.cusc.nirvana.user.rnr.notice.dto.RnrNoticeContentDTO;
import com.cusc.nirvana.user.rnr.notice.kafka.KafkaProduct;
import com.cusc.nirvana.user.rnr.notice.service.IRnrNoticeContentService;
import com.cusc.nirvana.user.util.CuscStringUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.CommonClientConfigs;
import org.apache.kafka.clients.producer.ProducerConfig;
import org.apache.kafka.common.config.SaslConfigs;
import org.apache.kafka.common.serialization.StringSerializer;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.kafka.core.DefaultKafkaProducerFactory;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.kafka.support.SendResult;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.util.concurrent.ListenableFuture;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * @className: TimingSendKafka
 * @description: 用于检测有没有发送kafka，最多20次
 * @author: jk
 * @date: 2022/7/22 11:39
 * @version: 1.0
 **/
@Component
@Slf4j
public class TimingSendKafka {

    @Autowired
    private KafkaProduct kafkaProduct;

    @Resource
    private IRnrNoticeContentService iRnrNoticeContentService;

    private int pageSize =50;

    @Autowired
    private TimingSendService timingSendService;

    //五分钟执行一次
    @Scheduled(fixedDelayString = "300000")
    public void scanningT1uploadstatus(){
        log.info("重试通知开始");
        RnrNoticeContentDTO rnrNoticeConfigDTO = new RnrNoticeContentDTO();
        rnrNoticeConfigDTO.setPageSize(pageSize);
        rnrNoticeConfigDTO.setCurrPage(1);
        PageResult<RnrNoticeContentDTO> queryByList = iRnrNoticeContentService.queryByPage(rnrNoticeConfigDTO);

        double size =Math.ceil(queryByList.getTotalCount()*1.0/queryByList.getPageSize());

        for(int i = 1 ;i<=size; i++){
            RnrNoticeContentDTO rnrNoticeConfigPage = new RnrNoticeContentDTO();
            rnrNoticeConfigPage.setPageSize(pageSize);
            rnrNoticeConfigPage.setCurrPage(i);

            PageResult<RnrNoticeContentDTO> result = iRnrNoticeContentService.queryByPage(rnrNoticeConfigPage);
            timingSendService.sendKafka(result.getList());
        }

    }

//    public static void main(String[] args) {
//        Map<String, Object> props = new HashMap<>();
//        props.put(ProducerConfig.BOOTSTRAP_SERVERS_CONFIG, "10.166.2.7:9092");
//        props.put(ProducerConfig.RETRIES_CONFIG, 0);
//        props.put(ProducerConfig.KEY_SERIALIZER_CLASS_CONFIG, StringSerializer.class);
//        props.put(ProducerConfig.VALUE_SERIALIZER_CLASS_CONFIG, StringSerializer.class);
//        props.put(CommonClientConfigs.SECURITY_PROTOCOL_CONFIG, "SASL_PLAINTEXT");
//        props.put(SaslConfigs.SASL_MECHANISM, "PLAIN");
//        props.put("sasl.jaas.config", "org.apache.kafka.common.security.plain.PlainLoginModule required username=\"admin\" password=\"dH2!kE2)nD\"");
//        KafkaTemplate<String, String> kafkaTemplate = new KafkaTemplate<>(new DefaultKafkaProducerFactory<>(props));
//
//        ListenableFuture<SendResult<String, String>> send =
//                kafkaTemplate.send("cusc-rnr-card-operation-topic", "MgCardNoticeDTO(vin=VINCX000001000001, iccid=89860200013000000001, oldIccid=null, orderId=7217293d62424ff9a06c95e3238dc798, orgId=null, manufacturerOrgId=aab1ae4c00d049e99d144d52b945ec5d, tenantNo=1, rnrBizzType=4, resultCode=3, operator=)");
//
//        send.addCallback(success -> log.info("KafkaMessageProducer 发送消息成功！topic:{}, message:{}", "cusc-rnr-card-operation-topic", "MgCardNoticeDTO(vin=VINCX000001000001, iccid=89860200013000000001, oldIccid=null, orderId=7217293d62424ff9a06c95e3238dc798, orgId=null, manufacturerOrgId=aab1ae4c00d049e99d144d52b945ec5d, tenantNo=1, rnrBizzType=4, resultCode=3, operator=)"),
//                fail -> log.error("KafkaMessageProducer 发送消息失败topic:{}, message:{}", "cusc-rnr-card-operation-topic", "MgCardNoticeDTO(vin=VINCX000001000001, iccid=89860200013000000001, oldIccid=null, orderId=7217293d62424ff9a06c95e3238dc798, orgId=null, manufacturerOrgId=aab1ae4c00d049e99d144d52b945ec5d, tenantNo=1, rnrBizzType=4, resultCode=3, operator=)"));
//    }
}
