package com.cusc.nirvana.user.rnr.common.handler;

import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.exception.CuscUserException;
import com.cusc.nirvana.user.rnr.common.constants.ResponseCode;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.core.annotation.Order;
import org.springframework.http.HttpStatus;
import org.springframework.http.converter.HttpMessageNotReadableException;
import org.springframework.validation.BindException;
import org.springframework.web.HttpRequestMethodNotSupportedException;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.ResponseStatus;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;

/**
 * Description: 异常处理
 * <br />
 * CreateDate 2021-11-10 10:00
 *
 * @author yuyi
 **/
@ControllerAdvice
@Order(0)
public class RnrMgExceptionHandler {

    private static final Logger LOGGER = LoggerFactory.getLogger(RnrMgExceptionHandler.class);

    @ExceptionHandler(CuscUserException.class)
    @ResponseBody
    @ResponseStatus(HttpStatus.OK)
    public Response<?> cuscUserHandler(CuscUserException e) {
        LOGGER.warn("cuscRnrHandler Handler code: {}, msg: {}", e.getCode(), e.getMessage());
		return Response.createError(e.getMessage(), StringUtils.isBlank(e.getCode()) ? ResponseCode.SYSTEM_ERROR.getCode() : Integer.parseInt(e.getCode()));
    }

    @ExceptionHandler(Exception.class)
    @ResponseBody
    @ResponseStatus(HttpStatus.INTERNAL_SERVER_ERROR)
    public Response validExceptionHandle(Exception ex) {
        String message;
        if (ex instanceof BindException) {
            BindException bingException = (BindException) ex;
            message = bingException.getAllErrors().get(0).getDefaultMessage();
        } else if (ex instanceof HttpMessageNotReadableException) {
            HttpMessageNotReadableException notReadableException = (HttpMessageNotReadableException) ex;
            message = notReadableException.getMessage();
        } else if (ex instanceof ConstraintViolationException) {
            //参数校验异常，controller层直接参数校验（单个字段校验）
            ConstraintViolationException validationException = (ConstraintViolationException) ex;
            Set<ConstraintViolation<?>> violationErrors = validationException.getConstraintViolations();
            ConstraintViolation<?> error = violationErrors.iterator().next();
            message = error.getMessage();
        } else if (ex instanceof HttpRequestMethodNotSupportedException) {
            HttpRequestMethodNotSupportedException methodNotSupportedException = (HttpRequestMethodNotSupportedException) ex;
            message = methodNotSupportedException.getMessage();
        } else {
            message = "系统繁忙，请稍后重试！";
        }

        LOGGER.error(message, ex);
        return Response.createError(message);
    }
}
