package com.cusc.nirvana.user.rnr.mg.controller;

import cn.hutool.crypto.SmUtil;
import cn.hutool.crypto.symmetric.SymmetricCrypto;
import com.alibaba.fastjson.JSONObject;
import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.mg.dto.*;
import com.cusc.nirvana.user.rnr.mg.service.IEnterpriseVerifyService;
import com.cusc.nirvana.user.rnr.mg.service.impl.LocalChangeEnterpriseRnrPersonService;
import com.cusc.nirvana.user.rnr.mg.service.impl.LocalVerifyService;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/localverify")
@Slf4j
public class LocalVerifyController {

    @Autowired
    private LocalVerifyService localVerifyService;
    @Autowired
    private LocalChangeEnterpriseRnrPersonService localChangeEnterpriseRnrPersonService;
    @Autowired
    private IEnterpriseVerifyService enterpriseVerifyService;

    /**
     * 本地人工审核列表
     */
    @ApiOperation(value = "本地人工审核列表", notes = "本地人工审核列表")
    @PostMapping("/list")
    public Response<PageResult<LocalVerifyListDTO>> list(@RequestBody LocalVerifyListRqDTO rq) {
        return localVerifyService.orderList(rq);
    }


    /**
     * 企业负责人变更审核详情
     *
     * @param uuid rnr_order的业务主键
     * @return
     */
    @ApiOperation(value = "企业负责人变更审核详情")
    @PostMapping("/enterpriseRnrPersonDetail")
    public Response<CompanyCorporationChangeRespDTO> enterpriseRnrPersonDetail(String uuid) {
        return localChangeEnterpriseRnrPersonService.enterpriseRnrPersonDetail(uuid);
    }


    /**
     * 自然人业务审核详情
     */
    @ApiOperation(value = "自然人业务审核详情", notes = "自然人业务审核详情")
    @PostMapping("/personDetail")
    public Response personDetail(@RequestBody LocalVerifyListRqDTO rq) {
        return localVerifyService.personDetail(rq);
    }


    /**
     * 查询工单企业详情
     */
    @ApiOperation(value = "查询工单企业详情", notes = "查询工单企业详情")
    @PostMapping("/getEnterpriseDetail")
    public Response<EnterpriseVerifyDetailDTO> getEnterpriseDetail(@RequestBody RnrOrderDTO rq) {
        return enterpriseVerifyService.getEnterpriseDetail(rq);
    }


    /**
     * 审核提交
     */
    @ApiOperation(value = "审核提交", notes = "审核提交")
    @PostMapping("/submit")
    public Response submit(@RequestBody LocalVerifySubmitRq rq) {
        log.info("审核提交入参{}", JSONObject.toJSONString(rq));
//        return Response.createSuccess();
        return localVerifyService.submit(rq);
    }


    /**
     * 审核提交
     */
    @ApiOperation(value = "重试", notes = "重试")
    @PostMapping("/retry")
    public Response<RnrRelationDTO> retry(@RequestBody LocalVerifySubmitRq rq) {
        return localVerifyService.retry(rq);
    }


    /**
     * 验证工单是否未审核
     */
    @ApiOperation(value = "验证工单是否未审核", notes = "验证工单是否未审核")
    @PostMapping("/validationRnrOrder")
    public Response validationRnrOrder(@RequestBody LocalVerifyListRqDTO rq) {
        return localVerifyService.validationRnrOrder(rq);
    }


}
