package com.cusc.nirvana.user.rnr.mg.controller;

import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrCardInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrCardInfoService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 实名卡信息(MgRnrCardInfo)表控制层
 *
 * @author yuy336
 * @since 2022-03-04 11:06:45
 */
@RestController
@RequestMapping("/mgRnrCardInfo")
public class MgRnrCardInfoController {
    /**
     * 服务对象
     */
    @Autowired
    private IMgRnrCardInfoService mgRnrCardInfoService;

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @PostMapping("/queryByPage")
    @ApiOperation(value = "分页查询", notes = "分页查询")
    public Response<PageResult<MgRnrCardInfoDTO>> queryByPage(@RequestBody MgRnrCardInfoDTO bean) {
        return Response.createSuccess(mgRnrCardInfoService.queryByPage(bean));
    }

    /**
     * 通过用户id查询card信息分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @PostMapping("/queryPageByUserId")
    @ApiOperation(value = "分页查询", notes = "分页查询")
    public Response<PageResult<MgRnrCardInfoDTO>> queryPageByUserId(@RequestBody MgRnrCardInfoDTO bean) {
        return Response.createSuccess(mgRnrCardInfoService.queryPageByUserId(bean));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
    @PostMapping("/getByUuid")
    public Response<MgRnrCardInfoDTO> getByUuid(@RequestBody MgRnrCardInfoDTO bean) {
        return Response.createSuccess(mgRnrCardInfoService.getByUuid(bean));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
    @PostMapping("/queryByList")
    public Response<List<MgRnrCardInfoDTO>> queryByList(@RequestBody MgRnrCardInfoDTO bean) {
        return Response.createSuccess(mgRnrCardInfoService.queryByList(bean));
    }

    /**
     * 通过vin查询iccid list
     */
    @PostMapping("/queryBindListByVin")
    public Response<List<MgRnrCardInfoDTO>> queryBindListByVin(@RequestBody MgRnrCardInfoDTO bean) {
        return Response.createSuccess(mgRnrCardInfoService.queryBindListByVin(bean.getIotId()));
    }


    /**
     * 给定一批vin和iccid;判断一批vin以及vin下的iccids是否存在已经实名过的iccid
     */
    @PostMapping("/getBindsByVinsAndIccids")
    public Response<List<MgRnrCardInfoDTO>> queryBindListByVinsAndIccids(@RequestBody MgRnrCardInfoDTO bean) {
        return Response.createSuccess(mgRnrCardInfoService.queryBindListByVinsAndIccids(bean.getVinList(), bean.getIccidList()));
    }

    /**
     * 通过vin和实名业务id查询iccid list
     */
    @PostMapping("/queryBindListByVinAndBizType")
    public Response<List<MgRnrCardInfoDTO>> queryBindListByVinAndBizType(@RequestBody MgRnrCardInfoDTO bean) {
        return Response.createSuccess(mgRnrCardInfoService.queryBindListByVinAndBizType(bean.getIotId(), bean.getRnrBizzType()));
    }

    /**
     * 通过vin查询iccid list
     */
    @PostMapping("/queryListByVin")
    public Response<List<MgRnrCardInfoDTO>> queryListByVin(@RequestBody MgRnrCardInfoDTO bean) {
        return Response.createSuccess(mgRnrCardInfoService.queryListByVin(bean.getIotId()));
    }

    /**
     * 新增数据
     *
     * @param bean 实体
     * @return 新增结果
     */
    @PostMapping("/add")
    public Response add(@RequestBody MgRnrCardInfoDTO bean) {
        return Response.createSuccess(mgRnrCardInfoService.insert(bean));
    }

    /**
     * 编辑数据
     *
     * @param bean 实体
     * @return 编辑结果
     */
    @PostMapping("/update")
    public Response update(@RequestBody MgRnrCardInfoDTO bean) {
        return Response.createSuccess(mgRnrCardInfoService.update(bean));
    }

    /**
     * 删除数据
     *
     * @param bean 实体
     * @return 删除是否成功
     */
    @PostMapping("/deleteById")
    public Response<Boolean> deleteById(@RequestBody MgRnrCardInfoDTO bean) {
        return Response.createSuccess(mgRnrCardInfoService.deleteById(bean));
    }

    /**
     * 校验卡实名状态
     *
     * @return
     */
    @PostMapping("/checkStatus")
    public Response<Boolean> checkStatus(@RequestBody MgRnrCardInfoDTO bean) {
        return Response.createSuccess(mgRnrCardInfoService.checkIccid(bean));
    }


    @PostMapping("/getOneByIccid")
    public Response getOneByIccid(@RequestBody MgRnrCardInfoDTO bean) {
        return Response.createSuccess(mgRnrCardInfoService.getOneByIccid(bean));
    }

    @PostMapping("/updateBeans")
    public Response updateCardStatus(@RequestBody List<MgRnrCardInfoDTO> beans) {
        return Response.createSuccess(mgRnrCardInfoService.updateBatchCardStatus(beans));
    }

    @PostMapping("/updateCardStatusByRnrId")
    public Response updateCardStatusByRnrId(@RequestBody MgRnrCardInfoDTO dto) {
        mgRnrCardInfoService.updateCardStatusByRnrId(dto);
        return Response.createSuccess();
    }

    @PostMapping("/insertBeans")
    public Response insertBeans(@RequestBody List<MgRnrCardInfoDTO> beans) {
        return Response.createSuccess(mgRnrCardInfoService.insertBatchCards(beans));
    }

    @PostMapping("/sendCardNotice")
    public Response sendCardNotice(@RequestBody MgRnrCardInfoDTO dto) {
        mgRnrCardInfoService.sendCardNotice(dto);
        return Response.createSuccess();
    }


    @PostMapping("/getNumWithUnload")
    public Response getNumWithUnload(@RequestBody MgRnrInfoDTO dto) {
        int num = mgRnrCardInfoService.getNumWithUnload(dto);
        return Response.createSuccess(num);
    }
}

