package com.cusc.nirvana.user.rnr.mg.controller;

import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrFileDTO;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrFileService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 实名图片信息表(MgRnrImage0)表控制层
 *
 * @author yuy336
 * @since 2022-01-26 13:49:12
 */
@RestController
@RequestMapping("/rnr/file")
public class MgRnrFileController {
    /**
     * 服务对象
     */
    @Autowired
    private IMgRnrFileService mgRnrImageService;

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @PostMapping("/queryByPage")
    @ApiOperation(value = "分页查询", notes = "分页查询")
    public Response<PageResult<MgRnrFileDTO>> queryByPage(@RequestBody MgRnrFileDTO bean) {
        return Response.createSuccess(mgRnrImageService.queryByPage(bean));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/getByUuid")
    public Response<MgRnrFileDTO> getByUuid(@RequestBody MgRnrFileDTO bean) {
        return Response.createSuccess(mgRnrImageService.getByUuid(bean));
    }
    
     /**
     * 通过实名业务id查询图片信息
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/getByRnrid")
    public Response<List<MgRnrFileDTO>> getByRnrid(@RequestBody MgRnrFileDTO bean) {
        return Response.createSuccess(mgRnrImageService.getByRnrid(bean));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
    @PostMapping("/queryByList")
    public Response<List<MgRnrFileDTO>> queryByList(@RequestBody MgRnrFileDTO bean) {
        return Response.createSuccess(mgRnrImageService.queryByList(bean));
    }


    /**
     * 新增数据
     *
     * @param bean 实体
     * @return 新增结果
     */
    @PostMapping("/add")
    public Response add(@RequestBody MgRnrFileDTO bean) {
       return Response.createSuccess(mgRnrImageService.insert(bean));
    }

    /**
     * 编辑数据
     *
     * @param bean 实体
     * @return 编辑结果
     */
    @PostMapping("/update")
    public Response update(@RequestBody MgRnrFileDTO bean) {
        return Response.createSuccess(mgRnrImageService.update(bean));
    }

    /**
     * 删除数据
     *
     * @param bean 实体
     * @return 删除是否成功
     */
    @PostMapping("/deleteById")
    public Response<Boolean> deleteById(@RequestBody MgRnrFileDTO bean) {
        return Response.createSuccess(mgRnrImageService.deleteById(bean));
    }

}

