package com.cusc.nirvana.user.rnr.mg.controller;

import com.alibaba.fastjson.JSON;
import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrInfoService;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 实名信息表(MgRnrInfo)表控制层
 *
 * @author yuy336
 * @since 2022-02-10 18:30:50
 */
@RestController
@Slf4j
@RequestMapping("/mgRnrInfo")
public class MgRnrInfoController {
    /**
     * 服务对象
     */
    @Autowired
    private IMgRnrInfoService mgRnrInfoService;

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @PostMapping("/queryByPage")
    @ApiOperation(value = "分页查询", notes = "分页查询")
    public Response<PageResult<MgRnrInfoDTO>> queryByPage(@RequestBody MgRnrInfoDTO bean) {
        return Response.createSuccess(mgRnrInfoService.queryByPage(bean));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/getByUuid")
    public Response<MgRnrInfoDTO> getByUuid(@RequestBody MgRnrInfoDTO bean) {
       log.info("获取实名实体信息入参:{}",JSON.toJSONString(bean));
       MgRnrInfoDTO byUuid = mgRnrInfoService.getByUuid(bean);
       log.info("获取实名实体信息出参:{}", JSON.toJSONString(byUuid));
       return Response.createSuccess(mgRnrInfoService.getByUuid(bean));
    }
    
     /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/queryByList")
    public Response<List<MgRnrInfoDTO>> queryByList(@RequestBody MgRnrInfoDTO bean) {
        return Response.createSuccess(mgRnrInfoService.queryByList(bean));
    }

    /**
     * 新增数据
     *
     * @param bean 实体
     * @return 新增结果
     */
    @PostMapping("/add")
    public Response add(@RequestBody MgRnrInfoDTO bean) {
       return Response.createSuccess(mgRnrInfoService.insert(bean));
    }

    /**
     * 编辑数据
     *
     * @param bean 实体
     * @return 编辑结果
     */
    @PostMapping("/update")
    public Response update(@RequestBody MgRnrInfoDTO bean) {
        return Response.createSuccess(mgRnrInfoService.update(bean));
    }

    /**
     * 删除数据
     *
     * @param bean 实体
     * @return 删除是否成功
     */
    @PostMapping("/deleteById")
    public Response<Boolean> deleteById(@RequestBody MgRnrInfoDTO bean) {
        return Response.createSuccess(mgRnrInfoService.deleteById(bean));
    }

}

