package com.cusc.nirvana.user.rnr.mg.controller;

import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrOperationLogDTO;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrOperationLogService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 实名操作日志，包含rnr_info_oplog(MgRnrOperationLog)表控制层
 *
 * @author yuy336
 * @since 2022-03-04 15:07:39
 */
@RestController
@RequestMapping("/mgRnrOperationLog")
public class MgRnrOperationLogController {
    /**
     * 服务对象
     */
    @Autowired
    private IMgRnrOperationLogService mgRnrOperationLogService;

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @PostMapping("/queryByPage")
    @ApiOperation(value = "分页查询", notes = "分页查询")
    public Response<PageResult<MgRnrOperationLogDTO>> queryByPage(@RequestBody MgRnrOperationLogDTO bean) {
        return Response.createSuccess(mgRnrOperationLogService.queryByPage(bean));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/getByUuid")
    public Response<MgRnrOperationLogDTO> getByUuid(@RequestBody MgRnrOperationLogDTO bean) {
        return Response.createSuccess(mgRnrOperationLogService.getByUuid(bean));
    }
    
     /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/queryByList")
    public Response<List<MgRnrOperationLogDTO>> queryByList(@RequestBody MgRnrOperationLogDTO bean) {
        return Response.createSuccess(mgRnrOperationLogService.queryByList(bean));
    }

    /**
     * 新增数据
     *
     * @param bean 实体
     * @return 新增结果
     */
    @PostMapping("/add")
    public Response add(@RequestBody MgRnrOperationLogDTO bean) {
       return Response.createSuccess(mgRnrOperationLogService.insert(bean));
    }

    /**
     * 编辑数据
     *
     * @param bean 实体
     * @return 编辑结果
     */
    @PostMapping("/update")
    public Response update(@RequestBody MgRnrOperationLogDTO bean) {
        return Response.createSuccess(mgRnrOperationLogService.update(bean));
    }
}

