package com.cusc.nirvana.user.rnr.mg.controller;

import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.mg.dto.MgTenantBizzConfigDTO;
import com.cusc.nirvana.user.rnr.mg.service.IMgTenantBizzConfigService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 租户业务配置(MgTenantBizzConfig)表控制层
 *
 * @author yuy336
 * @since 2022-06-14 09:36:10
 */
@RestController
@RequestMapping("/mgTenantBizzConfig")
public class MgTenantBizzConfigController {
    /**
     * 服务对象
     */
    @Autowired
    private IMgTenantBizzConfigService mgTenantBizzConfigService;

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @PostMapping("/queryByPage")
    @ApiOperation(value = "分页查询", notes = "分页查询")
    public Response<PageResult<MgTenantBizzConfigDTO>> queryByPage(@RequestBody MgTenantBizzConfigDTO bean) {
        return Response.createSuccess(mgTenantBizzConfigService.queryByPage(bean));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/getByUuid")
    public Response<MgTenantBizzConfigDTO> getByUuid(@RequestBody MgTenantBizzConfigDTO bean) {
        return Response.createSuccess(mgTenantBizzConfigService.getByUuid(bean));
    }
    
     /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/queryByList")
    public Response<List<MgTenantBizzConfigDTO>> queryByList(@RequestBody MgTenantBizzConfigDTO bean) {
        return Response.createSuccess(mgTenantBizzConfigService.queryByList(bean));
    }

    /**
     * 新增数据
     *
     * @param bean 实体
     * @return 新增结果
     */
    @PostMapping("/add")
    public Response add(@RequestBody MgTenantBizzConfigDTO bean) {
       return Response.createSuccess(mgTenantBizzConfigService.insert(bean));
    }

    /**
     * 编辑数据
     *
     * @param bean 实体
     * @return 编辑结果
     */
    @PostMapping("/update")
    public Response update(@RequestBody MgTenantBizzConfigDTO bean) {
        return Response.createSuccess(mgTenantBizzConfigService.update(bean));
    }

    /**
     * 删除数据
     *
     * @param bean 实体
     * @return 删除是否成功
     */
    @PostMapping("/deleteById")
    public Response<Boolean> deleteById(@RequestBody MgTenantBizzConfigDTO bean) {
        return Response.createSuccess(mgTenantBizzConfigService.deleteById(bean));
    }

}

