package com.cusc.nirvana.user.rnr.mg.controller;

import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.mg.dto.OpenTenantRelationDTO;
import com.cusc.nirvana.user.rnr.mg.service.IOpenTenantRelationService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 开放平台租户和实名制租户映射关系表(OpenTenantRelation)表控制层
 *
 * @author yuy336
 * @since 2022-06-15 20:03:28
 */
@RestController
@RequestMapping("/openTenantRelation")
public class OpenTenantRelationController {
    /**
     * 服务对象
     */
    @Autowired
    private IOpenTenantRelationService openTenantRelationService;

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @PostMapping("/queryByPage")
    @ApiOperation(value = "分页查询", notes = "分页查询")
    public Response<PageResult<OpenTenantRelationDTO>> queryByPage(@RequestBody OpenTenantRelationDTO bean) {
        return Response.createSuccess(openTenantRelationService.queryByPage(bean));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/getByUuid")
    public Response<OpenTenantRelationDTO> getByUuid(@RequestBody OpenTenantRelationDTO bean) {
        return Response.createSuccess(openTenantRelationService.getByUuid(bean));
    }
    
     /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/queryByList")
    public Response<List<OpenTenantRelationDTO>> queryByList(@RequestBody OpenTenantRelationDTO bean) {
        return Response.createSuccess(openTenantRelationService.queryByList(bean));
    }

    /**
     * 新增数据
     *
     * @param bean 实体
     * @return 新增结果
     */
    @PostMapping("/add")
    public Response add(@RequestBody OpenTenantRelationDTO bean) {
       return Response.createSuccess(openTenantRelationService.insert(bean));
    }

    /**
     * 编辑数据
     *
     * @param bean 实体
     * @return 编辑结果
     */
    @PostMapping("/update")
    public Response update(@RequestBody OpenTenantRelationDTO bean) {
        return Response.createSuccess(openTenantRelationService.update(bean));
    }

    /**
     * 删除数据
     *
     * @param bean 实体
     * @return 删除是否成功
     */
    @PostMapping("/deleteById")
    public Response<Boolean> deleteById(@RequestBody OpenTenantRelationDTO bean) {
        return Response.createSuccess(openTenantRelationService.deleteById(bean));
    }

}

