package com.cusc.nirvana.user.rnr.mg.controller;

import com.cusc.nirvana.common.loader.StringUtils;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.common.constants.ResponseCode;
import com.cusc.nirvana.user.rnr.mg.dto.OrgBusinessTagDTO;
import com.cusc.nirvana.user.rnr.mg.dto.OrgBusinessTagQueryDTO;
import com.cusc.nirvana.user.rnr.mg.service.IOrgBusinessTagService;
import com.cusc.nirvana.user.rnr.mg.validation.group.Delete;
import com.cusc.nirvana.user.rnr.mg.validation.group.Insert;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 业务标签
 */
@RestController
@RequestMapping("/businessTag")
public class OrgBusinessTagController {

    @Autowired
    private IOrgBusinessTagService businessTagService;

    /**
     * 新增业务标签
     *
     * @param tagDTO
     * @return
     */
    @PostMapping("add")
    public Response<OrgBusinessTagDTO> add(@RequestBody @Validated(Insert.class) OrgBusinessTagDTO tagDTO) {
        Response<OrgBusinessTagDTO> response = businessTagService.insert(tagDTO);
        return response;
    }

    /**
     * 修改业务标签
     *
     * @param tagDTO
     * @return
     */
    @PostMapping("update")
    public Response<OrgBusinessTagDTO> update(@RequestBody @Validated(Insert.class) OrgBusinessTagDTO tagDTO) {
        Response<OrgBusinessTagDTO> response = businessTagService.update(tagDTO);
        return response;
    }

    /**
     * 删除组织与卡关系
     *
     * @param tagDTO
     * @return
     */
    @PostMapping("delete")
    public Response delete(@RequestBody @Validated(Delete.class) OrgBusinessTagDTO tagDTO) {
        Response response = businessTagService.remove(tagDTO.getUuid());
        return response;
    }

    /**
     * 查询指定数据
     *
     * @param uuid
     * @return
     */
    @GetMapping("getByUuid")
    public Response<OrgBusinessTagDTO> getByUuid(String uuid) {
        Response<OrgBusinessTagDTO> response = businessTagService.getByUuid(uuid);
        return response;
    }

    /**
     * 根据租户和标签编码查询业务标签信息
     *
     * @param tagDTO
     * @return
     */
    @PostMapping("/getByTagCode")
    public Response<OrgBusinessTagDTO> getByTagCode(@RequestBody OrgBusinessTagDTO tagDTO) {
        if (StringUtils.isBlank(tagDTO.getTenantNo()) || StringUtils.isBlank(tagDTO.getTagCode())) {
            return Response.createError(ResponseCode.PARAMETER_NOT_NULL.getMsg(),
                    ResponseCode.PARAMETER_NOT_NULL.getCode());

        }
        return businessTagService.getByTagCode(tagDTO.getTenantNo(), tagDTO.getTagCode());
    }

    /**
     * 查询标签信息列表
     *
     * @param queryDto
     * @return
     */
    @PostMapping("query")
    @ApiOperation(value = "标签信息列表查询", notes = "标签信息列表查询")
    public Response<List<OrgBusinessTagDTO>> query(@RequestBody @Validated OrgBusinessTagQueryDTO queryDto) {
        Response<List<OrgBusinessTagDTO>> response =
                businessTagService.query(queryDto.getTenantNo(), queryDto.getOrgUuid());
        return response;
    }

}
