package com.cusc.nirvana.user.rnr.mg.controller;

import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.mg.dto.RnrNoticeTemplateConfigDTO;
import com.cusc.nirvana.user.rnr.mg.service.IRnrNoticeTemplateConfigService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 消息模板配置(RnrNoticeTemplateConfig)表控制层
 *
 * @author yuy336
 * @since 2022-06-01 11:07:09
 */
@RestController
@RequestMapping("/rnrNoticeTemplateConfig")
public class RnrNoticeTemplateConfigController {
    /**
     * 服务对象
     */
    @Autowired
    private IRnrNoticeTemplateConfigService rnrNoticeTemplateConfigService;

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @PostMapping("/queryByPage")
    @ApiOperation(value = "分页查询", notes = "分页查询")
    public Response<PageResult<RnrNoticeTemplateConfigDTO>> queryByPage(@RequestBody RnrNoticeTemplateConfigDTO bean) {
        return Response.createSuccess(rnrNoticeTemplateConfigService.queryByPage(bean));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/getByUuid")
    public Response<RnrNoticeTemplateConfigDTO> getByUuid(@RequestBody RnrNoticeTemplateConfigDTO bean) {
        return Response.createSuccess(rnrNoticeTemplateConfigService.getByUuid(bean));
    }
    
     /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/queryByList")
    public Response<List<RnrNoticeTemplateConfigDTO>> queryByList(@RequestBody RnrNoticeTemplateConfigDTO bean) {
        return Response.createSuccess(rnrNoticeTemplateConfigService.queryByList(bean));
    }

    /**
     * 新增数据
     *
     * @param bean 实体
     * @return 新增结果
     */
    @PostMapping("/add")
    public Response add(@RequestBody RnrNoticeTemplateConfigDTO bean) {
       return Response.createSuccess(rnrNoticeTemplateConfigService.insert(bean));
    }

    /**
     * 编辑数据
     *
     * @param bean 实体
     * @return 编辑结果
     */
    @PostMapping("/update")
    public Response update(@RequestBody RnrNoticeTemplateConfigDTO bean) {
        return Response.createSuccess(rnrNoticeTemplateConfigService.update(bean));
    }

    /**
     * 删除数据
     *
     * @param bean 实体
     * @return 删除是否成功
     */
    @PostMapping("/deleteById")
    public Response<Boolean> deleteById(@RequestBody RnrNoticeTemplateConfigDTO bean) {
        return Response.createSuccess(rnrNoticeTemplateConfigService.deleteById(bean));
    }

}

