package com.cusc.nirvana.user.rnr.mg.controller;

import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.mg.dto.RnrOrderOperationLogDTO;
import com.cusc.nirvana.user.rnr.mg.service.IRnrOrderOperationLogService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 实名工单操作日志(MgRnrOrderOperationLog)表控制层
 *
 * @author yuy336
 * @since 2022-03-04 10:07:53
 */
@RestController
@RequestMapping("/mgRnrOrderOperationLog")
public class RnrOrderOperationLogController {
    /**
     * 服务对象
     */
    @Autowired
    private IRnrOrderOperationLogService mgRnrOrderOperationLogService;

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @PostMapping("/queryByPage")
    @ApiOperation(value = "分页查询", notes = "分页查询")
    public Response<PageResult<RnrOrderOperationLogDTO>> queryByPage(@RequestBody RnrOrderOperationLogDTO bean) {
        return Response.createSuccess(mgRnrOrderOperationLogService.queryByPage(bean));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/getByUuid")
    public Response<RnrOrderOperationLogDTO> getByUuid(@RequestBody RnrOrderOperationLogDTO bean) {
        return Response.createSuccess(mgRnrOrderOperationLogService.getByUuid(bean));
    }
    
     /**
     * 通过主键查询单条数据
     *
     * @param bean 实体
     * @return 单条数据
     */
   @PostMapping("/queryByList")
    public Response<List<RnrOrderOperationLogDTO>> queryByList(@RequestBody RnrOrderOperationLogDTO bean) {
        return Response.createSuccess(mgRnrOrderOperationLogService.queryByList(bean));
    }

    /**
     * 新增数据
     *
     * @param bean 实体
     * @return 新增结果
     */
    @PostMapping("/add")
    public Response add(@RequestBody RnrOrderOperationLogDTO bean) {
       return Response.createSuccess(mgRnrOrderOperationLogService.insert(bean));
    }

    /**
     * 编辑数据
     *
     * @param bean 实体
     * @return 编辑结果
     */
    @PostMapping("/update")
    public Response update(@RequestBody RnrOrderOperationLogDTO bean) {
        return Response.createSuccess(mgRnrOrderOperationLogService.update(bean));
    }
}

