package com.cusc.nirvana.user.rnr.mg.controller;

import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrCardInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.RnrRelationDTO;
import com.cusc.nirvana.user.rnr.mg.dto.RnrRelationIccidDTO;
import com.cusc.nirvana.user.rnr.mg.service.IRnrRelationService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * Description: 实名关系控制层
 * <br />
 * CreateDate 2022-03-04 15:14:20
 *
 * @author yuyi
 **/
@Slf4j
@RestController
@RequestMapping("/rnr/relation")
public class RnrRelationController {

    /**
     * Description: 实名关系service
     * <br />
     * CreateDate 2022-03-03 15:56:52
     *
     * @author yuyi
     **/
    @Autowired
    private IRnrRelationService rnrRelationService;

    /**
     * 保存实名关系
     *
     * @param bean 实体
     * @return 单条数据
     */
    @PostMapping("/saveRnrRelation")
    public Response saveRnrRelation(@RequestBody RnrRelationDTO bean) {
        return rnrRelationService.saveRnrRelation(bean);
    }

    /**
     * 同步实名信息
     *
     * @param bean 实体
     * @return 单条数据
     */
    @PostMapping("/syncRnrRelation")
    public Response syncRnrRelation(@RequestBody RnrRelationDTO bean) {
        return rnrRelationService.syncRnrRelation(bean);
    }

    /**
     * Description: 锁定iccid
     * <br />
     * CreateDate 2022-03-07 15:24:32
     *
     * @author yuyi
     **/
    @PostMapping("/lockRnrIccidList")
    public Response lockRnrIccidList(@RequestBody RnrRelationIccidDTO bean) {
        rnrRelationService.lockRnrIccidList(bean.getTenantNo(), bean.getIccidList(), bean.getValue());
        return Response.createSuccess();
    }

    /**
     * Description: 解锁iccid
     * <br />
     * CreateDate 2022-03-07 15:24:32
     *
     * @author yuyi
     **/
    @PostMapping("/unLockRnrIccidList")
    public Response unLockRnrIccidList(@RequestBody RnrRelationIccidDTO bean) {
        rnrRelationService.unLockRnrIccidList(bean.getTenantNo(), bean.getIccidList());
        return Response.createSuccess();
    }

    /**
     * Description: 检查iccid的状态
     * <br />
     * CreateDate 2022-03-07 16:14:07
     *
     * @author yuyi
     **/
    @PostMapping("/checkIccidStatus")
    public Response checkIccidStatus(@RequestBody RnrRelationIccidDTO bean) {
        log.info("checkIccidStatus 被访问了");
        rnrRelationService.checkIccidStatus(bean.getTenantNo(), bean.getIccidList());
        return Response.createSuccess();
    }

    /**
     * 根据iccid获取实名关系信息（rnr info、公司信息、联系人信息）
     *
     * @param bean
     * @return
     */
    @PostMapping("/getRnrRelation")
    public Response<RnrRelationDTO> getRnrRelation(@RequestBody MgRnrCardInfoDTO bean) {
        return rnrRelationService.getRnrRelation(bean);
    }
}
