package com.cusc.nirvana.user.rnr.mg.converter;

import com.cusc.nirvana.user.rnr.mg.dao.entity.MgVehicleCompanyPO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrCompanyInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgVehicleCompanyDTO;
import org.mapstruct.Mapper;
import org.mapstruct.factory.Mappers;

import java.util.List;

/**
 * 车企信息表(FpVehicleCompany)表服务接口
 *
 * @author yuy336
 * @since 2022-04-19 20:11:33
 */
@Mapper
public interface MgVehicleCompanyConverter {

    MgVehicleCompanyConverter INSTANCE = Mappers.getMapper(MgVehicleCompanyConverter.class);

    /**
     * Description: do 转 dto
     * <br />
     * CreateDate 2021-11-18 15:21:27
     *
     * @author yuyi
     **/
    MgVehicleCompanyDTO poToDto(MgVehicleCompanyPO bean);

    /**
     * Description: dto 转 do
     * <br />
     * CreateDate 2021-11-18 15:21:27
     *
     * @author yuyi
     **/
    MgVehicleCompanyPO dtoToPo(MgVehicleCompanyDTO bean);

    /**
     * Description: do list 转 dto list
     * <br />
     * CreateDate 2021-11-18 15:21:27
     *
     * @author yuyi
     **/
    List<MgVehicleCompanyDTO> poListToDtoList(List<MgVehicleCompanyPO> list);

    /**
     * Description: 实名的公司信息转为车企信息
     * <br />
     * CreateDate 2021-11-18 15:21:27
     *
     * @author yuyi
     **/
    MgVehicleCompanyDTO rnrCompanyToVehicleCompany(MgRnrCompanyInfoDTO bean);

    /**
     * Description: 将实名信息转为车企信息
     * <br />
     * CreateDate 2021-11-18 15:21:27
     *
     * @author yuyi
     **/
    default MgVehicleCompanyDTO rnrToVehicleCompany(MgRnrInfoDTO rnrInfo, MgRnrCompanyInfoDTO company){
        MgVehicleCompanyDTO ret = MgVehicleCompanyConverter.INSTANCE.rnrCompanyToVehicleCompany(company);
        ret.setCorporationName(rnrInfo.getFullName());
        //ret.setCorporationGender(rnrInfo.getGender());
        //ret.setCorporationCertType(rnrInfo.getCertType());
        //ret.setCorporationCertNumber(rnrInfo.getCertNumber());
        //ret.setCorporationCertAddress(rnrInfo.getCertAddress());
        //ret.setCorporationContactAddress(rnrInfo.getContactAddress());
        ret.setCorporationPhone(rnrInfo.getPhone());
        //ret.setCorporationBirthday(rnrInfo.getBirthday());
        //ret.setCorporationEffectiveDate(rnrInfo.getEffectiveDate());
        //ret.setCorporationExpiredDate(rnrInfo.getExpiredDate());
        //ret.setCorporationNation(rnrInfo.getNation());
        //ret.setCorporationCountry(rnrInfo.getCountry());
        //ret.setCorporationIssuingAuthority(rnrInfo.getIssuingAuthority());
        ret.setFirstRnrId(rnrInfo.getUuid());
        ret.setTenantNo(rnrInfo.getTenantNo());
        return ret;
    }
}
