package com.cusc.nirvana.user.rnr.mg.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.user.rnr.mg.constants.RnrStatus;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrCardInfoPO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrCardInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 实名卡信息(MgRnrCardInfo)表服务接口
 *
 * @author yuy336
 * @since 2022-03-04 11:06:45
 */
public interface IMgRnrCardInfoService extends IService<MgRnrCardInfoPO> {

    /**
     * 通过UUID查询单条数据
     *
     * @param bean
     * @return 实例对象
     */
    MgRnrCardInfoDTO getByUuid(MgRnrCardInfoDTO bean);

    /**
     * 通过查询条件查询集合数据
     *
     * @param bean
     * @return 集合对象
     */
    List<MgRnrCardInfoDTO> queryByList(MgRnrCardInfoDTO bean);

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    PageResult<MgRnrCardInfoDTO> queryByPage(MgRnrCardInfoDTO bean);

    /**
     * 新增数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    MgRnrCardInfoDTO insert(MgRnrCardInfoDTO bean);

    /**
     * 修改数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    MgRnrCardInfoDTO update(MgRnrCardInfoDTO bean);

    /**
     * 通过主键删除数据
     *
     * @param bean
     * @return 是否成功
     */
    boolean deleteById(MgRnrCardInfoDTO bean);

    /**
     * Description: 批量新增卡信息
     * <br />
     * CreateDate 2022-03-04 11:27:51
     *
     * @author yuyi
     **/
    Integer addRnrCardBatch(List<MgRnrCardInfoPO> beanList);

    /**
     * 查询有效的card信息
     *
     * @param bean
     * @return 实例对象
     */
    List<MgRnrCardInfoDTO> getByIccid(MgRnrCardInfoDTO bean);

    /**
     * Description: 检查iccid是否存在
     * <br />
     * CreateDate 2022-03-04 19:01:54
     *
     * @author yuyi
     **/
    boolean checkIccidExists(MgRnrCardInfoDTO bean);

    /**
     * 更新解绑记录
     *
     * @param uuids
     * @return
     */
    Integer unboundCardBatch(@Param("beans") List<String> uuids, RnrStatus status);

    /**
     * 根据iccid获取card列表
     *
     * @param bean
     * @return
     */
    List<MgRnrCardInfoDTO> getListByIccid(MgRnrCardInfoDTO bean);

    /**
     * 根据业务id和iccid获取数据
     *
     * @param orderId
     * @param iccid
     * @return
     */
    MgRnrCardInfoDTO getByOrderIdAndIccId(String orderId, String iccid);

    /**
     * 根据iccid 获取card信息
     *
     * @param
     * @return
     */
    MgRnrCardInfoDTO getOneByIccid(MgRnrCardInfoDTO bean);

    /**
     * 更新mq发送状态
     *
     * @param mgRnrCardInfoDTO
     * @return
     */
    Integer updateCardNoticeStatus(MgRnrCardInfoDTO mgRnrCardInfoDTO);

    /**
     * 更新消息状态和实名状态
     *
     * @param orderId
     * @param noticeStatus
     * @param rnrStatus
     * @return
     */
    Integer updateCardStatusByOrderId(String orderId, int noticeStatus, int rnrStatus);

    /**
     * 卡的绑定状态校验
     *
     * @param bean
     * @return
     */
    boolean checkIccid(MgRnrCardInfoDTO bean);

    /**
     * 根据vin查询iccidList
     */
    List<MgRnrCardInfoDTO> queryBindListByVin(String vin);


    Integer updateBatchCardStatus(List<MgRnrCardInfoDTO> beans);

    /**
     * 给定一批vin和iccid;判断一批vin以及vin下的iccids是否存在已经实名过的iccid
     */
    List<MgRnrCardInfoDTO> queryBindListByVinsAndIccids(List<String> vins, List<String> iccids);

    List<MgRnrCardInfoDTO> queryBindListByVinAndBizType(String vin, int bizTpye);

    Integer insertBatchCards(List<MgRnrCardInfoDTO> beans);

    /**
     * 根据rnrId更新状态
     *
     * @param dto
     */
    void updateCardStatusByRnrId(MgRnrCardInfoDTO dto);

    void sendCardNotice(MgRnrCardInfoDTO dto);

    List<MgRnrCardInfoDTO> queryListByVin(String vin);

    /**
     * 通过用户id查询card信息分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    PageResult<MgRnrCardInfoDTO> queryPageByUserId(MgRnrCardInfoDTO bean);

    /**
     * 根据iccid最新的实名卡信息
     */
    MgRnrCardInfoDTO getNewRnrCardByIccid(MgRnrCardInfoDTO bean);


    int getNumWithUnload(MgRnrInfoDTO dto);
}
