package com.cusc.nirvana.user.rnr.mg.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrFilePO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrFileDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;

import java.util.List;

/**
 * 实名图片信息表(MgRnrImage0)表服务接口
 *
 * @author yuy336
 * @since 2022-01-26 13:49:12
 */
public interface IMgRnrFileService extends IService<MgRnrFilePO> {

    /**
     * 通过UUID查询单条数据
     *
     * @param bean
     * @return 实例对象
     */
    MgRnrFileDTO getByUuid(MgRnrFileDTO bean);


    /**
     * 根据实名id获取信息
     * @param bean
     * @return
     */
    List<MgRnrFileDTO> getByRnrid(MgRnrFileDTO bean);

    /**
     * 通过查询条件查询集合数据
     *
     * @param bean
     * @return 集合对象
     */
    List<MgRnrFileDTO> queryByList(MgRnrFileDTO bean);

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    PageResult<MgRnrFileDTO> queryByPage(MgRnrFileDTO bean);

    /**
     * 新增数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    MgRnrFileDTO insert(MgRnrFileDTO bean);

    /**
     * 修改数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    MgRnrFileDTO update(MgRnrFileDTO bean);

    /**
     * 通过主键删除数据
     *
     * @param bean
     * @return 是否成功
     */
    boolean deleteById(MgRnrFileDTO bean);


    /**
     * 实名文件批量上传
     *
     * @param imageList 图片集合
     * @param imageList 实名信息DTO
     * @return 集合对象
     */
    List<MgRnrFileDTO> rnrImageBatchUpload(List<MgRnrFileDTO> imageList, MgRnrInfoDTO rnrInfoDTO);

    /**
     * Description: 批量新增图片信息
     * <br />
     * CreateDate 2022-03-04 11:27:51
     *
     * @author yuyi
     **/
    Integer addRnrFileBatch(List<MgRnrFilePO> beanList);

    /**
     * Description: 批量新增文件信息
     * <br />
     * CreateDate 2022-03-04 11:27:51
     *
     * @author yuyi
     **/
    Integer addRnrFileFromInfo(MgRnrInfoDTO info, List<MgRnrFileDTO> beanList);

}
