package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.alibaba.fastjson.JSON;
import com.cusc.nirvana.common.loader.CollectionUtils;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.eiam.client.UserClient;
import com.cusc.nirvana.user.eiam.dto.UserDTO;
import com.cusc.nirvana.user.rnr.mg.constants.AuthWayTypeEnum;
import com.cusc.nirvana.user.rnr.mg.constants.CertTypeEnum;
import com.cusc.nirvana.user.rnr.mg.constants.CompanyTypeEnum;
import com.cusc.nirvana.user.rnr.mg.constants.GenderEnum;
import com.cusc.nirvana.user.rnr.mg.constants.IndustryTypeEnum;
import com.cusc.nirvana.user.rnr.mg.constants.RnrFileType;
import com.cusc.nirvana.user.rnr.mg.dto.EnterpriseVerifyDetailDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrAuthenticationResultDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrCompanyInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrFileDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.RnrOrderDTO;
import com.cusc.nirvana.user.rnr.mg.service.IEnterpriseVerifyService;
import com.cusc.nirvana.user.rnr.mg.service.IFileService;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrAuthenticationResultService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author xxx
 */
@Service
@Slf4j
public class EnterpriseVerifyServiceImpl implements IEnterpriseVerifyService {

    @Autowired
    private RnrOrderServiceImpl rnrOrderService;
    @Autowired
    private MgRnrCompanyInfoServiceImpl mgRnrCompanyInfoService;
    @Autowired
    private MgRnrInfoServiceImpl mgRnrInfoService;
    @Autowired
    private MgRnrFileServiceImpl mgRnrFileService;
    @Autowired
    private IMgRnrAuthenticationResultService iMgRnrAuthenticationResultService;

    @Autowired
    private UserClient userClient;


    @Resource
	private IFileService fileService;


    @Override
    public Response<EnterpriseVerifyDetailDTO> getEnterpriseDetail(RnrOrderDTO rnrOrderDTO) {
        EnterpriseVerifyDetailDTO enterpriseVerifyDetailDTO = new EnterpriseVerifyDetailDTO();

        //查询工单信息
        RnrOrderDTO rnrOrderDetails = rnrOrderService.getByUuid(rnrOrderDTO);
        log.info("查询工单信息返参:{}", JSON.toJSONString(rnrOrderDetails));
        if (null == rnrOrderDetails) {
            return Response.createError("工单不存在");
        }
        BeanUtils.copyProperties(rnrOrderDetails, enterpriseVerifyDetailDTO.getRnrOrderDetail());

        //----企业信息,根据rnr_id实名id查询企业信息
        MgRnrCompanyInfoDTO companyInfoParams = new MgRnrCompanyInfoDTO();
        //rnr_id为uuid
        companyInfoParams.setRnrId(rnrOrderDetails.getRnrId());
        MgRnrCompanyInfoDTO mgRnrCompanyInfoDTO = mgRnrCompanyInfoService.getByRnrid(companyInfoParams);
        log.info("查询企业信息返参:{}", JSON.toJSONString(mgRnrCompanyInfoDTO));
        if (mgRnrCompanyInfoDTO == null) {
            return Response.createError("企业信息不能为空");
        }
        BeanUtils.copyProperties(mgRnrCompanyInfoDTO, enterpriseVerifyDetailDTO.getCompanyInfoDetail());

        //责任人的信息
        MgRnrInfoDTO rnrInfoParams = new MgRnrInfoDTO();
        rnrInfoParams.setUuid(rnrOrderDetails.getRnrId());
        MgRnrInfoDTO mgRnrInfoDTO = mgRnrInfoService.getByUuid(rnrInfoParams);
        log.info("查询责任人的信息返参:{}", JSON.toJSONString(mgRnrInfoDTO));
        if (mgRnrInfoDTO == null || StringUtils.isBlank(mgRnrInfoDTO.getCertType())) {
            return Response.createError("实名责任人信息不能为空");
        }
        EnterpriseVerifyDetailDTO.CorporationInfoDetail corporationInfoDetail =
                enterpriseVerifyDetailDTO.getCorporationInfoDetail();
        corporationInfoDetail.setCorporationName(mgRnrInfoDTO.getFullName());
        corporationInfoDetail.setCorporationGender(mgRnrInfoDTO.getGender());
        corporationInfoDetail.setCorporationGenderName(GenderEnum.findNameByCode(mgRnrInfoDTO.getGender()));
//        corporationInfoDetail.setCorporationCertType(mgRnrInfoDTO.getCertType());
        corporationInfoDetail.setCorporationCertType(CertTypeEnum.getEnumByCode(mgRnrInfoDTO.getCertType()).getName());
        corporationInfoDetail.setCorporationCertNumber(mgRnrInfoDTO.getCertNumber());
        corporationInfoDetail.setCorporationCertExpirationDate(mgRnrInfoDTO.getExpiredDate());
        corporationInfoDetail.setCorporationCertAddress(mgRnrInfoDTO.getCertAddress());
        corporationInfoDetail.setCorporationPhone(mgRnrInfoDTO.getPhone());
        corporationInfoDetail.setCorporationContactAddress(mgRnrInfoDTO.getContactAddress());
        BeanUtils.copyProperties(mgRnrInfoDTO, enterpriseVerifyDetailDTO.getCorporationInfoDetail());

        //通过rnrId查询企业所有相关证件，包括责任人身份证人像面、身份证国徽面、活体截图1、企业证件照片、委托书
        MgRnrFileDTO file = new MgRnrFileDTO();
        file.setRnrId(rnrOrderDetails.getRnrId());
        /////file.setFileType(RnrFileType.ENTERPRISE_AUTH_FILE.getCode());
        List<MgRnrFileDTO> fileList = mgRnrFileService.queryByList(file);
        log.info("查询文件信息返参:{}", JSON.toJSONString(fileList));
        if (CollectionUtils.isEmpty(fileList)) {
            return Response.createError("企业相关证件不能为空");
        }

        fileList.forEach(mgRnrFileDTO -> {
            try {
                //活体认证视频，视频返回url
                //base64与url不同时返回，url放在base64里
                if (RnrFileType.LIVENESS_VIDEO.getCode().intValue() == mgRnrFileDTO.getFileType()
                        && StringUtils.isNotBlank(mgRnrFileDTO.getFileSystemId())) {
                  /*  String objectUrl = null;
                    if (FIleSystemType.OSS.getCode().equals(fileSelect)) {
                        objectUrl = OSSUtil.getFileUrl(ossConfig.getBucketName(),
                                ossConfig.getPrefix() + mgRnrFileDTO.getFileSystemId());
                    } else {
                        throw new CuscUserException(fileSelect, "未知文件系统");
                    }*/
					String fileUrl = fileService.getFileUrl(mgRnrFileDTO.getFileSystemId());
					mgRnrFileDTO.setFileBase64(fileUrl);
                }
            } catch (Exception e) {
                log.error("---根据FileSystemId获取文件url失败mgRnrFileDTO：{}", mgRnrFileDTO);
                log.error("---根据FileSystemId获取文件url失败Exception：{}", e);
            }
        });

        //文件根据fileSystemId统一调用接口
        //根据文件类型分组
        Map<Integer, List<MgRnrFileDTO>> fileMap2List =
                fileList.stream().collect(Collectors.groupingBy(MgRnrFileDTO::getFileType));

        List<String> fileSystemList = new ArrayList<>();
        log.warn("fileList++++++++{}",JSON.toJSON(fileList));
        for(MgRnrFileDTO mgRnrFileDTO:fileList){
            if(RnrFileType.VEHUCLE_BIND.getCode().equals(mgRnrFileDTO.getFileType())||RnrFileType.DUTY_FILE.getCode().equals(mgRnrFileDTO.getFileType())||RnrFileType.ENTERPRISE_AUTH_FILE.getCode().equals(mgRnrFileDTO.getFileType())){
                fileSystemList.add(mgRnrFileDTO.getFileSystemId());
            }
        }
        log.warn("fileSystemList========={}",JSON.toJSON(fileSystemList));
        enterpriseVerifyDetailDTO.getCorporationInfoDetail().setFileSystemList(fileSystemList);
        //设置企业证件照片
        enterpriseVerifyDetailDTO.getCompanyInfoDetail()
                .setCompanyLicenseFiles(fileMap2List.get(RnrFileType.ENTERPRISE_PIC.getCode()));
        enterpriseVerifyDetailDTO.getCompanyInfoDetail().setCompanyCertType(CertTypeEnum.getEnumByCode(mgRnrCompanyInfoDTO.getCompanyCertType()).getName());
        enterpriseVerifyDetailDTO.getCompanyInfoDetail().setCompanyType(null !=CompanyTypeEnum.getEnumByCode(mgRnrCompanyInfoDTO.getCompanyType())?CompanyTypeEnum.getEnumByCode(mgRnrCompanyInfoDTO.getCompanyType()).getValue():"");
        enterpriseVerifyDetailDTO.getCompanyInfoDetail().setIndustryType(null != IndustryTypeEnum.getEnumByCode(mgRnrCompanyInfoDTO.getIndustryType()) ?IndustryTypeEnum.getEnumByCode(mgRnrCompanyInfoDTO.getIndustryType()).getValue():"");
        //设置企业实名认证授权书
        enterpriseVerifyDetailDTO.getCorporationInfoDetail()
                .setAuthorizationLetterPic(fileMap2List.get(RnrFileType.ENTERPRISE_AUTH_FILE.getCode()));
        //人脸图片
        enterpriseVerifyDetailDTO.getVerifyLivingMsg().getFaceImages()
                .addAll((fileMap2List.get(RnrFileType.LIVENESS_SCREEN_FIRST.getCode())));
        enterpriseVerifyDetailDTO.getVerifyLivingMsg().getFaceImages()
                .addAll((fileMap2List.get(RnrFileType.LIVENESS_SCREEN_TWO.getCode())));
        //活体认证视频，视频返回url
        enterpriseVerifyDetailDTO.getVerifyLivingMsg()
                .setLivingVideo(fileMap2List.get(RnrFileType.LIVENESS_VIDEO.getCode()).get(0));
        ////上面会必有的文件，下面可能没有，只会有一种，如身份证或警官证，详见枚举类CertTypeEnum，根据证件类型返回文件
        String certType = mgRnrInfoDTO.getCertType();
        //身份证
        if (CertTypeEnum.IDCARD.getCode().equalsIgnoreCase(certType)) {
            //设置责任人身份证人像面
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertFrontPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.IDENTITY_CARD_BACK.getCode())) ?
                            fileMap2List.get(RnrFileType.IDENTITY_CARD_BACK.getCode()).get(0) : null);
            //设置责任人身份证身份证国徽面
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertBackPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.IDENTITY_CARD_FRONT.getCode())) ?
                            fileMap2List.get(RnrFileType.IDENTITY_CARD_FRONT.getCode()).get(0) : null);
        }
        //港澳居民来往内地通行证
        else if (CertTypeEnum.HKIDCARD.getCode().equalsIgnoreCase(certType)) {
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertFrontPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.HK_MACAO_PASSPORT_FRONT.getCode())) ?
                            fileMap2List.get(RnrFileType.HK_MACAO_PASSPORT_FRONT.getCode()).get(0) : null);
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertBackPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.HK_MACAO_PASSPORT_BACK.getCode())) ?
                            fileMap2List.get(RnrFileType.HK_MACAO_PASSPORT_BACK.getCode()).get(0) : null);
        }
        //护照
        else if (CertTypeEnum.PASSPORT.getCode().equalsIgnoreCase(certType)) {
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertFrontPic(
                    CollectionUtils.isNotEmpty(
                            fileMap2List.get(RnrFileType.FOREIGN_NATIONAL_PASSPORT_FRONT.getCode())) ?
                            fileMap2List.get(RnrFileType.FOREIGN_NATIONAL_PASSPORT_FRONT.getCode()).get(0) : null);
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertBackPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.FOREIGN_NATIONAL_PASSPORT_BACK.getCode())) ?
                            fileMap2List.get(RnrFileType.FOREIGN_NATIONAL_PASSPORT_BACK.getCode()).get(0) : null);
        }
        //军官证
        else if (CertTypeEnum.PLA.getCode().equalsIgnoreCase(certType)) {
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertFrontPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.OFFICIAL_CARD_FRONT.getCode())) ?
                            fileMap2List.get(RnrFileType.OFFICIAL_CARD_FRONT.getCode()).get(0) : null);
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertBackPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.OFFICIAL_CARD_BACK.getCode())) ?
                            fileMap2List.get(RnrFileType.OFFICIAL_CARD_BACK.getCode()).get(0) : null);
        }
        //警官证
        else if (CertTypeEnum.POLICEPAPER.getCode().equalsIgnoreCase(certType)) {
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertFrontPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.POLICE_CARD_FRONT.getCode())) ?
                            fileMap2List.get(RnrFileType.POLICE_CARD_FRONT.getCode()).get(0) : null);
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertBackPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.POLICE_CARD_BACK.getCode())) ?
                            fileMap2List.get(RnrFileType.POLICE_CARD_BACK.getCode()).get(0) : null);
        }
        //台湾居民来往大陆通行证
        else if (CertTypeEnum.TAIBAOZHENG.getCode().equalsIgnoreCase(certType)) {
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertFrontPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.TAIWAN_CARD_FRONT.getCode())) ?
                            fileMap2List.get(RnrFileType.TAIWAN_CARD_FRONT.getCode()).get(0) : null);
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertBackPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.TAIWAN_CARD_BACK.getCode())) ?
                            fileMap2List.get(RnrFileType.TAIWAN_CARD_BACK.getCode()).get(0) : null);
        }
        //港澳居民居住证
        else if (CertTypeEnum.HKRESIDENCECARD.getCode().equalsIgnoreCase(certType)) {
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertFrontPic(
                    CollectionUtils.isNotEmpty(
                            fileMap2List.get(RnrFileType.HK_MACAO_RESIDENCE_PERMIT_FRONT.getCode())) ?
                            fileMap2List.get(RnrFileType.HK_MACAO_RESIDENCE_PERMIT_FRONT.getCode()).get(0) : null);
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertBackPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.HK_MACAO_RESIDENCE_PERMIT_BACK.getCode())) ?
                            fileMap2List.get(RnrFileType.HK_MACAO_RESIDENCE_PERMIT_BACK.getCode()).get(0) : null);
        }
        //台湾居民居住证
        else if (CertTypeEnum.TWRESIDENCECARD.getCode().equalsIgnoreCase(certType)) {
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertFrontPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.TAIWAN_RESIDENCE_PERMIT_FRONT.getCode())) ?
                            fileMap2List.get(RnrFileType.TAIWAN_RESIDENCE_PERMIT_FRONT.getCode()).get(0) : null);
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertBackPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.TAIWAN_RESIDENCE_PERMIT_BACK.getCode())) ?
                            fileMap2List.get(RnrFileType.TAIWAN_RESIDENCE_PERMIT_BACK.getCode()).get(0) : null);
        }
        //事业代为法人证书或社会团体法人证书，
        // SOCIAL_ORG_LEGAL_PERSON_CERT("3", "事业代为法人证书或社会团体法人证书", false, ENTERPRISE_AUTH_FILE),
        //对应RnrFileType类的ENTERPRISE_AUTH_FILE，可上传3张，但提交时只存了两张，可以get(1)
        else if (CertTypeEnum.SOCIAL_ORG_LEGAL_PERSON_CERT.getCode().equalsIgnoreCase(certType)) {
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertFrontPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.ENTERPRISE_AUTH_FILE.getCode())) ?
                            fileMap2List.get(RnrFileType.ENTERPRISE_AUTH_FILE.getCode()).get(0) : null);
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertBackPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.ENTERPRISE_AUTH_FILE.getCode())) ?
                            fileMap2List.get(RnrFileType.ENTERPRISE_AUTH_FILE.getCode()).get(0) : null);
        }
        //户口簿
        else if (CertTypeEnum.RESIDENCE.getCode().equalsIgnoreCase(certType)) {
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertFrontPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.RESIDENCE_BOOKLET_FRONT.getCode())) ?
                            fileMap2List.get(RnrFileType.RESIDENCE_BOOKLET_FRONT.getCode()).get(0) : null);
            enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertBackPic(
                    CollectionUtils.isNotEmpty(fileMap2List.get(RnrFileType.RESIDENCE_BOOKLET_BACK.getCode())) ?
                            fileMap2List.get(RnrFileType.RESIDENCE_BOOKLET_BACK.getCode()).get(0) : null);
        }
        //其他证件
        else if (CertTypeEnum.OTHER.getCode().equalsIgnoreCase(certType)) {
			List<MgRnrFileDTO> fileDTOS = fileMap2List.get(RnrFileType.OTHER.getCode());
			if (!CollectionUtils.isEmpty(fileDTOS)) {
				for (int i =0 ;i<fileDTOS.size();i++){
					MgRnrFileDTO fileDTO = fileDTOS.get(i);
					if (i == 0) {
						enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertFrontPic(fileDTO);
					} else {
						enterpriseVerifyDetailDTO.getCorporationInfoDetail().setCorporationCertBackPic(fileDTO);
					}
				}
			}

        }

        //认证结果信息
        MgRnrAuthenticationResultDTO bean = new MgRnrAuthenticationResultDTO();
        bean.setRnrId(rnrOrderDetails.getRnrId());
        List<MgRnrAuthenticationResultDTO> authenticationResultDTOS =
                iMgRnrAuthenticationResultService.queryByList(bean);
        if (CollectionUtils.isNotEmpty(authenticationResultDTOS)) {
            List<EnterpriseVerifyDetailDTO.AuthResult> authResultInfo =
                    new ArrayList<>(authenticationResultDTOS.size());
            authenticationResultDTOS.forEach(authResultDTO -> {
                EnterpriseVerifyDetailDTO.AuthResult authResult = new EnterpriseVerifyDetailDTO.AuthResult();
                authResult.setTpAction(authResultDTO.getAuthWayType());
                authResult.setTpActionName(AuthWayTypeEnum.getEnumByCode(authResultDTO.getAuthWayType()).getName());
                authResult.setMessage(authResultDTO.getAuthResultMsg());
                //实名认证结果，1-成功，其他-失败
                authResult.setSuccess("1".equals(authResultDTO.getAuthResult()) ? true : false);
                authResultInfo.add(authResult);
            });
            enterpriseVerifyDetailDTO.setAuthResultInfo(authResultInfo);
        }

        //审核信息
        UserDTO userDTO = new UserDTO();
        userDTO.setUuid(rnrOrderDTO.getUserId());
        userDTO.setApplicationId(rnrOrderDTO.getApplicationId());
        userDTO.setTenantNo(rnrOrderDTO.getTenantNo());
        Response<UserDTO> userDTOResponse = userClient.getByUuid(userDTO);
        UserDTO user = userDTOResponse.getData();
        log.info("审核人的信息返参:{}", JSON.toJSONString(user));
        if (userDTOResponse == null || user == null) {
            return Response.createError("审核人不能为空");
        }
        //前端自己显示审核用户
        enterpriseVerifyDetailDTO.getVerifyMsg().setReviewer(user.getUserName());
        enterpriseVerifyDetailDTO.getVerifyMsg().setReviewDate
                (DateTimeFormatter.ofPattern("yyyy-MM-dd").format(LocalDate.now()));
        //设置审核意见复选框
        enterpriseVerifyDetailDTO.getVerifyMsg().setVerifyComments(
                Arrays.stream(rnrOrderDetails.getVerifyComments().split(",")).collect(Collectors.toList()));
        //其他审核意见
        enterpriseVerifyDetailDTO.getVerifyMsg().setOtherComments(rnrOrderDetails.getComment());
        enterpriseVerifyDetailDTO.getVerifyMsg().setOrderStatus(rnrOrderDetails.getOrderStatus());
        log.warn("enterpriseVerifyDetailDTO回参{}",JSON.toJSON(enterpriseVerifyDetailDTO));
        return Response.createSuccess(enterpriseVerifyDetailDTO);
    }
}
