package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.mg.constants.RnrFileType;
import com.cusc.nirvana.user.rnr.mg.constants.RnrOrderType;
import com.cusc.nirvana.user.rnr.mg.constants.RnrStatus;
import com.cusc.nirvana.user.rnr.mg.dto.*;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Slf4j
@Service
public class LocalChangeEnterpriseRnrPersonService {

    @Autowired
    private RnrOrderServiceImpl rnrOrderService;
    @Autowired
    private MgRnrCompanyInfoServiceImpl mgRnrCompanyInfoService;
    @Autowired
    private MgRnrInfoServiceImpl mgRnrInfoService;
    @Autowired
    private MgRnrFileServiceImpl mgRnrFileService;

    /**
     * 企业负责人变更审核详情
     *
     * @param uuid rnr_order的业务主键
     * @return
     */
    public Response<CompanyCorporationChangeRespDTO> enterpriseRnrPersonDetail(String uuid) {
        CompanyCorporationChangeRespDTO rs = new CompanyCorporationChangeRespDTO();
        //工单信息实体类
        RnrOrderDTO queryBean = new RnrOrderDTO();
        queryBean.setUuid(uuid);
        RnrOrderDTO rnrOrderDTO = rnrOrderService.getByUuid(queryBean);
        if (null == rnrOrderDTO) {
            rs.setErrorCode(10001);
            rs.setErrorMsg("未查询到相关工单信息");
            return Response.createError(rs.getErrorMsg(), rs.getErrorCode(), rs);
        } else {
            CompanyCorporationChangeRespDTO.OrderDto orderDto = new CompanyCorporationChangeRespDTO.OrderDto();
            //业务类型
            RnrOrderType rnrOrderType = RnrOrderType.getTypeByCode(rnrOrderDTO.getOrderType());
            orderDto.setOrderType(rnrOrderType.getComment());
            //经销商名称
            String organName = rnrOrderService.getOrganNameForOrgId(rnrOrderDTO.getOrgId());
            orderDto.setOrganName(organName);
            //车企名称
            MgRnrCompanyInfoDTO bean2 = new MgRnrCompanyInfoDTO();
            bean2.setRnrId(rnrOrderDTO.getRnrId());
            MgRnrCompanyInfoDTO mgRnrCompanyInfoDTO = mgRnrCompanyInfoService.getByRnrid(bean2);
            orderDto.setCompanyName(mgRnrCompanyInfoDTO.getCompanyName());
            //实名日期
            MgRnrInfoDTO bean3 = new MgRnrInfoDTO();
            bean3.setUuid(rnrOrderDTO.getUuid());
            MgRnrInfoDTO mgRnrInfoDTO = mgRnrInfoService.getByUuid(bean3);
            orderDto.setUpdateTime(mgRnrInfoDTO.getUpdateTime());
            orderDto.setOrderStatus(rnrOrderDTO.getOrderStatus());
            rs.setOrderDto(orderDto);
        }
        //原企业和责任人信息
        MgRnrInfoDTO queryBean2 = new MgRnrInfoDTO();
        queryBean2.setTenantNo(rnrOrderDTO.getTenantNo());
        queryBean2.setRnrStatus(RnrStatus.RNR.getCode());
        queryBean2.setCompanyName(rs.getOrderDto().getCompanyName());
        List<MgRnrInfoDTO> mgRnrInfoDTOList = mgRnrInfoService.queryByList(queryBean2);
        if (mgRnrInfoDTOList.size() <= 0) {
            rs.setErrorCode(10002);
            rs.setErrorMsg("未查询到原企业和责任人信息");
            return Response.createError(rs.getErrorMsg(), rs.getErrorCode(), rs);
        } else {
            CompanyCorporationChangeRespDTO.OldMgRnrInfoDto oldMgRnrInfoDto =
                    new CompanyCorporationChangeRespDTO.OldMgRnrInfoDto();
            MgRnrInfoDTO mgRnrInfoDTO = mgRnrInfoDTOList.get(0);
            oldMgRnrInfoDto.setFullName(mgRnrInfoDTO.getFullName());
            oldMgRnrInfoDto.setCompanyName(mgRnrInfoDTO.getCompanyName());
            rs.setOldMgRnrInfoDto(oldMgRnrInfoDto);
        }

        //图片相关
        MgRnrFileDTO bean = new MgRnrFileDTO();
        bean.setRnrId(rnrOrderDTO.getUuid());
        bean.setTenantNo(rnrOrderDTO.getTenantNo());
        List<MgRnrFileDTO> mgRnrFileDTOList = mgRnrFileService.getByRnrid(bean);
        bean.setTenantNo(rnrOrderDTO.getTenantNo());
        if (mgRnrFileDTOList.size() < 0) {
            rs.setErrorCode(10003);
            rs.setErrorMsg("新责任人信息查不到证件信息");
            return Response.createError(rs.getErrorMsg(), rs.getErrorCode(), rs);
        }
        mgRnrFileDTOList.forEach(mgRnrFileDTO -> {
            try {
                //base64与url不同时返回，url放在base64里
                if (StringUtils.isNotBlank(mgRnrFileDTO.getFileSystemId())) {
                    //todo 此处去掉了minio
                    //mgRnrFileDTO.setFileBase64(MinIOUtils.getPresignedObjectUrl(minIOConfig.getBucketName(), mgRnrFileDTO.getFileSystemId()));
                }
            } catch (Exception e) {
                log.error("---根据FileSystemId获取文件url失败mgRnrFileDTO：{}", mgRnrFileDTO);
                log.error("---根据FileSystemId获取文件url失败Exception：{}", e);
            }
        });
        //新责任人信息
        MgRnrInfoDTO queryBean3 = new MgRnrInfoDTO();
        queryBean3.setUuid(rnrOrderDTO.getUuid());
        MgRnrInfoDTO mgRnrInfoDTO = mgRnrInfoService.getByUuid(queryBean3);
        if (null == mgRnrInfoDTO) {
            rs.setErrorCode(10004);
            rs.setErrorMsg("未查询到新责任人信息");
            return Response.createError(rs.getErrorMsg(), rs.getErrorCode(), rs);
        } else {
            CompanyCorporationChangeRespDTO.NewMgRnrInfoDto newMgRnrInfoDto =
                    new CompanyCorporationChangeRespDTO.NewMgRnrInfoDto();
            newMgRnrInfoDto.setFullName(mgRnrInfoDTO.getFullName());
            newMgRnrInfoDto.setGender(mgRnrInfoDTO.getGender());
            newMgRnrInfoDto.setCertType(mgRnrInfoDTO.getCertType());
            newMgRnrInfoDto.setCertNumber(mgRnrInfoDTO.getCertNumber());
            newMgRnrInfoDto.setExpiredDate(mgRnrInfoDTO.getExpiredDate());
            newMgRnrInfoDto.setCertAddress(mgRnrInfoDTO.getCertAddress());
            newMgRnrInfoDto.setPhone(mgRnrInfoDTO.getPhone());
            newMgRnrInfoDto.setContactAddress(mgRnrInfoDTO.getContactAddress());

            for (MgRnrFileDTO mf : mgRnrFileDTOList) {
                if (mf.getFileType().equals(RnrFileType.IDENTITY_CARD_BACK.getCode())) {
                    //身份证人像面
                    newMgRnrInfoDto.setIdentityCardBackForUuId(mf.getFileBase64());
                } else if (mf.getFileType().equals(RnrFileType.IDENTITY_CARD_FRONT.getCode())) {
                    //身份证国徽面
                    newMgRnrInfoDto.setIdentityCardFrontForUuId(mf.getFileBase64());
                }
            }
            if (StringUtils.isEmpty(newMgRnrInfoDto.getIdentityCardBackForUuId())
                    || StringUtils.isEmpty(newMgRnrInfoDto.getIdentityCardFrontForUuId())) {
                rs.setErrorCode(10005);
                rs.setErrorMsg("新责任人信息证件信息不齐");
                return Response.createError(rs.getErrorMsg(), rs.getErrorCode(), rs);
            }
            rs.setNewMgRnrInfoDto(newMgRnrInfoDto);
        }

        for (MgRnrFileDTO mf : mgRnrFileDTOList) {
            if (mf.getFileType().equals(RnrFileType.ENTERPRISE_AUTH_FILE.getCode())) {
                //企业实名认证授权书
                rs.setEnterpriseAuthFileForUuId(mf.getFileBase64());
            } else if (mf.getFileType().equals(RnrFileType.LIVENESS_SCREEN_FIRST.getCode())) {
                //活体截图1
                rs.setLivenessScreenFirstForUuId(mf.getFileBase64());
            } else if (mf.getFileType().equals(RnrFileType.LIVENESS_VIDEO.getCode())) {
                //活体视频
                rs.setLivenessVideoForUuId(mf.getFileBase64());
            }
        }
        if (StringUtils.isEmpty(rs.getEnterpriseAuthFileForUuId())) {
            rs.setErrorCode(10005);
            rs.setErrorMsg("授权书信息有误");
            return Response.createError(rs.getErrorMsg(), rs.getErrorCode(), rs);
        }
        if (StringUtils.isEmpty(rs.getLivenessScreenFirstForUuId())
                || StringUtils.isEmpty(rs.getLivenessVideoForUuId())) {
            rs.setErrorCode(10005);
            rs.setErrorMsg("证件信息不齐");
            return Response.createError(rs.getErrorMsg(), rs.getErrorCode(), rs);
        }
        return Response.createSuccess(rs);
    }


}
