package com.cusc.nirvana.user.rnr.mg.service.impl;

import cn.hutool.crypto.SmUtil;
import cn.hutool.crypto.symmetric.SymmetricCrypto;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.cusc.nirvana.common.loader.CollectionUtils;
import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.eiam.client.UserClient;
import com.cusc.nirvana.user.eiam.dto.UserDTO;
import com.cusc.nirvana.user.rnr.mg.constants.AuthWayTypeEnum;
import com.cusc.nirvana.user.rnr.mg.constants.CertTypeEnum;
import com.cusc.nirvana.user.rnr.mg.constants.GenderEnum;
import com.cusc.nirvana.user.rnr.mg.constants.PassCodeEnum;
import com.cusc.nirvana.user.rnr.mg.constants.RnrFileType;
import com.cusc.nirvana.user.rnr.mg.constants.RnrOrderStatusEnum;
import com.cusc.nirvana.user.rnr.mg.constants.RnrOrderType;
import com.cusc.nirvana.user.rnr.mg.constants.RnrStatus;
import com.cusc.nirvana.user.rnr.mg.constants.SubjectTypeEnum;
import com.cusc.nirvana.user.rnr.mg.converter.MgRnrCompanyInfoConverter;
import com.cusc.nirvana.user.rnr.mg.converter.MgRnrImageConverter;
import com.cusc.nirvana.user.rnr.mg.converter.MgRnrInfoConverter;
import com.cusc.nirvana.user.rnr.mg.converter.MgRnrLiaisonInfoConverter;
import com.cusc.nirvana.user.rnr.mg.converter.RnrOrderConverter;
import com.cusc.nirvana.user.rnr.mg.dao.RnrOrderDao;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrCardInfoPO;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrCompanyInfoPO;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrFilePO;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrInfoPO;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrLiaisonInfoPO;
import com.cusc.nirvana.user.rnr.mg.dao.entity.RnrOrderPO;
import com.cusc.nirvana.user.rnr.mg.dto.EnterpriseVerifyDetailDTO;
import com.cusc.nirvana.user.rnr.mg.dto.LocalVerifyListDTO;
import com.cusc.nirvana.user.rnr.mg.dto.LocalVerifyListRqDTO;
import com.cusc.nirvana.user.rnr.mg.dto.LocalVerifyPersonDetailDTO;
import com.cusc.nirvana.user.rnr.mg.dto.LocalVerifySubmitRq;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrAuthenticationResultDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrCardInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrCompanyInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrFileDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrLiaisonInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.RnrOrderDTO;
import com.cusc.nirvana.user.rnr.mg.dto.RnrRelationDTO;
import com.cusc.nirvana.user.rnr.mg.service.IFileService;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrAuthenticationResultService;
import com.cusc.nirvana.user.rnr.mg.util.DateUtil;
import com.cusc.nirvana.user.rnr.workorder.constants.WorkOrderTypeEnum;
import com.cusc.nirvana.user.rnr.workorder.dto.WorkOrderReviewCallBackRequestDTO;
import com.cusc.nirvana.user.rnr.workorder.handler.impl.EnterpriseChangeCallBackHandler;
import com.cusc.nirvana.user.rnr.workorder.handler.impl.ManufacturerRnrCallBackHandler;
import com.cusc.nirvana.user.rnr.workorder.handler.impl.RnrWorkOrderCallBackHandler;
import com.cusc.nirvana.user.rnr.workorder.handler.impl.UnbindWorkOrderCallBackHandler;
import com.cusc.nirvana.user.util.CuscStringUtils;
import com.cusc.nirvana.user.util.crypt.CryptKeyUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.Date;
import java.util.HashSet;
import java.util.LinkedHashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

@Slf4j
@Service
public class LocalVerifyService {
    @Autowired
    NotifyCloudService notifyCloudService;
    @Autowired
    RnrOrderServiceImpl rnrOrderService;
    @Autowired
    RnrOrderDao rnrOrderDao;
    @Autowired
    MgRnrInfoServiceImpl mgRnrInfoService;
    @Autowired
    MgRnrCardInfoServiceImpl mgRnrCardInfoService;
    @Autowired
    MgRnrCompanyInfoServiceImpl mgRnrCompanyInfoService;
    @Autowired
    MgRnrFileServiceImpl mgRnrFileService;
    @Autowired
    MgRnrLiaisonInfoServiceImpl mgRnrLiaisonInfoService;
    @Autowired
    ManufacturerRnrCallBackHandler manufacturerRnrCallBackHandler;
    @Autowired
    UnbindWorkOrderCallBackHandler unbindWorkOrderCallBackHandler;
    @Autowired
    RnrWorkOrderCallBackHandler rnrWorkOrderCallBackHandler;
    @Autowired
    EnterpriseChangeCallBackHandler enterpriseChangeCallBackHandler;

    @Resource
    private IFileService fileService;

    @Autowired
    private UserClient userClient;
    @Autowired
    private IMgRnrAuthenticationResultService iMgRnrAuthenticationResultService;


    /**
     * 自然人关联文件类型集合
     */
    private static Set<Integer> NPFileTypeSet = new HashSet<>();


    static {
        NPFileTypeSet.add(RnrFileType.IDENTITY_CARD_BACK.getCode());
        NPFileTypeSet.add(RnrFileType.IDENTITY_CARD_FRONT.getCode());
        NPFileTypeSet.add(RnrFileType.POLICE_CARD_FRONT.getCode());
        NPFileTypeSet.add(RnrFileType.POLICE_CARD_BACK.getCode());
        NPFileTypeSet.add(RnrFileType.HK_MACAO_PASSPORT_FRONT.getCode());
        NPFileTypeSet.add(RnrFileType.HK_MACAO_PASSPORT_BACK.getCode());
        NPFileTypeSet.add(RnrFileType.TAIWAN_CARD_FRONT.getCode());
        NPFileTypeSet.add(RnrFileType.TAIWAN_CARD_BACK.getCode());
        NPFileTypeSet.add(RnrFileType.FOREIGN_NATIONAL_PASSPORT_FRONT.getCode());
        NPFileTypeSet.add(RnrFileType.FOREIGN_NATIONAL_PASSPORT_BACK.getCode());
        NPFileTypeSet.add(RnrFileType.HK_MACAO_RESIDENCE_PERMIT_FRONT.getCode());
        NPFileTypeSet.add(RnrFileType.HK_MACAO_RESIDENCE_PERMIT_BACK.getCode());
        NPFileTypeSet.add(RnrFileType.TAIWAN_RESIDENCE_PERMIT_FRONT.getCode());
        NPFileTypeSet.add(RnrFileType.TAIWAN_RESIDENCE_PERMIT_BACK.getCode());
        NPFileTypeSet.add(RnrFileType.RESIDENCE_BOOKLET_FRONT.getCode());
        NPFileTypeSet.add(RnrFileType.RESIDENCE_BOOKLET_BACK.getCode());
        NPFileTypeSet.add(RnrFileType.OFFICIAL_CARD_FRONT.getCode());
        NPFileTypeSet.add(RnrFileType.OFFICIAL_CARD_BACK.getCode());
        NPFileTypeSet.add(RnrFileType.OTHER.getCode());
    }

    public Response<PageResult<LocalVerifyListDTO>> orderList(LocalVerifyListRqDTO rq) {
        PageResult pageResult = new PageResult();
        if (StringUtils.isNotBlank(rq.getVin())) {
            rq.setVin(CryptKeyUtil.encryptToBase64(rq.getVin()));
        }
        if (StringUtils.isNotBlank(rq.getIccid())) {
            rq.setIccid(CryptKeyUtil.encryptToBase64(rq.getIccid()));
        }
        if (StringUtils.isNotBlank(rq.getVinOwnerName())) {
            rq.setVinOwnerName("%" + CryptKeyUtil.encryptToBase64(rq.getVinOwnerName()) + "%");
        }
        if (StringUtils.isNotBlank(rq.getVinOwnerPhone())) {
            rq.setVinOwnerPhone("%" + CryptKeyUtil.encryptToBase64(rq.getVinOwnerPhone()) + "%");
        }
        if (StringUtils.isNotBlank(rq.getVinCompanyName())) {
            rq.setVinCompanyName("%" + CryptKeyUtil.encryptToBase64(rq.getVinCompanyName()) + "%");
        }
        if (StringUtils.isNotBlank(rq.getOrgName())) {
            rq.setOrgName("%" + CryptKeyUtil.encryptToBase64(rq.getOrgName()) + "%");
        }
        Integer total = rnrOrderService.orderTotal(rq);
        List<LocalVerifyListDTO> datas = rnrOrderService.orderList(rq);
        if (!CollectionUtils.isEmpty(datas)) {
            for (LocalVerifyListDTO data : datas) {
                if (null != data) {
                    //data.setVin(CryptKeyUtil.decryptByBase64(data.getVin()));
                    //一平sql用，拼的，多个iccid时不能直接解密
                    if (data.getIccid().contains(",")) {
                        List<String> iccids = new LinkedList<>();
                        for (String iccid : data.getIccid().split(",")) {
                            iccids.add(CryptKeyUtil.decryptByBase64(iccid));
                        }
                        data.setIccid(StringUtils.join(iccids, ","));
                    } else {
                        data.setIccid(CryptKeyUtil.decryptByBase64(data.getIccid()));
                    }

                    if (data.getVin().contains(",")) {
                        List<String> vinList = new LinkedList<>();
                        for (String vin : data.getVin().split(",")) {
                            vinList.add(CryptKeyUtil.decryptByBase64(vin));
                        }
                        data.setVin(StringUtils.join(vinList, ","));
                    } else {
                        data.setVin(CryptKeyUtil.decryptByBase64(data.getVin()));
                    }

                    data.setOrderTypeName(
                            RnrOrderType.getTypeByCode(Integer.valueOf(data.getOrderType())).getComment());
                    data.setVinOwnerName(CryptKeyUtil.decryptByBase64(data.getVinOwnerName()));
                    data.setVinOwnerPhone(CryptKeyUtil.decryptByBase64(data.getVinOwnerPhone()));
                    data.setVinCompanyName(CryptKeyUtil.decryptByBase64(data.getVinCompanyName()));
                }
            }
        }

        pageResult.setCurrPage(rq.getCurrPage());
        pageResult.setPageSize(rq.getPageSize());
        pageResult.setTotalCount(total);
        pageResult.setList(datas);
        return Response.createSuccess(pageResult);
    }

    public Response<LocalVerifyPersonDetailDTO> personDetail(LocalVerifyListRqDTO rq) {

        RnrOrderPO rnrOrderPO =
                rnrOrderService.getOne(new QueryWrapper<RnrOrderPO>().eq("uuid", rq.getRnrOrderInfoId()));
        if (null == rnrOrderPO) {
            return Response.createError("工单不存在");
        }

        MgRnrInfoPO mgRnrInfoPO =
                mgRnrInfoService.getOne(new QueryWrapper<MgRnrInfoPO>().eq("uuid", rnrOrderPO.getRnrId()));
        if (null == mgRnrInfoPO) {
            return Response.createError("工单详情不存在");
        }

        List<MgRnrCardInfoPO> mgRnrCardInfoPOS =
                mgRnrCardInfoService.list(new QueryWrapper<MgRnrCardInfoPO>().eq("rnr_id", rnrOrderPO.getRnrId()));
        if (null == mgRnrInfoPO || mgRnrCardInfoPOS.size() == 0) {
            return Response.createError("实名信息不存在");
        }

        String companyName = "";
        List<MgRnrCompanyInfoPO> mgRnrCompanyInfoPOS = mgRnrCompanyInfoService.list(
                new QueryWrapper<MgRnrCompanyInfoPO>().eq("rnr_id", rnrOrderPO.getRnrId()));
        if (null != mgRnrCompanyInfoPOS && mgRnrCompanyInfoPOS.size() != 0) {
            companyName = mgRnrCompanyInfoPOS.get(0).getCompanyName();
        }

        List<MgRnrFilePO> mgRnrFilePOS =
                mgRnrFileService.getPoByRnridOrderByOrderno(mgRnrInfoPO.getUuid(), mgRnrInfoPO.getTenantNo());
        if (CollectionUtils.isNotEmpty(mgRnrFilePOS)) {
            mgRnrFilePOS.forEach(mgRnrFileDTO -> {
                try {
                    //活体认证视频，视频返回url
                    //base64与url不同时返回，url放在base64里
                    if (RnrFileType.LIVENESS_VIDEO.getCode().intValue() == mgRnrFileDTO.getFileType()
                            && StringUtils.isNotBlank(mgRnrFileDTO.getFileSystemId())) {
                       /* String objectUrl = null;
                        if (FIleSystemType.OSS.getCode().equals(fileSelect)) {
                            objectUrl = OSSUtil.getFileUrl(ossConfig.getBucketName(),
                                    ossConfig.getPrefix() + mgRnrFileDTO.getFileSystemId());
                        } else {
                            throw new CuscUserException(fileSelect, "未知文件系统");
                        }*/

                        String fileUrl = fileService.getFileUrl(mgRnrFileDTO.getFileSystemId());
                        mgRnrFileDTO.setFileSystemId(fileUrl);
                    }
                } catch (Exception e) {
                    log.error("---根据FileSystemId获取文件url失败mgRnrFileDTO：{}", mgRnrFileDTO);
                    log.error("---根据FileSystemId获取文件url失败Exception：{}", e);
                }
            });
        }

        String orgname = rnrOrderDao.getOrgnameById(mgRnrInfoPO.getOrgId());

        LocalVerifyPersonDetailDTO localVerifyPersonDetailDTO = new LocalVerifyPersonDetailDTO();

        //工单信息
        localVerifyPersonDetailDTO.setRnrOrderDetail(new LocalVerifyPersonDetailDTO.RnrOrderDetail(
                orgname, companyName,
                RnrOrderType.getTypeByCode(Integer.valueOf(rnrOrderPO.getOrderType())).getComment(),
                DateUtil.toString(rnrOrderPO.getCreateTime(), DateUtil.yyyy_MM_dd_HH_mm_ss)));

        //车卡信息
        ArrayList<LocalVerifyPersonDetailDTO.VinCardMsg> vinCardMsgs = new ArrayList<>();
        for (MgRnrCardInfoPO mgRnrCardInfoPO : mgRnrCardInfoPOS) {
            vinCardMsgs.add(new LocalVerifyPersonDetailDTO.VinCardMsg(
                    mgRnrCardInfoPO.getIotId(), mgRnrCardInfoPO.getIccid(),
                    RnrStatus.getEnumByCode(mgRnrCardInfoPO.getRnrStatus()).getComment()));
        }
        localVerifyPersonDetailDTO.setVinCardMsg(vinCardMsgs);
        //车主信息

        localVerifyPersonDetailDTO.setVinOwnerMsg(new LocalVerifyPersonDetailDTO.PersonMsg(
                mgRnrInfoPO.getFullName(), GenderEnum.findByCode(mgRnrInfoPO.getGender()).getName(),
                CertTypeEnum.getEnumByCode(mgRnrInfoPO.getCertType()).getName(),
                "", "", mgRnrInfoPO.getCertNumber(),
                mgRnrInfoPO.getExpiredDate(),
                mgRnrInfoPO.getCertAddress(), mgRnrInfoPO.getPhone(), mgRnrInfoPO.getContactAddress()
        ));
       /* for (MgRnrFilePO mgRnrFilePO : mgRnrFilePOS) {
            //是0，为自然人的证件信息，不是0为代办人证件信息
            if (StringUtils.isNotBlank(mgRnrFilePO.getLiaisonId()) && "0".equals(mgRnrFilePO.getLiaisonId()) && -1
            !=RnrFileType.getIdImageFace().indexOf(mgRnrFilePO.getFileType())) {
                localVerifyPersonDetailDTO.getVinOwnerMsg().setIdImageFace(mgRnrFilePO.getFileSystemId());
            } else if (StringUtils.isNotBlank(mgRnrFilePO.getLiaisonId()) && "0".equals(mgRnrFilePO.getLiaisonId())
            &&-1 !=RnrFileType.getIdImageEmblem().indexOf(mgRnrFilePO.getFileType()) ) {
                localVerifyPersonDetailDTO.getVinOwnerMsg().setIdImageEmblem(mgRnrFilePO.getFileSystemId());
            }
        }*/
        //车主展示文件
        List<MgRnrFilePO> ownerFileList = mgRnrFilePOS.stream().filter(file ->
                StringUtils.isNotBlank(file.getLiaisonId()) && "0".equals(file.getLiaisonId())
                        && NPFileTypeSet.contains(file.getFileType())
        ).sorted(Comparator.comparing(MgRnrFilePO::getFileType)).collect(Collectors.toList());

        for (int i = 0; i < ownerFileList.size(); i++) {
            MgRnrFilePO mgRnrFilePO = ownerFileList.get(i);
            if (i == 0) {
                localVerifyPersonDetailDTO.getVinOwnerMsg().setIdImageFace(mgRnrFilePO.getFileSystemId());
            } else {
                localVerifyPersonDetailDTO.getVinOwnerMsg().setIdImageEmblem(mgRnrFilePO.getFileSystemId());
            }
        }

        //代办人信息
        if (1 == mgRnrInfoPO.getIsTrust()) {
            MgRnrLiaisonInfoPO mgRnrLiaisonInfoPO = mgRnrLiaisonInfoService.getPoByRnrid(mgRnrInfoPO.getUuid());
            localVerifyPersonDetailDTO.setVinLiaisonMsg(new LocalVerifyPersonDetailDTO.PersonMsg(
                    mgRnrLiaisonInfoPO.getLiaisonName(),
                    GenderEnum.findByCode(mgRnrLiaisonInfoPO.getLiaisonGender()).getName(),
                    CertTypeEnum.getEnumByCode(mgRnrLiaisonInfoPO.getLiaisonCertType()).getName(),
                    "", "", mgRnrLiaisonInfoPO.getLiaisonCertNumber(),
                    mgRnrLiaisonInfoPO.getLiaisonExpiredDate(),
                    mgRnrLiaisonInfoPO.getLiaisonCertAddress(), mgRnrLiaisonInfoPO.getLiaisonPhone(),
                    mgRnrLiaisonInfoPO.getLiaisonContactAddress()
            ));

            //代办人展示文件
            List<MgRnrFilePO> liaisonFileList = mgRnrFilePOS.stream().filter(file ->
                    !"0".equals(file.getLiaisonId()) && NPFileTypeSet.contains(file.getFileType())
            ).sorted(Comparator.comparing(MgRnrFilePO::getFileType)).collect(Collectors.toList());

            for (int i = 0; i < liaisonFileList.size(); i++) {
                MgRnrFilePO liaisonFile = liaisonFileList.get(i);
                if (i == 0) {
                    localVerifyPersonDetailDTO.getVinLiaisonMsg().setIdImageFace(liaisonFile.getFileSystemId());
                } else {
                    localVerifyPersonDetailDTO.getVinLiaisonMsg().setIdImageEmblem(liaisonFile.getFileSystemId());
                }
            }


            /*for (MgRnrFilePO mgRnrFilePO : mgRnrFilePOS) {
                //不是0，为代办人的证件信息
                if (!"0".equals(mgRnrFilePO.getLiaisonId())) {
                    if (RnrFileType.IDENTITY_CARD_BACK.getCode().intValue() == mgRnrFilePO.getFileType()) {
                        localVerifyPersonDetailDTO.getVinLiaisonMsg().setIdImageFace(mgRnrFilePO.getFileSystemId());
                    } else if (RnrFileType.IDENTITY_CARD_FRONT.getCode().intValue() == mgRnrFilePO.getFileType()) {
                        localVerifyPersonDetailDTO.getVinLiaisonMsg().setIdImageEmblem(mgRnrFilePO.getFileSystemId());
                    }
                }
            }*/
        }
        //文件信息、认证信息
        localVerifyPersonDetailDTO.setVerifyFileMsg(new LocalVerifyPersonDetailDTO.VerifyFileMsg());
        for (MgRnrFilePO mgRnrFilePO : mgRnrFilePOS) {

            if (RnrFileType.LETTER_ATTORNEY.getCode().intValue() == mgRnrFilePO.getFileType()) {
                localVerifyPersonDetailDTO.getVerifyFileMsg().getAttorneyImage().add(mgRnrFilePO.getFileSystemId());
            } else if (RnrFileType.CAR_PURCHASE_INVOICE.getCode().intValue() == mgRnrFilePO.getFileType()) {
                localVerifyPersonDetailDTO.getVerifyFileMsg().getBuyBillImage().add(mgRnrFilePO.getFileSystemId());
            } else if (RnrFileType.CAR_PURCHASE_CONTRACT.getCode().intValue() == mgRnrFilePO.getFileType()) {
                localVerifyPersonDetailDTO.getVerifyFileMsg().getBuyContractImage().add(mgRnrFilePO.getFileSystemId());
            } else if (RnrFileType.CAR_TRANSFER_CERTIFICATE.getCode().intValue() == mgRnrFilePO.getFileType()) {
                localVerifyPersonDetailDTO.getVerifyFileMsg().getTransferOwnershipProveImage()
                        .add(mgRnrFilePO.getFileSystemId());
            } else if (RnrFileType.VEHUCLE_BIND.getCode().intValue() == mgRnrFilePO.getFileType()
                    || RnrFileType.DUTY_FILE.getCode().intValue() == mgRnrFilePO.getFileType()) {
                localVerifyPersonDetailDTO.getVerifyFileMsg().getNetworkAccessContractImage()
                        .add(mgRnrFilePO.getFileSystemId());
            } else if (RnrFileType.LIVENESS_SCREEN_FIRST.getCode().intValue() == mgRnrFilePO.getFileType() ||
                    RnrFileType.LIVENESS_SCREEN_TWO.getCode().intValue() == mgRnrFilePO.getFileType()) {
                localVerifyPersonDetailDTO.getVerifyLivingMsg().getFaceImage().add(mgRnrFilePO.getFileSystemId());
            } else if (RnrFileType.LIVENESS_VIDEO.getCode().intValue() == mgRnrFilePO.getFileType()) {
                localVerifyPersonDetailDTO.getVerifyLivingMsg().setLivingVideo(mgRnrFilePO.getFileSystemId());
            } else if ("0".equals(mgRnrFilePO.getLiaisonId())
                    && RnrFileType.IDENTITY_CARD_BACK.getCode().intValue() == mgRnrFilePO.getFileType()) {
                localVerifyPersonDetailDTO.getVinOwnerMsg().setIdImageFace(mgRnrFilePO.getFileSystemId());
            } else if ("0".equals(mgRnrFilePO.getLiaisonId())
                    && RnrFileType.IDENTITY_CARD_FRONT.getCode().intValue() == mgRnrFilePO.getFileType()) {
                localVerifyPersonDetailDTO.getVinOwnerMsg().setIdImageEmblem(mgRnrFilePO.getFileSystemId());
            }
        }
        //审核信息
        LinkedHashMap<String, String> verifySuggestion = new LinkedHashMap<>();
        verifySuggestion.put(PassCodeEnum.INFO_INCOMPLETE.getCode().toString(),
                PassCodeEnum.INFO_INCOMPLETE.getComment());
        verifySuggestion.put(PassCodeEnum.INFO_ATYPISM.getCode().toString(), PassCodeEnum.INFO_ATYPISM.getComment());
        verifySuggestion.put(PassCodeEnum.INFO_NOT_FOUND.getCode().toString(),
                PassCodeEnum.INFO_NOT_FOUND.getComment());
        verifySuggestion.put(PassCodeEnum.PIC_FORMAT_ERROR.getCode().toString(),
                PassCodeEnum.PIC_FORMAT_ERROR.getComment());
        verifySuggestion.put(PassCodeEnum.PIC_BLURRING.getCode().toString(), PassCodeEnum.PIC_BLURRING.getComment());

        //认证结果信息
        MgRnrAuthenticationResultDTO bean = new MgRnrAuthenticationResultDTO();
        bean.setRnrId(rnrOrderPO.getRnrId());
        List<MgRnrAuthenticationResultDTO> authenticationResultDTOS =
                iMgRnrAuthenticationResultService.queryByList(bean);
        if (CollectionUtils.isNotEmpty(authenticationResultDTOS)) {
            List<EnterpriseVerifyDetailDTO.AuthResult> authResultInfo =
                    new ArrayList<>(authenticationResultDTOS.size());

            List<EnterpriseVerifyDetailDTO.AuthResult> liaisonResultInfo =
                    new ArrayList<>(authenticationResultDTOS.size());

            authenticationResultDTOS.forEach(authResultDTO -> {
                EnterpriseVerifyDetailDTO.AuthResult authResult = new EnterpriseVerifyDetailDTO.AuthResult();
                authResult.setTpAction(authResultDTO.getAuthWayType());
                authResult.setTpActionName(AuthWayTypeEnum.getEnumByCode(authResultDTO.getAuthWayType()).getName());
                authResult.setMessage(authResultDTO.getAuthResultMsg());
                //实名认证结果，1-成功，其他-失败
                authResult.setSuccess("1".equals(authResultDTO.getAuthResult()) ? true : false);
                if (SubjectTypeEnum.ONESELF.getCode().equals(authResultDTO.getSubjectType())) {
                    authResultInfo.add(authResult);
                } else {
                    liaisonResultInfo.add(authResult);
                }
            });
            localVerifyPersonDetailDTO.setAuthResultInfo(authResultInfo);
            localVerifyPersonDetailDTO.setLiaisonAuthResultInfo(liaisonResultInfo);
        }

        //审核信息
        UserDTO userDTO = new UserDTO();
        userDTO.setUuid(rq.getUserId());
        userDTO.setApplicationId(rq.getApplicationId());
        userDTO.setTenantNo(rq.getTenantNo());
        Response<UserDTO> userDTOResponse = userClient.getByUuid(userDTO);
        UserDTO user = userDTOResponse.getData();
        log.info("审核人的信息返参:{}", JSON.toJSONString(user));
        if (userDTOResponse == null || user == null) {
            return Response.createError("审核人不能为空");
        }
        localVerifyPersonDetailDTO.setVerifyMsg(new LocalVerifyPersonDetailDTO.VerifyMsg(user.getUserName(),
                DateUtil.toString(new Date(), DateUtil.yyyy_MM_dd), verifySuggestion, rnrOrderPO.getOrderStatus()));

        return Response.createSuccess(localVerifyPersonDetailDTO);
    }

    @Transactional(rollbackFor = Throwable.class)
    public Response submit(LocalVerifySubmitRq rq) {
        RnrOrderPO rnrOrderPO = rnrOrderService.getPoByUuid(rq.getRnrOrderInfoId());
        RnrOrderType typeByCode = RnrOrderType.getTypeByCode(rnrOrderPO.getOrderType());
        WorkOrderTypeEnum workOrderTypeEnum
                = WorkOrderTypeEnum.getWorkOrderTypeEnumByRnrOrderType(typeByCode);
        WorkOrderReviewCallBackRequestDTO dto = new WorkOrderReviewCallBackRequestDTO();
        dto.setBusinessObjectId(rnrOrderPO.getUuid());
        if (RnrOrderStatusEnum.PASS.getCode().toString().equals(rq.getAuditResult())) {
            dto.setAuditResult("1");
        } else if (RnrOrderStatusEnum.NOT_PASS.getCode().toString().equals(rq.getAuditResult())) {
            dto.setAuditResult("2");
        }
        if ("rnrWorkOrderCallBackHandler".equals(workOrderTypeEnum.getWorkOrderCallBackServiceName())) {
            //人工实名认证工单、二手车实名认证工单、企业新车实名认证
            rnrWorkOrderCallBackHandler.reviewCallBack(dto);
        } else if ("manufacturerRnrCallBackHandler".equals(workOrderTypeEnum.getWorkOrderCallBackServiceName())) {
            //车企新车实名认证
            manufacturerRnrCallBackHandler.reviewCallBack(dto);
        } else if ("unbindWorkOrderCallBackHandler".equals(workOrderTypeEnum.getWorkOrderCallBackServiceName())) {
            //二手车主解绑
            unbindWorkOrderCallBackHandler.reviewCallBack(dto);
        } else if ("enterpriseChangeCallBackHandler".equals(workOrderTypeEnum.getWorkOrderCallBackServiceName())) {
            //企业责任人变更
            enterpriseChangeCallBackHandler.reviewCallBack(dto);
        }
        //更新审核用户、审核意见、备注
        //审核时间
        rnrOrderPO.setAuditTime(new Date());
        //设置操作人
        rnrOrderPO.setReviewUserId(rq.getUserId());
        //审核状态
        rnrOrderPO.setOrderStatus(Integer.parseInt(rq.getAuditResult()));
        //审核意见, 可以多选
        rnrOrderPO.setVerifyComments(StringUtils.join(rq.getAuditNote(), ","));
        //其他意见
        rnrOrderPO.setComment(rq.getOtherComments());
        rnrOrderDao.updateById(rnrOrderPO);
        //发送通知
        List<MgRnrCardInfoDTO> mgRnrCardInfoDTOS = mgRnrCardInfoService.getByRnrid(rnrOrderPO.getRnrId());
        MgRnrInfoPO mgRnrInfoPO = mgRnrInfoService.getPoByUuid(rnrOrderPO.getRnrId());
        notifyCloudService.notifyResult(mgRnrCardInfoDTOS, rnrOrderPO.getRnrBizzType().toString(),
                rnrOrderPO.getId().toString(), mgRnrInfoPO.getOrgId(), rnrOrderPO.getOrderStatus().toString());
        return Response.createSuccess("请求成功");
    }


    public Response retry(LocalVerifySubmitRq rq) {
        RnrRelationDTO rsBean = new RnrRelationDTO();
        rsBean.setRequestId(CuscStringUtils.generateUuid());
        RnrOrderPO rnrOrderPO =
                rnrOrderService.getOne(new QueryWrapper<RnrOrderPO>().eq("uuid", rq.getRnrOrderInfoId()));
        if (null == rnrOrderPO) {
            return Response.createError("工单不存在");
        } else {
            RnrOrderDTO rnrOrderDTO = RnrOrderConverter.INSTANCE.poToDto(rnrOrderPO);
            rsBean.setOrder(rnrOrderDTO);
            rsBean.setTenantNo(rnrOrderDTO.getTenantNo());
            if (rnrOrderDTO.getOrderType().equals("2")) {
                rsBean.setIsSecondHandCar(1);
            } else {
                rsBean.setIsSecondHandCar(0);
            }
        }

        //是否是委托实名 0 否   1 是
        boolean isTrust = false;

        MgRnrInfoPO mgRnrInfoPO = mgRnrInfoService.getPoByUuid(rnrOrderPO.getRnrId());
        if (null == mgRnrInfoPO) {
            return Response.createError("工单实名信息不存在");
        } else {
            MgRnrInfoDTO info = MgRnrInfoConverter.INSTANCE.poToDto(mgRnrInfoPO);
            rsBean.setInfo(info);
            rsBean.setIsTrust(info.getIsTrust());
            if (info.getIsTrust().equals("1")) {
                isTrust = true;
            }
        }

        List<MgRnrCompanyInfoPO> mgRnrCompanyInfoPOS = mgRnrCompanyInfoService.list(
                new QueryWrapper<MgRnrCompanyInfoPO>().eq("rnr_id", rnrOrderPO.getRnrId()));
        if (null != mgRnrCompanyInfoPOS && mgRnrCompanyInfoPOS.size() != 0) {
            MgRnrCompanyInfoDTO companyInfo = MgRnrCompanyInfoConverter.INSTANCE.poToDto(mgRnrCompanyInfoPOS.get(0));
        }

        //代办人信息
        if (isTrust) {
            List<MgRnrLiaisonInfoDTO> rnrLiaisonList = new ArrayList<>();
            MgRnrLiaisonInfoPO mgRnrLiaisonInfoPO = mgRnrLiaisonInfoService.getPoByRnrid(mgRnrInfoPO.getUuid());
            rnrLiaisonList.add(MgRnrLiaisonInfoConverter.INSTANCE.poToDto(mgRnrLiaisonInfoPO));
            rsBean.setRnrLiaisonList(rnrLiaisonList);
        }

        //实名文件信息
        List<MgRnrFilePO> mgRnrFilePOS =
                mgRnrFileService.getPoByRnridOrderByOrderno(mgRnrInfoPO.getUuid(), mgRnrInfoPO.getTenantNo());
        if (mgRnrFilePOS.size() > 0) {
            List<MgRnrFileDTO> rnrFileList = MgRnrImageConverter.INSTANCE.poListToDtoList(mgRnrFilePOS);
            rsBean.setRnrFileList(rnrFileList);
        }
        return Response.createSuccess(rsBean);
    }


    private static final String key = "89c0Cusc268f5A51";

    public Response validationRnrOrder(LocalVerifyListRqDTO rq) {
        SymmetricCrypto sm4 = SmUtil.sm4(key.getBytes());
        String vinEncryptStr = sm4.encryptBase64(rq.getVin());
        String iccidEncryptStr = sm4.encryptBase64(rq.getIccid());
        Integer returnInt = rnrOrderDao.validationRnrOrder(vinEncryptStr, iccidEncryptStr);
        if (returnInt > 0) {
            return Response.createSuccess();
        } else {
            return Response.createError();
        }
    }
}
