package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cusc.nirvana.user.rnr.mg.converter.MgRnrAuthenticationResultConverter;
import com.cusc.nirvana.user.rnr.mg.dao.MgRnrAuthenticationResultDao;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrAuthenticationResultPO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrAuthenticationResultDTO;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrAuthenticationResultService;
import com.cusc.nirvana.user.util.CuscStringUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 实名认证结果(MgRnrAuthenticationResult)表服务实现类
 *
 * @author yuy336
 * @since 2022-05-19 17:36:05
 */
@Service
public class MgRnrAuthenticationResultServiceImpl extends ServiceImpl<MgRnrAuthenticationResultDao, MgRnrAuthenticationResultPO> implements IMgRnrAuthenticationResultService {

    /**
     * 通过UUID查询单条数据
     *
     * @param bean
     * @return 实例对象
     */
    @Override
    public MgRnrAuthenticationResultDTO getByUuid(MgRnrAuthenticationResultDTO bean) {
        MgRnrAuthenticationResultPO record = this.getPoByUuid(bean.getUuid());;
        return MgRnrAuthenticationResultConverter.INSTANCE.poToDto(record);
    }
    
     /**
     * 通过查询条件查询集合数据
     *
     * @param bean
     * @return 集合对象
     */
    @Override
    public List<MgRnrAuthenticationResultDTO> queryByList(MgRnrAuthenticationResultDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        if (StringUtils.isNotBlank(bean.getRnrId())) {
            queryWrapper.eq("rnr_id", bean.getRnrId());
        }
        if (StringUtils.isNotBlank(bean.getTenantNo())) {
            queryWrapper.eq("tenant_no", bean.getTenantNo());
        }

        queryWrapper.eq(StringUtils.isNotBlank(bean.getOrderId()),"order_id",bean.getOrderId());
        queryWrapper.orderByDesc("create_time");
        List<MgRnrAuthenticationResultPO> record = this.list(queryWrapper);
        return MgRnrAuthenticationResultConverter.INSTANCE.poListToDtoList(record);
    }

    /**
     * 新增数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgRnrAuthenticationResultDTO insert(MgRnrAuthenticationResultDTO bean) {
       MgRnrAuthenticationResultPO mgRnrAuthenticationResultPO = MgRnrAuthenticationResultConverter.INSTANCE.dtoToPo(bean);
	   mgRnrAuthenticationResultPO.setUuid(CuscStringUtils.generateUuid());
        this.save(mgRnrAuthenticationResultPO);
		bean.setUuid(mgRnrAuthenticationResultPO.getUuid());
        return bean;
    }

    /**
     * 修改数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgRnrAuthenticationResultDTO update(MgRnrAuthenticationResultDTO bean) {
        MgRnrAuthenticationResultPO mgRnrAuthenticationResultPO = this.getPoByUuid(bean.getUuid());
		 if(mgRnrAuthenticationResultPO == null){
            return null;
        }
		MgRnrAuthenticationResultPO tmpBean = MgRnrAuthenticationResultConverter.INSTANCE.dtoToPo(bean);
		tmpBean.setId(mgRnrAuthenticationResultPO.getId());
        this.updateById(tmpBean);
        return bean;
    }
    
    /**
     * 通过UUID查询单条数据
     *
     * @param uuid
     * @return 实例对象
     */
    private MgRnrAuthenticationResultPO getPoByUuid(String uuid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("uuid", uuid);
        return this.getOne(queryWrapper);
    }
}
