package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.rds.mybatis.PageHelper;
import com.cusc.nirvana.user.rnr.common.constants.RnrConstants;
import com.cusc.nirvana.user.rnr.mg.constants.CommonDeleteEnum;
import com.cusc.nirvana.user.rnr.mg.constants.CryptKeyHelper;
import com.cusc.nirvana.user.rnr.mg.constants.MbCodeEnum;
import com.cusc.nirvana.user.rnr.mg.constants.RnrBizzTypeEnum;
import com.cusc.nirvana.user.rnr.mg.constants.RnrStatus;
import com.cusc.nirvana.user.rnr.mg.converter.MgRnrCardInfoConverter;
import com.cusc.nirvana.user.rnr.mg.dao.MgRnrCardInfoDao;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrCardInfoPO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrCardInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrCardInfoService;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrCardNoticeService;
import com.cusc.nirvana.user.util.CuscStringUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * 实名卡信息(MgRnrCardInfo)表服务实现类
 *
 * @author yuy336
 * @since 2022-03-04 11:06:45
 */
@Service
@Slf4j
public class MgRnrCardInfoServiceImpl extends ServiceImpl<MgRnrCardInfoDao, MgRnrCardInfoPO>
        implements IMgRnrCardInfoService {

    @Resource
    @Lazy
    private IMgRnrCardNoticeService cardNoticeService;

    /**
     * 通过UUID查询单条数据
     *
     * @param bean
     * @return 实例对象
     */
    @Override
    public MgRnrCardInfoDTO getByUuid(MgRnrCardInfoDTO bean) {
        MgRnrCardInfoPO record = this.getPoByUuid(bean.getUuid());
        return MgRnrCardInfoConverter.INSTANCE.poToDto(record);
    }

    /**
     * 通过查询条件查询集合数据
     *
     * @param bean
     * @return 集合对象
     */
    @Override
    public List<MgRnrCardInfoDTO> queryByList(MgRnrCardInfoDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.eq(StringUtils.isNotBlank(bean.getRnrId()), "rnr_id", bean.getRnrId());
        queryWrapper.eq(StringUtils.isNotBlank(bean.getTenantNo()), "tenant_no", bean.getTenantNo());
        queryWrapper.eq(StringUtils.isNotBlank(bean.getIccid()), "iccid",  CryptKeyHelper.encrypt(bean.getIccid()));
        queryWrapper.eq(null != bean.getRnrStatus(), "rnr_status", bean.getRnrStatus());
        queryWrapper.eq(null != bean.getRnrBizzType(), "rnr_bizz_type", bean.getRnrBizzType());
        queryWrapper.eq(null != bean.getOrderId(), "order_id", bean.getOrderId());
        queryWrapper.eq(StringUtils.isNotEmpty(bean.getIotId()), "iot_id", CryptKeyHelper.encrypt(bean.getIotId()));
        queryWrapper.in(!CollectionUtils.isEmpty(bean.getRnrIdList()), "rnr_id", bean.getRnrIdList());
		queryWrapper.in(!CollectionUtils.isEmpty(bean.getOrderIdList()), "order_id", bean.getOrderIdList());
        queryWrapper.in(!CollectionUtils.isEmpty(bean.getBizTypeList()), "rnr_bizz_type", bean.getBizTypeList());
        queryWrapper.in(!CollectionUtils.isEmpty(bean.getIccidList()), "iccid",
                CryptKeyHelper.encrypt(bean.getIccidList()));
        queryWrapper.orderByDesc("create_time");
        List<MgRnrCardInfoPO> record = this.list(queryWrapper);
        return MgRnrCardInfoConverter.INSTANCE.poListToDtoList(record);
    }

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @Override
    public PageResult<MgRnrCardInfoDTO> queryByPage(MgRnrCardInfoDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq(null != bean.getOrderId(), "order_id", bean.getOrderId());
        queryWrapper.orderByDesc("create_time");
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());

        Page<MgRnrCardInfoPO> page =
                this.page(new Page<>(bean.getCurrPage(), bean.getPageSize()), queryWrapper);
        return PageHelper.convert(page, MgRnrCardInfoDTO.class);
    }

    /**
     * 新增数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgRnrCardInfoDTO insert(MgRnrCardInfoDTO bean) {
        MgRnrCardInfoPO mgRnrCardInfoPO = MgRnrCardInfoConverter.INSTANCE.dtoToPo(bean);
        if (CuscStringUtils.isEmpty(bean.getUuid())) {
            mgRnrCardInfoPO.setUuid(CuscStringUtils.generateUuid());
            bean.setUuid(mgRnrCardInfoPO.getUuid());
        }
        this.save(mgRnrCardInfoPO);
        return bean;
    }

    /**
     * 修改数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgRnrCardInfoDTO update(MgRnrCardInfoDTO bean) {
        MgRnrCardInfoPO mgRnrCardInfoPO = this.getPoByUuid(bean.getUuid());
        if (mgRnrCardInfoPO == null) {
            return null;
        }
        MgRnrCardInfoPO tmpBean = MgRnrCardInfoConverter.INSTANCE.dtoToPo(bean);
        tmpBean.setId(mgRnrCardInfoPO.getId());
        this.updateById(tmpBean);
        return bean;
    }

    /**
     * 通过主键删除数据
     *
     * @param bean 实例对象
     * @return 是否成功
     */
    @Override
    @Transactional
    public boolean deleteById(MgRnrCardInfoDTO bean) {
        MgRnrCardInfoPO mgRnrCardInfoPO = this.getPoByUuid(bean.getUuid());
        if (mgRnrCardInfoPO == null) {
            return false;
        }
        MgRnrCardInfoPO tmpBean = new MgRnrCardInfoPO();
        tmpBean.setId(mgRnrCardInfoPO.getId());
        tmpBean.setIsDelete(CommonDeleteEnum.DELETED.getCode());
        return this.updateById(tmpBean);
    }

    @Override
    public Integer addRnrCardBatch(List<MgRnrCardInfoPO> beanList) {
        beanList.forEach(bean -> {
            if (null == bean.getOldCardId()) {
                bean.setOldCardId("");
            }
            //数据加密
            bean.setIccid(CryptKeyHelper.encrypt(bean.getIccid()));
            bean.setIotId(CryptKeyHelper.encrypt(bean.getIotId()));
            //bean.setOldCardId(CryptKeyHelper.encrypt(bean.getOldCardId()));
        });
        return baseMapper.addRnrCardBatch(beanList);
    }

    @Override
    public List<MgRnrCardInfoDTO> getByIccid(MgRnrCardInfoDTO bean) {
        //return MgRnrCardInfoConverter.INSTANCE.poListToDtoList(queryRnrCardByEs(bean));
        //直接查库
        return null;
    }

    @Override
    public List<MgRnrCardInfoDTO> getListByIccid(MgRnrCardInfoDTO bean) {
        List<MgRnrCardInfoPO> oneByIccid = this.getListByIccid(bean.getIccid());
        return MgRnrCardInfoConverter.INSTANCE.poListToDtoList(oneByIccid);
    }

    @Override
    public MgRnrCardInfoDTO getOneByIccid(MgRnrCardInfoDTO bean) {
        MgRnrCardInfoPO oneCardByIccid = getOneCardByIccid(bean.getIccid(), bean.getIotId(), bean.getTenantNo());
        return MgRnrCardInfoConverter.INSTANCE.poToDto(oneCardByIccid);
    }

    /**
     * 根据业务id和iccid查找记录
     *
     * @param orderId
     * @param iccid
     * @return
     */
    @Override
    public MgRnrCardInfoDTO getByOrderIdAndIccId(String orderId, String iccid) {
        QueryWrapper<MgRnrCardInfoPO> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("order_id", orderId);
        queryWrapper.eq("iccid", CryptKeyHelper.encrypt(iccid));
        List<MgRnrCardInfoPO> list = this.list(queryWrapper);
        return list.isEmpty() ? null : MgRnrCardInfoConverter.INSTANCE.poToDto(list.get(0));
    }

    /**
     * 更新mq发送状态
     *
     * @param mgRnrCardInfoDTO
     * @return
     */
    @Override
    public Integer updateCardNoticeStatus(MgRnrCardInfoDTO mgRnrCardInfoDTO) {
        return this.baseMapper.updateCardNoticeStatus(mgRnrCardInfoDTO);
    }

    @Override
    public Integer updateCardStatusByOrderId(String orderId, int noticeStatus, int rnrStatus) {
        return this.baseMapper.updateCardStatusByOrderId(orderId, noticeStatus, rnrStatus);
    }

    @Override
    public boolean checkIccidExists(MgRnrCardInfoDTO bean) {
        boolean ret = false;
        List<MgRnrCardInfoDTO> cardList = getByIccid(bean);
        if (CollectionUtils.isEmpty(cardList)) {
            return ret;
        }
        for (MgRnrCardInfoDTO card : cardList) {
            if (RnrConstants.RNR_STATUS_WAIT_CHECK == card.getRnrStatus()
                    || RnrConstants.RNR_STATUS_CHECK_ACCESS == card.getRnrStatus()
                    || RnrConstants.RNR_STATUS_WAIT_MANUAL_CHECK == card.getRnrStatus()) {
                ret = true;
                break;
            }
        }
        return ret;
    }

    @Override
    public boolean checkIccid(MgRnrCardInfoDTO bean) {
        boolean ret = false;
        List<MgRnrCardInfoDTO> cardList = getListByIccid(bean);
        if (CollectionUtils.isEmpty(cardList)) {
            return ret;
        }
        for (MgRnrCardInfoDTO card : cardList) {
            if (RnrConstants.RNR_STATUS_NOT_BINDING == card.getRnrStatus()) {
                ret = true;
                break;
            }
        }
        return ret;
    }

    @Override
    public List<MgRnrCardInfoDTO> queryBindListByVin(String vin) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.eq("rnr_status", RnrStatus.RNR.getCode());
        queryWrapper.eq("iot_id", CryptKeyHelper.encrypt(vin));
        queryWrapper.orderByDesc("create_time");
        List<MgRnrCardInfoPO> record = this.list(queryWrapper);
        return MgRnrCardInfoConverter.INSTANCE.poListToDtoList(record);
    }


    @Override
    public List<MgRnrCardInfoDTO> queryBindListByVinsAndIccids(List<String> vins, List<String> iccids) {
        List<String> encryptVins = new ArrayList<>();
        if (!CollectionUtils.isEmpty(vins)) {
            vins.forEach(vin -> encryptVins.add(CryptKeyHelper.encrypt(vin)));

        }
        List<String> encryptIccids = new ArrayList<>();
        if (!CollectionUtils.isEmpty(iccids)) {
            iccids.forEach(iccid -> encryptIccids.add(CryptKeyHelper.encrypt(iccid)));

        }
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.in("rnr_status", Arrays.asList(RnrStatus.RNR.getCode(), RnrStatus.INIT.getCode()));
        queryWrapper.in("iot_id", encryptVins);
        queryWrapper.in(!CollectionUtils.isEmpty(encryptIccids),"iccid", encryptIccids);
        queryWrapper.orderByDesc("create_time");
        List<MgRnrCardInfoPO> record = this.list(queryWrapper);
        return MgRnrCardInfoConverter.INSTANCE.poListToDtoList(record);
    }

    @Override
    public List<MgRnrCardInfoDTO> queryBindListByVinAndBizType(String vin, int bizTpye) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.eq("rnr_status", RnrStatus.RNR.getCode());
        queryWrapper.eq("iot_id", CryptKeyHelper.encrypt(vin));
        queryWrapper.eq("rnr_bizz_type", bizTpye);
        queryWrapper.orderByDesc("create_time");
        List<MgRnrCardInfoPO> record = this.list(queryWrapper);
        return MgRnrCardInfoConverter.INSTANCE.poListToDtoList(record);
    }

    @Override
    public List<MgRnrCardInfoDTO> queryListByVin(String vin) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        //queryWrapper.eq("rnr_status", RnrStatus.RNR.getCode());
        queryWrapper.eq("iot_id", CryptKeyHelper.encrypt(vin));
        queryWrapper.orderByDesc("create_time");
        List<MgRnrCardInfoPO> record = this.list(queryWrapper);
        return MgRnrCardInfoConverter.INSTANCE.poListToDtoList(record);
    }

    /**
     * 更新解绑记录
     *
     * @param uuids
     * @return
     */
    @Override
    public Integer unboundCardBatch(List<String> uuids, RnrStatus status) {
        return baseMapper.unboundCardBatch(uuids, status.getCode());
    }

    /**
     * 自然人批量解绑卡
     *
     * @param beans
     * @return
     */
    @Override
    public Integer updateBatchCardStatus(List<MgRnrCardInfoDTO> beans) {
        List<String> uuidList = new ArrayList<>();
        for (MgRnrCardInfoDTO cardInfoDTO : beans) {
            uuidList.add(cardInfoDTO.getUuid());
        }
        return unboundCardBatch(uuidList, RnrStatus.UNBOUND);
    }

    @Override
    public Integer insertBatchCards(List<MgRnrCardInfoDTO> beans) {
        int target = 0;
        List<String> uuidList = new ArrayList<>();
        for (MgRnrCardInfoDTO cardInfoDTO : beans) {
            MgRnrCardInfoDTO insert = this.insert(cardInfoDTO);
            if (insert == null) {
                break;
            } else {
                target++;
            }
        }
        return target;
    }

    @Override
    @Transactional
    public void updateCardStatusByRnrId(MgRnrCardInfoDTO dto) {
        MgRnrCardInfoPO updateEntity = new MgRnrCardInfoPO();
        updateEntity.setRnrStatus(dto.getRnrStatus());

        LambdaQueryWrapper<MgRnrCardInfoPO> query = new LambdaQueryWrapper<>();
        query.eq(MgRnrCardInfoPO::getRnrId, dto.getRnrId());
        this.baseMapper.update(updateEntity, query);
    }

    @Override
    public void sendCardNotice(MgRnrCardInfoDTO dto) {
        if (StringUtils.isBlank(dto.getOrderId())) {
            return;
        }

        cardNoticeService.sendCardNoticeByOrderId(dto.getOrderId());
    }

    @Override
    public PageResult<MgRnrCardInfoDTO> queryPageByUserId(MgRnrCardInfoDTO bean) {
        Page<MgRnrCardInfoPO> page = new Page<>(bean.getCurrPage(), bean.getPageSize());
        page.setRecords(baseMapper.queryByUserId(page, bean));
        return PageHelper.convert(page, MgRnrCardInfoDTO.class);
    }

    /**
     * 根据iccid最新的实名卡信息
     */
    @Override
    public MgRnrCardInfoDTO getNewRnrCardByIccid(MgRnrCardInfoDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.ne( "rnr_bizz_type", RnrBizzTypeEnum.Unbound.getCode());
        queryWrapper.eq("iccid", CryptKeyHelper.encrypt(bean.getIccid()));
        queryWrapper.eq("tenant_no", bean.getTenantNo());
        queryWrapper.eq("rnr_status", RnrStatus.RNR.getCode());
        queryWrapper.orderByDesc("create_time");
        List<MgRnrCardInfoPO> record = this.list(queryWrapper);
        if(CollectionUtils.isEmpty(record)){
            return null;
        }
        return MgRnrCardInfoConverter.INSTANCE.poToDto(record.get(0));
    }

    @Override
    public int getNumWithUnload(MgRnrInfoDTO dto) {
        int num = 0 ;
        String certNumber = CryptKeyHelper.encrypt(dto.getCertNumber());
        List<String> retList = this.baseMapper.getNumWithUnload(certNumber);
        for (String iccid : retList) {
            iccid = CryptKeyHelper.decrypt(iccid);
            MbCodeEnum mbCodeEnum = MbCodeEnum.get(iccid);
            log.info("解密之后是,{},通讯商是,{},前6位是,{}", iccid, mbCodeEnum.getName(), iccid.substring(0, 6));
            if(MbCodeEnum.CUCC.equals(mbCodeEnum)){
                num ++;
            }
        }
        return num;
    }

    //-----------私有方法区--------------

    /**
     * 通过UUID查询单条数据
     *
     * @param uuid
     * @return 实例对象
     */
    private MgRnrCardInfoPO getPoByUuid(String uuid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("uuid", uuid);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        return this.getOne(queryWrapper);
    }

    /**
     * 通过iccid查询单条数据
     */
    private List<MgRnrCardInfoPO> getListByIccid(String iccid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("iccid", CryptKeyHelper.encrypt(iccid));
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        return this.list(queryWrapper);
    }

    /**
     * 通过iccid和vin查询实名后的单条数据
     */
    private MgRnrCardInfoPO getOneCardByIccid(String iccid, String vin, String tenantNo) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("iccid", CryptKeyHelper.encrypt(iccid));
        queryWrapper.ne("rnr_bizz_type", RnrBizzTypeEnum.Unbound.getCode());
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.eq("rnr_status", RnrStatus.RNR.getCode());
        queryWrapper.eq("tenant_no", tenantNo);
        if (StringUtils.isNotEmpty(vin)) {
            queryWrapper.eq("iot_id", CryptKeyHelper.encrypt(vin));
        }
        List<MgRnrCardInfoPO> retList = this.list(queryWrapper);
        if (!CollectionUtils.isEmpty(retList)) {
            return retList.get(0);
        }
        return null;
    }

    public List<MgRnrCardInfoDTO> getByRnrid(String uuid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.eq("rnr_id", uuid);
        queryWrapper.orderByDesc("create_time");
        List<MgRnrCardInfoPO> record = this.list(queryWrapper);
        return MgRnrCardInfoConverter.INSTANCE.poListToDtoList(record);
    }

    /**
     * 通过iccid查询单条数据
     *//*
    private List<MgRnrCardInfoPO> getCardByIccids(String vin) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.eq("rnr_status", RnrStatus.RNR.getCode());
        queryWrapper.eq("iot_id",vin);
        return this.list(queryWrapper);
    }*/
}
