package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cache.annotation.tag.Cache;
import com.cusc.nirvana.user.rnr.common.constants.RedisConstant;
import com.cusc.nirvana.user.rnr.mg.constants.CommonDeleteEnum;
import com.cusc.nirvana.user.rnr.mg.converter.MgRnrCommonConfigConverter;
import com.cusc.nirvana.user.rnr.mg.dao.MgRnrCommonConfigDao;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrCommonConfigPO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrCommonConfigDTO;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrCommonConfigService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 实名业务公共配置(MgRnrCommonConfig)表服务实现类
 *
 * @author yuy336
 * @since 2022-03-03 10:56:46
 */
@Service
public class MgRnrCommonConfigServiceImpl extends ServiceImpl<MgRnrCommonConfigDao, MgRnrCommonConfigPO>
        implements IMgRnrCommonConfigService {

    /**
     * 通过UUID查询单条数据
     *
     * @param bean
     * @return 实例对象
     */
    @Override
    public MgRnrCommonConfigDTO getByUuid(MgRnrCommonConfigDTO bean) {
        MgRnrCommonConfigPO record = this.getPoByUuid(bean.getUuid());
        ;
        return MgRnrCommonConfigConverter.INSTANCE.poToDto(record);
    }

    /**
     * 通过查询条件查询集合数据
     *
     * @param bean
     * @return 集合对象
     */
    @Override
    public List<MgRnrCommonConfigDTO> queryByList(MgRnrCommonConfigDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.orderByDesc("create_time");
        List<MgRnrCommonConfigPO> record = this.list(queryWrapper);
        return MgRnrCommonConfigConverter.INSTANCE.poListToDtoList(record);
    }

    /**
     * 新增数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    @Cache(keyPrefix = RedisConstant.RNR_COMMON_CONFIG, key = "#bean.configPath", level1 = "redis", action = 0)
    public MgRnrCommonConfigDTO insert(MgRnrCommonConfigDTO bean) {
        MgRnrCommonConfigPO mgRnrCommonConfigPO = MgRnrCommonConfigConverter.INSTANCE.dtoToPo(bean);
        this.save(mgRnrCommonConfigPO);
        return bean;
    }

    /**
     * 修改数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    @Cache(keyPrefix = RedisConstant.RNR_COMMON_CONFIG, key = "#bean.configPath", level1 = "redis", action = 0)
    public MgRnrCommonConfigDTO update(MgRnrCommonConfigDTO bean) {
        MgRnrCommonConfigPO mgRnrCommonConfigPO = this.getPoByUuid(bean.getUuid());
        if (mgRnrCommonConfigPO == null) {
            return null;
        }
        MgRnrCommonConfigPO tmpBean = MgRnrCommonConfigConverter.INSTANCE.dtoToPo(bean);
        tmpBean.setId(mgRnrCommonConfigPO.getId());
        this.updateById(tmpBean);
        return bean;
    }

    /**
     * 通过主键删除数据
     *
     * @param bean 实例对象
     * @return 是否成功
     */
    @Override
    @Transactional
    @Cache(keyPrefix = RedisConstant.RNR_COMMON_CONFIG, key = "#bean.configPath", level1 = "redis", action = 0)
    public boolean deleteById(MgRnrCommonConfigDTO bean) {
        MgRnrCommonConfigPO mgRnrCommonConfigPO = this.getPoByUuid(bean.getUuid());
        if (mgRnrCommonConfigPO == null) {
            return false;
        }
        MgRnrCommonConfigPO tmpBean = new MgRnrCommonConfigPO();
        tmpBean.setId(mgRnrCommonConfigPO.getId());
        tmpBean.setIsDelete(CommonDeleteEnum.DELETED.getCode());
        return this.updateById(tmpBean);
    }

    @Override
    @Cache(keyPrefix = RedisConstant.RNR_COMMON_CONFIG, key = "#path", level1 = "redis")
    public MgRnrCommonConfigDTO getByConfigPath(String path) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("config_path", path);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        MgRnrCommonConfigPO record = this.getOne(queryWrapper);
        return MgRnrCommonConfigConverter.INSTANCE.poToDto(record);
    }

    @Override
    public List<MgRnrCommonConfigDTO> getByConfigParentPath(String parentPath) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("parent_path", parentPath);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.orderByAsc("create_time");
        List<MgRnrCommonConfigPO> record = this.list(queryWrapper);
        return MgRnrCommonConfigConverter.INSTANCE.poListToDtoList(record);
    }

    /**
     * 通过UUID查询单条数据
     *
     * @param uuid
     * @return 实例对象
     */
    private MgRnrCommonConfigPO getPoByUuid(String uuid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("uuid", uuid);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        return this.getOne(queryWrapper);
    }
}
