package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cusc.nirvana.user.rnr.mg.constants.CommonDeleteEnum;
import com.cusc.nirvana.user.rnr.mg.constants.CryptKeyHelper;
import com.cusc.nirvana.user.rnr.mg.converter.MgRnrCompanyInfoConverter;
import com.cusc.nirvana.user.rnr.mg.dao.MgRnrCompanyInfoDao;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrCompanyInfoPO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrCompanyInfoDTO;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrCompanyInfoService;
import com.cusc.nirvana.user.util.CuscStringUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.util.List;
import java.util.stream.Collectors;

/**
 * 实名公司信息表(MgRnrCompanyInfo)表服务实现类
 *
 * @author yuy336
 * @since 2022-02-10 18:30:32
 */
@Service
public class MgRnrCompanyInfoServiceImpl extends ServiceImpl<MgRnrCompanyInfoDao, MgRnrCompanyInfoPO> implements IMgRnrCompanyInfoService {

    /**
     * 通过UUID查询单条数据
     *
     * @param bean
     * @return 实例对象
     */
    @Override
    public MgRnrCompanyInfoDTO getByUuid(MgRnrCompanyInfoDTO bean) {
        MgRnrCompanyInfoPO record = this.getPoByUuid(bean.getUuid());;
        return MgRnrCompanyInfoConverter.INSTANCE.poToDto(record);
    }

    @Override
    public MgRnrCompanyInfoDTO getByRnrid(MgRnrCompanyInfoDTO bean) {
        MgRnrCompanyInfoPO record = this.getPoByRnrid(bean.getRnrId());;
        return MgRnrCompanyInfoConverter.INSTANCE.poToDto(record);
    }

    @Override
    public List<String> findRnrIdsByCompanyName(MgRnrCompanyInfoDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.eq("company_name", CryptKeyHelper.encrypt(bean.getCompanyName()));
        queryWrapper.orderByDesc("create_time");
        List<MgRnrCompanyInfoPO> record = this.list(queryWrapper);
        return record.stream().map(info -> info.getRnrId()).collect(Collectors.toList());
    }

    /**
     * 通过查询条件查询集合数据
     *
     * @param bean
     * @return 集合对象
     */
    @Override
    public List<MgRnrCompanyInfoDTO> queryByList(MgRnrCompanyInfoDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.eq(StringUtils.isNotBlank(bean.getTenantNo()),"tenant_no",bean.getTenantNo());
        queryWrapper.eq(null != bean.getIsVehicleCompany(),"is_vehicle_company",bean.getIsVehicleCompany());
        queryWrapper.eq(StringUtils.isNotBlank(bean.getRnrId()),"rnr_id",bean.getRnrId());
		queryWrapper.in(!CollectionUtils.isEmpty(bean.getRnrIdList()),"rnr_id",bean.getRnrIdList());
        queryWrapper.likeLeft(StringUtils.isNotBlank(bean.getCompanyName()),"company_name",CryptKeyHelper.encrypt(bean.getCompanyName()));
        queryWrapper.orderByDesc("create_time");
        List<MgRnrCompanyInfoPO> record = this.list(queryWrapper);
        return MgRnrCompanyInfoConverter.INSTANCE.poListToDtoList(record);
    }

    /**
     * 新增数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgRnrCompanyInfoDTO insert(MgRnrCompanyInfoDTO bean) {
       MgRnrCompanyInfoPO mgRnrCompanyInfoPO = MgRnrCompanyInfoConverter.INSTANCE.dtoToPo(bean);
        if(CuscStringUtils.isEmpty(bean.getUuid())){
            mgRnrCompanyInfoPO.setUuid(CuscStringUtils.generateUuid());
            bean.setUuid(mgRnrCompanyInfoPO.getUuid());
        }
        this.save(mgRnrCompanyInfoPO);
        return bean;
    }

    /**
     * 修改数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgRnrCompanyInfoDTO update(MgRnrCompanyInfoDTO bean) {
        MgRnrCompanyInfoPO mgRnrCompanyInfoPO = this.getPoByUuid(bean.getUuid());
		 if(mgRnrCompanyInfoPO == null){
            return null;
        }
		MgRnrCompanyInfoPO tmpBean = MgRnrCompanyInfoConverter.INSTANCE.dtoToPo(bean);
		tmpBean.setId(mgRnrCompanyInfoPO.getId());
        this.updateById(tmpBean);
        return bean;
    }

    /**
     * 通过主键删除数据
     * @param bean 实例对象
     * @return 是否成功
     */
    @Override
    @Transactional
    public boolean deleteById(MgRnrCompanyInfoDTO bean) {
        MgRnrCompanyInfoPO mgRnrCompanyInfoPO = this.getPoByUuid(bean.getUuid());
		 if (mgRnrCompanyInfoPO == null) {
            return false;
        }
        MgRnrCompanyInfoPO tmpBean = new MgRnrCompanyInfoPO();
        tmpBean.setId(mgRnrCompanyInfoPO.getId());
        tmpBean.setIsDelete(CommonDeleteEnum.DELETED.getCode());
        return this.updateById(tmpBean);
    }
    
    /**
     * 通过UUID查询单条数据
     *
     * @param uuid
     * @return 实例对象
     */
    private MgRnrCompanyInfoPO getPoByUuid(String uuid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("uuid", uuid);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        return this.getOne(queryWrapper);
    }

    /**
     * 根据rnrid获取列表
     * @param rnrid
     * @return
     */
    private MgRnrCompanyInfoPO getPoByRnrid(String rnrid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("rnr_id", rnrid);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        return this.getOne(queryWrapper);
    }
}
