package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.rds.mybatis.PageHelper;
import com.cusc.nirvana.user.rnr.mg.constants.CommonDeleteEnum;
import com.cusc.nirvana.user.rnr.mg.converter.MgRnrImageConverter;
import com.cusc.nirvana.user.rnr.mg.dao.MgRnrFileDao;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrFilePO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrFileDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;
import com.cusc.nirvana.user.rnr.mg.service.IFileService;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrFileService;
import com.cusc.nirvana.user.util.CuscStringUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.List;

/**
 * 实名图片信息表(MgRnrImage0)表服务实现类
 *
 * @author yuy336
 * @since 2022-01-26 13:49:12
 */
@Service
public class MgRnrFileServiceImpl extends ServiceImpl<MgRnrFileDao, MgRnrFilePO> implements IMgRnrFileService {

    @Autowired
    private IFileService fileService;

    /**
     * 通过UUID查询单条数据
     *
     * @param bean
     * @return 实例对象
     */
    @Override
    public MgRnrFileDTO getByUuid(MgRnrFileDTO bean) {
        MgRnrFilePO record = this.getPoByUuid(bean.getUuid());
        return MgRnrImageConverter.INSTANCE.poToDto(record);
    }

    /**
     * 通过RNRID查询数据
     *
     * @param bean
     * @return 实例对象
     */
    @Override
    public List<MgRnrFileDTO> getByRnrid(MgRnrFileDTO bean) {
        List<MgRnrFilePO> poByRnrid = this.getPoByRnrid(bean.getRnrId(), bean.getTenantNo());
        return MgRnrImageConverter.INSTANCE.poListToDtoList(poByRnrid);
    }


    /**
     * 通过查询条件查询集合数据
     *
     * @param bean
     * @return 集合对象
     */
    @Override
    public List<MgRnrFileDTO> queryByList(MgRnrFileDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq(StringUtils.isNotBlank(bean.getRnrId()), "rnr_id", bean.getRnrId());
        queryWrapper.eq(bean.getRnrBizzType() != null, "rnr_bizz_type", bean.getRnrBizzType());
        queryWrapper.eq(bean.getFileType() != null, "file_type", bean.getFileType());
        queryWrapper.eq(StringUtils.isNotBlank(bean.getRnrCompanyId()), "rnr_company_id", bean.getRnrCompanyId());
        queryWrapper.eq(StringUtils.isNotBlank(bean.getLiaisonId()), "liaison_id", bean.getLiaisonId());
        queryWrapper.eq(bean.getRoutingKey() != null, "routing_key", bean.getRoutingKey());
        queryWrapper.eq(StringUtils.isNotBlank(bean.getTenantNo()), "tenant_no", bean.getTenantNo());
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.orderByDesc("order_no", "create_time");
        List<MgRnrFilePO> record = this.list(queryWrapper);
        return MgRnrImageConverter.INSTANCE.poListToDtoList(record);
    }

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @Override
    public PageResult<MgRnrFileDTO> queryByPage(MgRnrFileDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.orderByDesc("create_time");
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());

        Page<MgRnrFilePO> page =
                this.page(new Page<>(bean.getCurrPage(), bean.getPageSize()), queryWrapper);
        return PageHelper.convert(page, MgRnrFileDTO.class);
    }

    /**
     * 新增数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgRnrFileDTO insert(MgRnrFileDTO bean) {
        MgRnrFilePO mgRnrImagePO = MgRnrImageConverter.INSTANCE.dtoToPo(bean);
        if (CuscStringUtils.isEmpty(bean.getUuid())) {
            mgRnrImagePO.setUuid(CuscStringUtils.generateUuid());
            bean.setUuid(mgRnrImagePO.getUuid());
        }
        this.save(mgRnrImagePO);
        return bean;
    }

    /**
     * 修改数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgRnrFileDTO update(MgRnrFileDTO bean) {
        MgRnrFilePO MgRnrImagePO = this.getPoByUuid(bean.getUuid());
        if (MgRnrImagePO == null) {
            return null;
        }
        MgRnrFilePO tmpBean = MgRnrImageConverter.INSTANCE.dtoToPo(bean);
        tmpBean.setId(MgRnrImagePO.getId());
        this.updateById(tmpBean);
        return bean;
    }

    /**
     * 通过主键删除数据
     *
     * @param bean 实例对象
     * @return 是否成功
     */
    @Override
    @Transactional
    public boolean deleteById(MgRnrFileDTO bean) {
        MgRnrFilePO MgRnrImagePO = this.getPoByUuid(bean.getUuid());
        if (MgRnrImagePO == null) {
            return false;
        }
        MgRnrFilePO tmpBean = new MgRnrFilePO();
        tmpBean.setId(MgRnrImagePO.getId());
        tmpBean.setIsDelete(CommonDeleteEnum.DELETED.getCode());
        return this.updateById(tmpBean);
    }

    @Override
    public List<MgRnrFileDTO> rnrImageBatchUpload(List<MgRnrFileDTO> imageList, MgRnrInfoDTO rnrInfoDTO) {
        return null;
    }

    @Override
    public Integer addRnrFileBatch(List<MgRnrFilePO> beanList) {
        return baseMapper.addRnrFileBatch(beanList);
    }

    @Override
    public Integer addRnrFileFromInfo(MgRnrInfoDTO info, List<MgRnrFileDTO> beanList) {
        if (CollectionUtils.isEmpty(beanList)) {
            return 0;
        }
        MgRnrFilePO imagePO;
//        FileEntityBase64DTO fileEntityDTO;
        List<MgRnrFilePO> imagePOList = new ArrayList<>();
//        List<FileEntityBase64DTO> fileEntityList = new ArrayList<>();
        for (MgRnrFileDTO imageDTO : beanList) {
            imageDTO.setUuid(CuscStringUtils.generateUuid());
            imageDTO.setFileSystemId(imageDTO.getFileSystemId());
            imageDTO.setRnrId(info.getUuid());
            imageDTO.setTenantNo(info.getTenantNo());
            imageDTO.setRoutingKey(info.getRoutingKey());
            imageDTO.setRnrBizzType(info.getRnrBizzType());
            imageDTO.setIsCompany(info.getIsCompany());
            imagePO = MgRnrImageConverter.INSTANCE.dtoToPo(imageDTO);
            imagePOList.add(imagePO);

//            fileEntityDTO = new FileEntityBase64DTO();
//            fileEntityDTO.setUuid(imageDTO.getUuid());
//            fileEntityDTO.setFileName(imageDTO.getFileName());
//            fileEntityDTO.setBase64(imageDTO.getFileBase64());
//            fileEntityList.add(fileEntityDTO);
        }
        //文件上传
//        FileBase64ReqDTO base64ReqDTO = new FileBase64ReqDTO();
//        base64ReqDTO.setFileList(fileEntityList);
//        boolean isUploadFile = fileService.uploadBase64(base64ReqDTO);
//        if (!isUploadFile) {
//            throw new CuscUserException(ResponseCode.RNR_IMAGE_UPLOAD_FAIL.getCode(),
//                    ResponseCode.RNR_IMAGE_UPLOAD_FAIL.getMsg());
//        }
        //执行文件保存
        return addRnrFileBatch(imagePOList);
    }

    /**
     * 通过UUID查询单条数据
     *
     * @param uuid
     * @return 实例对象
     */
    private MgRnrFilePO getPoByUuid(String uuid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("uuid", uuid);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        return this.getOne(queryWrapper);
    }

    /**
     * 根据rnrid获取列表
     *
     * @param rnrid
     * @return
     */
    public List<MgRnrFilePO> getPoByRnrid(String rnrid, String tenantNo) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("rnr_id", rnrid);
        queryWrapper.eq("tenant_no", tenantNo);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        return this.list(queryWrapper);
    }

    /**
     * 根据rnrid获取列表
     *
     * @param rnrid
     * @return
     */
    public List<MgRnrFilePO> getPoByRnridOrderByOrderno(String rnrid, String tenantNo) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("rnr_id", rnrid);
        queryWrapper.eq("tenant_no", tenantNo);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.orderByAsc("order_no");
        return this.list(queryWrapper);
    }
}
