package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.rds.mybatis.PageHelper;
import com.cusc.nirvana.user.rnr.mg.constants.CommonDeleteEnum;
import com.cusc.nirvana.user.rnr.mg.constants.CryptKeyHelper;
import com.cusc.nirvana.user.rnr.mg.constants.RnrStatus;
import com.cusc.nirvana.user.rnr.mg.converter.MgRnrInfoConverter;
import com.cusc.nirvana.user.rnr.mg.dao.MgRnrInfoDao;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrInfoPO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrInfoService;
import com.cusc.nirvana.user.rnr.mg.util.CuscSqlUtils;
import com.cusc.nirvana.user.util.CuscStringUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import java.util.List;

/**
 * 实名信息表(MgRnrInfo)表服务实现类
 *
 * @author yuy336
 * @since 2022-02-10 18:30:52
 */
@Service
public class MgRnrInfoServiceImpl extends ServiceImpl<MgRnrInfoDao, MgRnrInfoPO> implements IMgRnrInfoService {

    /**
     * 通过UUID查询单条数据
     *
     * @param bean
     * @return 实例对象
     */
    @Override
    public MgRnrInfoDTO getByUuid(MgRnrInfoDTO bean) {
        MgRnrInfoPO record = this.getPoByUuid(bean.getUuid());
        return MgRnrInfoConverter.INSTANCE.poToDto(record);
    }
    
     /**
     * 通过查询条件查询集合数据
     *
     * @param bean
     * @return 集合对象
     */
    @Override
    public List<MgRnrInfoDTO> queryByList(MgRnrInfoDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.in(!CollectionUtils.isEmpty(bean.getUuidList()),"uuid",bean.getUuidList());
		queryWrapper.eq(StringUtils.isNotBlank(bean.getTenantNo()),"tenant_no",bean.getTenantNo());
		queryWrapper.eq(StringUtils.isNotBlank(bean.getFullName()),"full_name", CryptKeyHelper.encrypt(bean.getFullName()));
		queryWrapper.eq(StringUtils.isNotBlank(bean.getPhone()),"phone",CryptKeyHelper.encrypt(bean.getPhone()));
		queryWrapper.eq(StringUtils.isNotBlank(bean.getCertNumber()),"cert_number",CryptKeyHelper.encrypt(bean.getCertNumber()));
		queryWrapper.eq(null != bean.getRnrStatus(),"rnr_status",bean.getRnrStatus());
        //关联公司进行查询
        queryWrapper.exists(StringUtils.isNotBlank(bean.getCompanyName()),"select 1 from mg_rnr_company_info company where mg_rnr_info.uuid = company.rnr_id and company.company_name = '" + CryptKeyHelper.encrypt(
                CuscSqlUtils.transactSQLInjection(bean.getCompanyName()))+"'");

        queryWrapper.orderByDesc("create_time");
        List<MgRnrInfoPO> record = this.list(queryWrapper);
        return MgRnrInfoConverter.INSTANCE.poListToDtoList(record);
    }

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @Override
    public PageResult<MgRnrInfoDTO> queryByPage(MgRnrInfoDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.orderByDesc("create_time");
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        
       Page<MgRnrInfoPO> page =
                this.page(new Page<>(bean.getCurrPage(), bean.getPageSize()), queryWrapper);
        return PageHelper.convert(page, MgRnrInfoDTO.class);
    }

    /**
     * 新增数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgRnrInfoDTO insert(MgRnrInfoDTO bean) {
       MgRnrInfoPO mgRnrInfoPO = MgRnrInfoConverter.INSTANCE.dtoToPo(bean);
        if(CuscStringUtils.isEmpty(bean.getUuid())){
            mgRnrInfoPO.setUuid(CuscStringUtils.generateUuid());
            bean.setUuid(mgRnrInfoPO.getUuid());
        }
        this.save(mgRnrInfoPO);
        return bean;
    }

    /**
     * 修改数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgRnrInfoDTO update(MgRnrInfoDTO bean) {
        MgRnrInfoPO mgRnrInfoPO = this.getPoByUuid(bean.getUuid());
		 if(mgRnrInfoPO == null){
            return null;
        }
		MgRnrInfoPO tmpBean = MgRnrInfoConverter.INSTANCE.dtoToPo(bean);
		tmpBean.setId(mgRnrInfoPO.getId());
        this.updateById(tmpBean);
        return bean;
    }

    /**
     * 通过主键删除数据
     * @param bean 实例对象
     * @return 是否成功
     */
    @Override
    @Transactional
    public boolean deleteById(MgRnrInfoDTO bean) {
        MgRnrInfoPO mgRnrInfoPO = this.getPoByUuid(bean.getUuid());
		 if (mgRnrInfoPO == null) {
            return false;
        }
        MgRnrInfoPO tmpBean = new MgRnrInfoPO();
        tmpBean.setId(mgRnrInfoPO.getId());
        tmpBean.setIsDelete(CommonDeleteEnum.DELETED.getCode());
        return this.updateById(tmpBean);
    }

    @Override
    public void updateRnrStatus(String rnrId, RnrStatus status) {
        this.baseMapper.updateRnrStatus(rnrId,status.getCode());
    }

    @Override
    public void updateRnrStatusBatch(List<String> rnrIds, RnrStatus status) {
        this.baseMapper.updateRnrStatusBatch(rnrIds,status.getCode());
    }

    /**
     * 通过UUID查询单条数据
     *
     * @param uuid
     * @return 实例对象
     */
    public MgRnrInfoPO getPoByUuid(String uuid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("uuid", uuid);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        return this.getOne(queryWrapper);
    }

}
