package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.rds.mybatis.PageHelper;
import com.cusc.nirvana.user.rnr.mg.constants.CommonDeleteEnum;
import com.cusc.nirvana.user.rnr.mg.converter.MgRnrTagConverter;
import com.cusc.nirvana.user.rnr.mg.dao.MgRnrTagDao;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrTagPO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrTagDTO;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrTagService;
import com.cusc.nirvana.user.util.CuscStringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

/**
 * 实名标签，可用于对数据权限查询(MgRnrTag15)表服务实现类
 *
 * @author yuy336
 * @since 2022-01-26 13:50:09
 */
@Service
public class MgRnrTagServiceImpl extends ServiceImpl<MgRnrTagDao, MgRnrTagPO> implements IMgRnrTagService {

    /**
     * 通过UUID查询单条数据
     *
     * @param bean
     * @return 实例对象
     */
    @Override
    public MgRnrTagDTO getByUuid(MgRnrTagDTO bean) {
        MgRnrTagPO record = this.getPoByUuid(bean.getUuid());;
        return MgRnrTagConverter.INSTANCE.poToDto(record);
    }
    
     /**
     * 通过查询条件查询集合数据
     *
     * @param bean
     * @return 集合对象
     */
    @Override
    public List<MgRnrTagDTO> queryByList(MgRnrTagDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.orderByDesc("create_time");
        List<MgRnrTagPO> record = this.list(queryWrapper);
        return MgRnrTagConverter.INSTANCE.poListToDtoList(record);
    }

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @Override
    public PageResult<MgRnrTagDTO> queryByPage(MgRnrTagDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.orderByDesc("create_time");
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        
       Page<MgRnrTagPO> page =
                this.page(new Page<>(bean.getCurrPage(), bean.getPageSize()), queryWrapper);
        return PageHelper.convert(page, MgRnrTagDTO.class);
    }

    /**
     * 新增数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgRnrTagDTO insert(MgRnrTagDTO bean) {
       MgRnrTagPO MgRnrTagPO = MgRnrTagConverter.INSTANCE.dtoToPo(bean);
	   MgRnrTagPO.setUuid(CuscStringUtils.generateUuid());
        this.save(MgRnrTagPO);
		bean.setUuid(MgRnrTagPO.getUuid());
        return bean;
    }

    /**
     * 修改数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgRnrTagDTO update(MgRnrTagDTO bean) {
        MgRnrTagPO MgRnrTagPO = this.getPoByUuid(bean.getUuid());
		 if(MgRnrTagPO == null){
            return null;
        }
		MgRnrTagPO tmpBean = MgRnrTagConverter.INSTANCE.dtoToPo(bean);
		tmpBean.setId(MgRnrTagPO.getId());
        this.updateById(tmpBean);
        return bean;
    }

    /**
     * 通过主键删除数据
     * @param bean 实例对象
     * @return 是否成功
     */
    @Override
    @Transactional
    public boolean deleteById(MgRnrTagDTO bean) {
        MgRnrTagPO MgRnrTagPO = this.getPoByUuid(bean.getUuid());
		 if (MgRnrTagPO == null) {
            return false;
        }
        MgRnrTagPO tmpBean = new MgRnrTagPO();
        tmpBean.setId(MgRnrTagPO.getId());
        tmpBean.setIsDelete(CommonDeleteEnum.DELETED.getCode());
        return this.updateById(tmpBean);
    }

    @Override
    public Integer addRnrTagBatch(List<MgRnrTagPO> beanList) {
        return baseMapper.addRnrTagBatch(beanList);
    }

    @Override
    public Integer addRnrTagFromRnrInfo(MgRnrInfoDTO info, List<MgRnrTagDTO> beanList) {
        MgRnrTagPO tagPO;
        List<MgRnrTagPO> tagPOList = new ArrayList<>();
        for (MgRnrTagDTO tagDTO : beanList) {
            tagDTO.setUuid(CuscStringUtils.generateUuid());
            tagDTO.setRnrId(info.getUuid());
            tagDTO.setTenantNo(info.getTenantNo());
            tagDTO.setRoutingKey(info.getRoutingKey());
            tagPO = MgRnrTagConverter.INSTANCE.dtoToPo(tagDTO);
            tagPOList.add(tagPO);
        }
        return addRnrTagBatch(tagPOList);
    }

    //-----------私有方法区--------------
    /**
     * 通过UUID查询单条数据
     *
     * @param uuid
     * @return 实例对象
     */
    private MgRnrTagPO getPoByUuid(String uuid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("uuid", uuid);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        return this.getOne(queryWrapper);
    }
}
