package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.rds.mybatis.PageHelper;
import com.cusc.nirvana.user.rnr.mg.constants.CommonDeleteEnum;
import com.cusc.nirvana.user.rnr.mg.converter.MgTenantBizzConfigConverter;
import com.cusc.nirvana.user.rnr.mg.dao.MgTenantBizzConfigDao;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgTenantBizzConfigPO;
import com.cusc.nirvana.user.rnr.mg.dto.MgTenantBizzConfigDTO;
import com.cusc.nirvana.user.rnr.mg.service.IMgTenantBizzConfigService;
import com.cusc.nirvana.user.util.CuscStringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 租户业务配置(MgTenantBizzConfig)表服务实现类
 *
 * @author yuy336
 * @since 2022-06-14 09:36:11
 */
@Service
public class MgTenantBizzConfigServiceImpl extends ServiceImpl<MgTenantBizzConfigDao, MgTenantBizzConfigPO> implements IMgTenantBizzConfigService {

    /**
     * 通过UUID查询单条数据
     *
     * @param bean
     * @return 实例对象
     */
    @Override
    public MgTenantBizzConfigDTO getByUuid(MgTenantBizzConfigDTO bean) {
        MgTenantBizzConfigPO record = this.getPoByUuid(bean.getUuid());;
        return MgTenantBizzConfigConverter.INSTANCE.poToDto(record);
    }
    
     /**
     * 通过查询条件查询集合数据
     *
     * @param bean
     * @return 集合对象
     */
    @Override
    public List<MgTenantBizzConfigDTO> queryByList(MgTenantBizzConfigDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.orderByDesc("create_time");
        List<MgTenantBizzConfigPO> record = this.list(queryWrapper);
        return MgTenantBizzConfigConverter.INSTANCE.poListToDtoList(record);
    }

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @Override
    public PageResult<MgTenantBizzConfigDTO> queryByPage(MgTenantBizzConfigDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.orderByDesc("create_time");
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        
       Page<MgTenantBizzConfigPO> page =
                this.page(new Page<>(bean.getCurrPage(), bean.getPageSize()), queryWrapper);
        return PageHelper.convert(page, MgTenantBizzConfigDTO.class);
    }

    /**
     * 新增数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgTenantBizzConfigDTO insert(MgTenantBizzConfigDTO bean) {
       MgTenantBizzConfigPO mgTenantBizzConfigPO = MgTenantBizzConfigConverter.INSTANCE.dtoToPo(bean);
	   mgTenantBizzConfigPO.setUuid(CuscStringUtils.generateUuid());
        this.save(mgTenantBizzConfigPO);
		bean.setUuid(mgTenantBizzConfigPO.getUuid());
        return bean;
    }

    /**
     * 修改数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public MgTenantBizzConfigDTO update(MgTenantBizzConfigDTO bean) {
        MgTenantBizzConfigPO mgTenantBizzConfigPO = this.getPoByUuid(bean.getUuid());
		 if(mgTenantBizzConfigPO == null){
            return null;
        }
		MgTenantBizzConfigPO tmpBean = MgTenantBizzConfigConverter.INSTANCE.dtoToPo(bean);
		tmpBean.setId(mgTenantBizzConfigPO.getId());
        this.updateById(tmpBean);
        return bean;
    }

    /**
     * 通过主键删除数据
     * @param bean 实例对象
     * @return 是否成功
     */
    @Override
    @Transactional
    public boolean deleteById(MgTenantBizzConfigDTO bean) {
        MgTenantBizzConfigPO mgTenantBizzConfigPO = this.getPoByUuid(bean.getUuid());
		 if (mgTenantBizzConfigPO == null) {
            return false;
        }
        MgTenantBizzConfigPO tmpBean = new MgTenantBizzConfigPO();
        tmpBean.setId(mgTenantBizzConfigPO.getId());
        tmpBean.setIsDelete(CommonDeleteEnum.DELETED.getCode());
        return this.updateById(tmpBean);
    }
    
    /**
     * 通过UUID查询单条数据
     *
     * @param uuid
     * @return 实例对象
     */
    private MgTenantBizzConfigPO getPoByUuid(String uuid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("uuid", uuid);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        return this.getOne(queryWrapper);
    }
}
