package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.mg.constants.CommonDeleteEnum;
import com.cusc.nirvana.user.rnr.mg.converter.OrgBusinessTagConverter;
import com.cusc.nirvana.user.rnr.mg.dao.OrgBusinessTagDao;
import com.cusc.nirvana.user.rnr.mg.dao.entity.OrgBusinessTagPO;
import com.cusc.nirvana.user.rnr.mg.dto.OrgBusinessTagDTO;
import com.cusc.nirvana.user.rnr.mg.service.IOrgBusinessTagService;
import com.cusc.nirvana.user.util.CuscStringUtils;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class OrgBusinessTagServiceImpl extends ServiceImpl<OrgBusinessTagDao, OrgBusinessTagPO>
        implements IOrgBusinessTagService {

    @Override
    public Response<OrgBusinessTagDTO> getByUuid(String uuid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("uuid", uuid);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        OrgBusinessTagPO po = this.getOne(queryWrapper);
        return Response.createSuccess(OrgBusinessTagConverter.INSTANCE.poToDto(po));
    }

    @Override
    public Response<OrgBusinessTagDTO> getByTagCode(String tenantNo, String tagCode) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("tenant_no", tenantNo);
        queryWrapper.eq("tag_code", tagCode);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        OrgBusinessTagPO po = this.getOne(queryWrapper);
        return Response.createSuccess(OrgBusinessTagConverter.INSTANCE.poToDto(po));
    }

    @Override
    public Response<OrgBusinessTagDTO> insert(OrgBusinessTagDTO tagDTO) {
        if (getByTagCode(tagDTO.getTenantNo(), tagDTO.getTagCode()) != null) {
            return Response.createSuccess("标签编码已经存在，请核实！");
        }
        tagDTO.setUuid(CuscStringUtils.generateUuid());
        if (this.save(OrgBusinessTagConverter.INSTANCE.dtoToPo(tagDTO))) {
            return Response.createSuccess(tagDTO);
        }
        return Response.createError("新增标签失败!");
    }

    @Override
    public Response<OrgBusinessTagDTO> update(OrgBusinessTagDTO tagDTO) {
        OrgBusinessTagDTO tmpDto = getByTagCode(tagDTO.getTenantNo(), tagDTO.getTagCode()).getData();
        if (tmpDto != null && !tmpDto.getUuid().equals(tagDTO.getUuid())) {
            return Response.createSuccess("标签编码已经存在，请核实！");
        }
        UpdateWrapper wrapper = new UpdateWrapper();
        wrapper.eq("uuid", tagDTO.getUuid());
        wrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        boolean flag = this.update(OrgBusinessTagConverter.INSTANCE.dtoToPo(tagDTO), wrapper);
        return Response.createSuccess(flag);
    }

    @Override
    public Response<Integer> remove(String uuid) {
        OrgBusinessTagDTO tagDTO = getByUuid(uuid).getData();
        if (tagDTO == null) {
            return Response.createSuccess(0);
        }
        tagDTO.setIsDelete(1);
        tagDTO = update(tagDTO).getData();
        return Response.createSuccess(tagDTO);
    }

    @Override
    public Response<List<OrgBusinessTagDTO>> query(String tenantNo, String orgUuid) {
        QueryWrapper wrapper = new QueryWrapper();
        wrapper.eq("tenant_no", tenantNo);
        if (CuscStringUtils.isNotEmpty(orgUuid)) {
            wrapper.eq("org_uuid", orgUuid);
        }
        wrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        List<OrgBusinessTagPO> pos = this.list(wrapper);
        return Response.createSuccess(OrgBusinessTagConverter.INSTANCE.poListToDtoList(pos));
    }
}
