package com.cusc.nirvana.user.rnr.mg.service.impl;

import cn.hutool.core.codec.Base64Decoder;
import cn.hutool.core.codec.Base64Encoder;
import com.aliyun.oss.OSS;
import com.aliyun.oss.OSSClientBuilder;
import com.aliyun.oss.model.GetObjectRequest;
import com.aliyun.oss.model.OSSObject;
import com.aliyun.oss.model.ObjectMetadata;
import com.aliyun.oss.model.PutObjectRequest;
import com.cusc.nirvana.user.exception.CuscUserException;
import com.cusc.nirvana.user.rnr.common.constants.ResponseCode;
import com.cusc.nirvana.user.rnr.mg.service.IFileService;
import com.cusc.nirvana.user.util.CuscStringUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.io.IOUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.net.URL;
import java.util.Date;

/**
 * @author stayAnd
 * @date 2022/6/22
 */
@Service
@Slf4j
public class OssFileServiceImpl implements IFileService {

	@Value("${oss.endpoint}")
	private String endpoint;


	@Value("${oss.accessKeyId}")
	private String accessKeyId;


	@Value("${oss.accessKeySecret}")
	private String accessKeySecret;


	@Value("${oss.bucketName}")
	private String bucketName;


	@Override
	public String upLoadImage(InputStream inputStream, String suffix) {
		return upLoadFile(inputStream,suffix);
	}

	@Override
	public String upLoadFile(InputStream inputStream,String suffix) {
		// 创建OSSClient实例。
		OSS ossClient = new OSSClientBuilder().build(endpoint, accessKeyId, accessKeySecret);

		String ossFileKey = CuscStringUtils.generateUuid()+"."+suffix;
		PutObjectRequest request = new PutObjectRequest(bucketName,ossFileKey,inputStream);
		ossClient.putObject(request);
		ossClient.shutdown();

		return ossFileKey;
	}

	@Override
	public String upLoadFileBase64Img(String base64, String suffix) {
		try {
			byte[] bytes = Base64Decoder.decode(base64);
			ByteArrayInputStream inputStream = new ByteArrayInputStream(bytes);
			return upLoadFile(inputStream,suffix);
		} catch (Exception e) {
			log.error("upLoadFileBase64Img has error");
		}
		return "";
	}

	@Override
	public String getFileUrl(String fileKey) {
		// 创建OSSClient实例。
		OSS ossClient = new OSSClientBuilder().build(endpoint, accessKeyId, accessKeySecret);
		Date date = new Date(System.currentTimeMillis() +(3600L * 1000) );
		URL url = ossClient.generatePresignedUrl(bucketName,fileKey,date);
		log.info("OssFileServiceImpl getFileUrl fileKey = {},url = {}",fileKey,url.toString());
		return url.toString();
	}

	@Override
	public String downLoadBase64(String fileKey) {
		try {
			// 创建OSSClient实例。
			OSS ossClient = new OSSClientBuilder().build(endpoint, accessKeyId, accessKeySecret);
			GetObjectRequest request = new GetObjectRequest(bucketName,fileKey);
			OSSObject object = ossClient.getObject(request);
			InputStream inputStream = object.getObjectContent();

			byte[] bytes = IOUtils.toByteArray(inputStream);
			return Base64Encoder.encode(bytes);
		} catch (Exception e) {
			throw new CuscUserException(ResponseCode.SYSTEM_ERROR.getCode(),"文件oss下载失败");
		}
	}

	@Override
	public Double getFileSize(String fileKey) {
		OSS ossClient = new OSSClientBuilder().build(endpoint, accessKeyId, accessKeySecret);
		boolean existFlag = ossClient.doesObjectExist(bucketName, fileKey);
		if(!existFlag){
			throw new CuscUserException("500","文件不存在");
		}
		ObjectMetadata objectMetadata = ossClient.getObjectMetadata(bucketName, fileKey);
		Double fileSize = (double) objectMetadata.getContentLength()/1024;
		ossClient.shutdown();
		return fileSize;
	}

	@Override
	public byte[] downLoadBytes(String fileKey) {

		// 创建OSSClient实例。
		OSS ossClient = new OSSClientBuilder().build(endpoint, accessKeyId, accessKeySecret);
		GetObjectRequest request = new GetObjectRequest(bucketName,fileKey);
		OSSObject object = ossClient.getObject(request);
		InputStream inputStream = object.getObjectContent();

		try {
			byte[] bytes = IOUtils.toByteArray(inputStream);
			return bytes;
		} catch (Exception e){
			throw new CuscUserException(ResponseCode.SYSTEM_ERROR.getCode(),"文件oss bytes下载失败");
		}
	}
}
