package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.rds.mybatis.PageHelper;
import com.cusc.nirvana.user.rnr.mg.constants.CommonDeleteEnum;
import com.cusc.nirvana.user.rnr.mg.converter.RnrOrderOperationLogConverter;
import com.cusc.nirvana.user.rnr.mg.dao.RnrOrderOperationLogDao;
import com.cusc.nirvana.user.rnr.mg.dao.entity.RnrOrderOperationLogPO;
import com.cusc.nirvana.user.rnr.mg.dto.RnrOrderOperationLogDTO;
import com.cusc.nirvana.user.rnr.mg.service.IRnrOrderOperationLogService;
import com.cusc.nirvana.user.util.CuscStringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 实名工单操作日志(MgRnrOrderOperationLog)表服务实现类
 *
 * @author yuy336
 * @since 2022-03-04 10:07:54
 */
@Service
public class RnrOrderOperationLogServiceImpl extends ServiceImpl<RnrOrderOperationLogDao, RnrOrderOperationLogPO> implements
        IRnrOrderOperationLogService {

    /**
     * 通过UUID查询单条数据
     *
     * @param bean
     * @return 实例对象
     */
    @Override
    public RnrOrderOperationLogDTO getByUuid(RnrOrderOperationLogDTO bean) {
        RnrOrderOperationLogPO record = this.getPoByUuid(bean.getUuid());;
        return RnrOrderOperationLogConverter.INSTANCE.poToDto(record);
    }
    
     /**
     * 通过查询条件查询集合数据
     *
     * @param bean
     * @return 集合对象
     */
    @Override
    public List<RnrOrderOperationLogDTO> queryByList(RnrOrderOperationLogDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.orderByDesc("create_time");
        List<RnrOrderOperationLogPO> record = this.list(queryWrapper);
        return RnrOrderOperationLogConverter.INSTANCE.poListToDtoList(record);
    }

    /**
     * 分页查询
     *
     * @param bean 筛选条件
     * @return 查询结果
     */
    @Override
    public PageResult<RnrOrderOperationLogDTO> queryByPage(RnrOrderOperationLogDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.orderByDesc("create_time");
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        
       Page<RnrOrderOperationLogPO> page =
                this.page(new Page<>(bean.getCurrPage(), bean.getPageSize()), queryWrapper);
        return PageHelper.convert(page, RnrOrderOperationLogDTO.class);
    }

    /**
     * 新增数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public RnrOrderOperationLogDTO insert(RnrOrderOperationLogDTO bean) {
       RnrOrderOperationLogPO mgRnrOrderOperationLogPO = RnrOrderOperationLogConverter.INSTANCE.dtoToPo(bean);
	   mgRnrOrderOperationLogPO.setUuid(CuscStringUtils.generateUuid());
        this.save(mgRnrOrderOperationLogPO);
		bean.setUuid(mgRnrOrderOperationLogPO.getUuid());
        return bean;
    }

    /**
     * 修改数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public RnrOrderOperationLogDTO update(RnrOrderOperationLogDTO bean) {
        RnrOrderOperationLogPO mgRnrOrderOperationLogPO = this.getPoByUuid(bean.getUuid());
		 if(mgRnrOrderOperationLogPO == null){
            return null;
        }
		RnrOrderOperationLogPO tmpBean = RnrOrderOperationLogConverter.INSTANCE.dtoToPo(bean);
		tmpBean.setId(mgRnrOrderOperationLogPO.getId());
        this.updateById(tmpBean);
        return bean;
    }

    @Override
    public Integer insertBatchOrderOperationLog(List<RnrOrderOperationLogPO> orderOptLogList) {
        return baseMapper.insertBatchOrderOperationLog(orderOptLogList);
    }

    /**
     * 通过UUID查询单条数据
     *
     * @param uuid
     * @return 实例对象
     */
    private RnrOrderOperationLogPO getPoByUuid(String uuid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("uuid", uuid);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        return this.getOne(queryWrapper);
    }
}
