package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.cusc.nirvana.user.rnr.mg.constants.NoticeStatusEnum;
import com.cusc.nirvana.user.rnr.mg.constants.RnrOrderSourceEnum;
import com.cusc.nirvana.user.rnr.mg.constants.RnrOrderStatusEnum;
import com.cusc.nirvana.user.rnr.mg.constants.RnrStatus;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.RnrOrderDTO;
import com.cusc.nirvana.user.rnr.mg.service.ICiamService;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrCardInfoService;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrCardNoticeService;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrInfoService;
import com.cusc.nirvana.user.rnr.mg.service.IRnrOrderService;
import com.cusc.nirvana.user.rnr.mg.service.IRnrResultProcessService;
import com.cusc.nirvana.user.rnr.mg.util.RnrOrderUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;

/**
 * @author stayAnd
 * @date 2022/5/5
 */
@Service
@Slf4j
public class RnrResultProcessServiceImpl implements IRnrResultProcessService {

	@Resource
	private IRnrOrderService orderService;

	@Resource
	@Lazy
	private IMgRnrCardNoticeService cardNoticeService;

	@Resource
	private IMgRnrInfoService mgRnrInfoService;

	@Resource
	private IMgRnrCardInfoService cardInfoService;

	@Autowired
	private ICiamService ciamService;

	@Override
	public void processRnrResult(String orderId, String rnrId, RnrOrderStatusEnum statusEnum,String content) {

		//更新状态
		saveStatus(orderId, rnrId, statusEnum,content);

		//发送通知
		if (statusEnum == RnrOrderStatusEnum.PASS) {
			saveUser(orderId,rnrId);
		}
		log.info("开始发送实名成功mq，order:{}",orderId);
		cardNoticeService.sendCardNoticeByOrderId(orderId);
	}


	//创建用户
	private void saveUser(String orderId, String rnrId) {
		MgRnrInfoDTO mgRnrInfoDTO = new MgRnrInfoDTO();
		mgRnrInfoDTO.setUuid(rnrId);
		mgRnrInfoDTO = mgRnrInfoService.getByUuid(mgRnrInfoDTO);

		RnrOrderDTO rnrOrderDTO = new RnrOrderDTO();
		rnrOrderDTO.setUuid(orderId);
		rnrOrderDTO = orderService.getByUuid(rnrOrderDTO);

		if(mgRnrInfoDTO != null && rnrOrderDTO != null){
			if(!RnrOrderSourceEnum.H5_CUSTOMER.equals(rnrOrderDTO.getOrderSource()) && RnrOrderUtil.needCreateUser(mgRnrInfoDTO,rnrOrderDTO)){
				ciamService.createUser(mgRnrInfoDTO);
			}
		}
	}

	private void saveStatus(String orderId, String rnrId, RnrOrderStatusEnum statusEnum,String content) {

		//更新订单状态
		//orderService.updateOrderStatus(Collections.singletonList(orderId), statusEnum.getCode());
		RnrOrderDTO updateOrder = new RnrOrderDTO();
		updateOrder.setUuid(orderId);
		updateOrder.setOrderStatus(statusEnum.getCode());
		updateOrder.setComment(content);
		updateOrder.setAuditTime(new Date());
		updateOrder.setFinalApproveTime(new Date());
		orderService.update(updateOrder);

		if (statusEnum == RnrOrderStatusEnum.PASS) {
			//审核通过
			//更新rnr状态
			mgRnrInfoService.updateRnrStatus(rnrId, RnrStatus.RNR);
			//更新订单状态
			cardInfoService.updateCardStatusByOrderId(orderId, NoticeStatusEnum.NEED.getCode(), RnrStatus.RNR.getCode());
		} else {
			//更新rnr状态
			mgRnrInfoService.updateRnrStatus(rnrId, RnrStatus.RNR_FAIL);
			//更新订单状态
			cardInfoService.updateCardStatusByOrderId(orderId, NoticeStatusEnum.NONEED.getCode(), RnrStatus.RNR_FAIL.getCode());
		}

	}
}
