package com.cusc.nirvana.user.rnr.mg.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cusc.nirvana.common.result.PageResult;
import com.cusc.nirvana.rds.mybatis.PageHelper;
import com.cusc.nirvana.user.rnr.mg.constants.CommonDeleteEnum;
import com.cusc.nirvana.user.rnr.mg.converter.SimFileHistoryConverter;
import com.cusc.nirvana.user.rnr.mg.dao.SimFileHistoryDao;
import com.cusc.nirvana.user.rnr.mg.dao.entity.SimFileHistoryPO;
import com.cusc.nirvana.user.rnr.mg.dto.SimFileHistoryDTO;
import com.cusc.nirvana.user.rnr.mg.dto.SimFileHistoryQueryDTO;
import com.cusc.nirvana.user.rnr.mg.service.ISimFileHistoryService;
import com.cusc.nirvana.user.util.CuscStringUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.Calendar;

@Service
public class SimFileHistoryServiceImpl extends ServiceImpl<SimFileHistoryDao, SimFileHistoryPO>
    implements ISimFileHistoryService {

    @Override
    public SimFileHistoryDTO getByUuid(String uuid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("uuid", uuid);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        SimFileHistoryPO historyPO = this.getOne(queryWrapper);
        return historyPO == null ? null : SimFileHistoryConverter.INSTANCE.poToDto(historyPO);
    }

    @Override
    public PageResult<SimFileHistoryDTO> queryByPage(SimFileHistoryQueryDTO queryDTO) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("org_uuid", queryDTO.getOrgUuid());
        queryWrapper.eq(null != queryDTO.getFileType(),"file_type", queryDTO.getFileType());
        queryWrapper.gt(queryDTO.getStartCreateTime() != null,"create_time", queryDTO.getStartCreateTime());
        queryWrapper.lt(queryDTO.getEndCreateTime() != null, "create_time", queryDTO.getEndCreateTime());
        if (queryDTO.getStatus() != null) {
            if (queryDTO.getStatus() != 2) {
                queryWrapper.eq("status", queryDTO.getStatus());
                queryWrapper.eq("error_count", 0);
            } else {
                queryWrapper.gt("error_count", 0);
            }
        }
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.orderByDesc("create_time");
        Page<SimFileHistoryPO> historyPOPage = this.page(new Page<>(queryDTO.getCurrPage(), queryDTO.getPageSize()), queryWrapper);
        return PageHelper.convert(historyPOPage, SimFileHistoryDTO.class);
    }

    @Override
    public SimFileHistoryDTO insert(SimFileHistoryDTO historyDTO) {
        historyDTO.setUuid(CuscStringUtils.generateUuid());
        if (historyDTO.getErrorCount() > 0) {
            historyDTO.setStatus(2);
        }
        SimFileHistoryPO simFileHistoryPO = SimFileHistoryConverter.INSTANCE.dtoToPo(historyDTO);
        this.save(simFileHistoryPO);
        return historyDTO;
    }

    @Override
    public SimFileHistoryDTO update(SimFileHistoryDTO historyDTO) {
        SimFileHistoryDTO bean = this.getByUuid(historyDTO.getUuid());
        if (bean == null) {
            return null;
        }
        historyDTO.setId(bean.getId());
        if (historyDTO.getErrorCount() > 0) {
            historyDTO.setStatus(2);
        }
        SimFileHistoryPO simFileHistoryPO = SimFileHistoryConverter.INSTANCE.dtoToPo(historyDTO);
        this.updateById(simFileHistoryPO);
        return historyDTO;
    }

    @Override
    public boolean deleteById(String orgUuid, String uuid) {
        SimFileHistoryDTO historyDTO = this.getByUuid(uuid);
        if (historyDTO == null || !historyDTO.getOrgUuid().equals(orgUuid)) {
            return false;
        }
        historyDTO.setIsDelete(1);
        return this.updateById(SimFileHistoryConverter.INSTANCE.dtoToPo(historyDTO));
    }
}
