package com.cusc.nirvana.user.rnr.mg.util;

import com.cusc.nirvana.user.exception.CuscUserException;
import com.cusc.nirvana.user.rnr.mg.constants.RnrBizzTypeEnum;
import com.cusc.nirvana.user.rnr.mg.constants.RnrOrderType;
import com.cusc.nirvana.user.rnr.mg.constants.RnrStatus;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.RnrOrderDTO;

/**
 * @author yubo
 * @since 2022-04-26 10:58
 */
public class RnrOrderUtil {

    //是否需要创建用户
    public static boolean needCreateUser(MgRnrInfoDTO rnrInfoDTO, RnrOrderDTO rnrOrderDTO) {
        return rnrInfoDTO.getIsTrust() == 0 &&
                (RnrOrderType.SEC_VEHICLE.getCode().equals(rnrOrderDTO.getOrderType())
                        || RnrOrderType.NEW_VEHICLE.getCode().equals(rnrOrderDTO.getOrderType()));
    }

    //订单类型转通知类型
    public static RnrBizzTypeEnum orderTypeToNoticeType(int orderType) {
        RnrOrderType rnrOrderType = RnrOrderType.getTypeByCode(orderType);
        if (rnrOrderType == null) {
            throw new CuscUserException("", "不支持发送此类型的工单消息");
        }

        switch (rnrOrderType) {
            case NEW_VEHICLE:
            case SEC_VEHICLE:
            case COMPANY_NEW_VEHICLE:
            case CARMAKER_NEW_VEHICLE:
            case ONE_CAR_MORE_CARD_BIND:
                return RnrBizzTypeEnum.Bind;
            case UNBIND:
            case SEC_UNBIND:
            case COMPANY_CORPORATION_UNBIND:
            case ENTERPRISEUNBIND:
                return RnrBizzTypeEnum.Unbound;
			case COMPANY_CORPORATION_CHANGE:
				return RnrBizzTypeEnum.INFO_CHANGE;
            case TBOX_CHANGE:
                return RnrBizzTypeEnum.ChangeBinding;
            default:
                throw new CuscUserException("", "不支持发送此类型的工单消息");
        }
    }

    //审核通过订单类型转成实名状态
    public static RnrStatus orderTypeToRnrStatus(int orderType) {
        RnrOrderType rnrOrderType = RnrOrderType.getTypeByCode(orderType);
        if (rnrOrderType == null) {
            throw new CuscUserException("", "不支持此类型的工单消息");
        }

        switch (rnrOrderType) {
            case NEW_VEHICLE:
            case SEC_VEHICLE:
            case COMPANY_NEW_VEHICLE:
            case CARMAKER_NEW_VEHICLE:
            case ONE_CAR_MORE_CARD_BIND:
            case REBINDING:
                return RnrStatus.RNR;
            case UNBIND:
            case SEC_UNBIND:
            case COMPANY_CORPORATION_UNBIND:
                return RnrStatus.UNBOUND;
            default:
                return RnrStatus.INIT;
        }
    }

}
