package com.cusc.nirvana.user.rnr.notice.kafka;

import com.cache.CacheFactory;
import com.cache.exception.CacheException;
import com.cache.service.ISortSetService;
import com.cusc.nirvana.user.rnr.mg.constants.RnrMgMqConstant;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.concurrent.ThreadPoolTaskScheduler;
import org.springframework.scheduling.support.CronTrigger;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import java.util.Map;
import java.util.concurrent.ScheduledFuture;


@Configuration
@EnableScheduling
@Slf4j
public class ConsumeDelaySchedule {

    @Resource
    private CacheFactory cacheFactory;

    @Autowired
    private KafkaProduct kafkaProduct;

    @Autowired
    private ThreadPoolTaskScheduler taskScheduler;

    private ScheduledFuture<?> future;

    @PostConstruct
    public void StartCron() {
        try {
            //kafka定时任务执行
            String basetime = "*/3 * * * * * ";
            if (future == null) {
                future = taskScheduler.schedule(new runnable(), new CronTrigger(basetime));
            }
        } catch (Exception e) {
            log.error("延迟定时任务启动失败：{}", e.getMessage());
        }
    }

    // 模仿消费者  每3秒执行一次
    //duled(cron = "*/3 * * * * * ")
    public void consume() {
        // 取出redis里的消息，小于当前时间戳的进行消费
        try {
            ISortSetService sortSetService = cacheFactory.getSortSetService();
            Map<String, Double> sortSetWithScore =
                    sortSetService.getSortSetWithScore("CT:USER:" + RnrMgMqConstant.RNR_CARD_OPERATION_DELAY_TOPIC, 1);
            sortSetWithScore.forEach((key, value) -> {
                if (value <= System.currentTimeMillis()) {
                    try {
                        //消息发送成功后删除redis里的member
                        boolean result = kafkaProduct.sendMessage(RnrMgMqConstant.RNR_CARD_OPERATION_DELAY_TOPIC, key);
                        if (result) {
                            sortSetService.delMembers("CT:USER:" + RnrMgMqConstant.RNR_CARD_OPERATION_DELAY_TOPIC, key);
                        }
                    } catch (CacheException e) {
                        e.printStackTrace();
                    }
                }
            });
        } catch (Exception e) {
            log.error("消费redis消息异常：{}", e.getMessage());
        }
    }

    private class runnable implements Runnable {
        @Override
        public void run() {
            try {
                consume();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

}
