package com.cusc.nirvana.user.rnr.notice.kafka;

import com.alibaba.fastjson.JSON;
import com.cusc.nirvana.user.rnr.mg.constants.*;
import com.cusc.nirvana.user.rnr.mg.dto.RnrOrderDTO;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrCardInfoService;
import com.cusc.nirvana.user.rnr.mg.service.IMgRnrInfoService;
import com.cusc.nirvana.user.rnr.mg.service.IRnrOrderService;
import lombok.extern.slf4j.Slf4j;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.kafka.annotation.KafkaListener;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.Optional;

/**
 * @author fyp
 * @since 2022-06-10
 */
@Slf4j
@Service
public class KfKRnrBindExchangeConsumer {

    @Autowired
    IRnrOrderService orderService;

    @Autowired
    IMgRnrCardInfoService cardInfoService;

    @Resource
	private IMgRnrInfoService rnrInfoService;

    @KafkaListener(id = RnrMgMqConstant.RNR_CARD_OPERATION_DELAY_GROUP, topics = {RnrMgMqConstant.RNR_CARD_OPERATION_DELAY_TOPIC})
    public void onMessage(ConsumerRecord<?, ?> record) {

        Optional<?> kafkaMessage = Optional.ofNullable(record.value());
        String message = "";
        if (kafkaMessage.isPresent()) {
            message = (String) kafkaMessage.get();
        }
        log.info("接收到延迟消息：{}", JSON.toJSONString(message));

        //查询工单信息
        RnrOrderDTO rnrOrderDTO = new RnrOrderDTO();
        rnrOrderDTO.setUuid(message);
        rnrOrderDTO = orderService.getByUuid(rnrOrderDTO);

		if (null == rnrOrderDTO) {
			log.info("接收到延迟消息 未查询到order,uuid = {}",rnrOrderDTO.getUuid());
			return;
		}

		if (RnrOrderType.UNBIND.getCode().equals(rnrOrderDTO.getOrderType())
				|| RnrOrderType.TBOX_CHANGE.getCode().equals(rnrOrderDTO.getOrderType())
				|| RnrOrderType.ONE_CAR_MORE_CARD_BIND.getCode().equals(rnrOrderDTO.getOrderType())
				|| RnrOrderType.ENTERPRISEUNBIND.getCode().equals(rnrOrderDTO.getOrderType())|| RnrOrderType.SEC_UNBIND.getCode().equals(rnrOrderDTO.getOrderType())){

			// 原车主解绑 、 换件 、 一车多卡 、 企业解绑 发送短信后order_status是1或者2(待审核)  如果此时收到延迟消息时 还是此状态 作废工单和卡
			if (!RnrOrderStatusEnum.notFinished(rnrOrderDTO.getOrderStatus())) {
				log.info("接收到延迟消息,不处理,工单类型:{} 工单状态:{} 工单uuid:{}",rnrOrderDTO.getOrderType(),rnrOrderDTO.getOrderStatus(),rnrOrderDTO.getUuid());
				return;
			}

			//还是待审核状态

			//工单设置成未通过
			orderService.updateOrderStatus(Collections.singletonList(rnrOrderDTO.getUuid()), RnrOrderStatusEnum.CANCEL.getCode());
			//卡设置成失败状态
			cardInfoService.updateCardStatusByOrderId(rnrOrderDTO.getUuid(), NoticeStatusEnum.NONEED.getCode(), RnrStatus.RNR_FAIL.getCode());

			//原车主解绑 、 换件 、 一车多卡 挂在原先的rnr_id 下面 不需要处理超时的rnr_info  企业解绑是新的rnr_info 需要处理超时的情况
			if (RnrOrderType.ENTERPRISEUNBIND.getCode().equals(rnrOrderDTO.getOrderType())) {
				//rnr_info 设置成为失败
				rnrInfoService.updateRnrStatus(rnrOrderDTO.getRnrId(),RnrStatus.RNR_FAIL);
			}
		} else if(RnrOrderType.NEW_VEHICLE.getCode().equals(rnrOrderDTO.getOrderType())
				|| RnrOrderType.SEC_VEHICLE.getCode().equals(rnrOrderDTO.getOrderType())
				|| RnrOrderType.COMPANY_NEW_VEHICLE.getCode().equals(rnrOrderDTO.getOrderType())) {
			//新车自然人实名 二手车实名 企业新车实名 提交资料后 order_status 是0(初始化状态) 如果此时收到延迟消息时 还是此状态 作废工单和卡和实名信息
			if (!RnrOrderStatusEnum.COMMIT.getCode().equals(rnrOrderDTO.getOrderStatus())) {
				log.info("接收到延迟消息,不处理,工单类型:{} 工单状态:{} 工单uuid:{}",rnrOrderDTO.getOrderType(),rnrOrderDTO.getOrderStatus(),rnrOrderDTO.getUuid());
				return;
			}


			//还是初始化状态 需要作废这笔实名信息

			//工单设置成未通过
			orderService.updateOrderStatus(Collections.singletonList(rnrOrderDTO.getUuid()), RnrOrderStatusEnum.CANCEL.getCode());
			//卡设置成失败状态
			cardInfoService.updateCardStatusByOrderId(rnrOrderDTO.getUuid(), NoticeStatusEnum.NONEED.getCode(), RnrStatus.RNR_FAIL.getCode());
			//rnr_info 设置成为失败
			rnrInfoService.updateRnrStatus(rnrOrderDTO.getRnrId(),RnrStatus.RNR_FAIL);
		}
    }
}
