package com.cusc.nirvana.user.rnr.notice.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cusc.nirvana.user.rnr.mg.constants.CommonDeleteEnum;
import com.cusc.nirvana.user.rnr.notice.converter.RnrNoticeContentLogConverter;
import com.cusc.nirvana.user.rnr.notice.dao.RnrNoticeContentLogDao;
import com.cusc.nirvana.user.rnr.notice.dao.entity.RnrNoticeContentLogPO;
import com.cusc.nirvana.user.rnr.notice.dto.RnrNoticeContentLogDTO;
import com.cusc.nirvana.user.rnr.notice.service.IRnrNoticeContentLogService;
import com.cusc.nirvana.user.util.CuscStringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * 实名通知内容日志(RnrNoticeContentLog)表服务实现类
 *
 * @author yuy336
 * @since 2022-03-31 15:05:28
 */
@Service
public class RnrNoticeContentLogServiceImpl extends ServiceImpl<RnrNoticeContentLogDao, RnrNoticeContentLogPO> implements IRnrNoticeContentLogService {

    /**
     * 通过UUID查询单条数据
     *
     * @param bean
     * @return 实例对象
     */
    @Override
    public RnrNoticeContentLogDTO getByUuid(RnrNoticeContentLogDTO bean) {
        RnrNoticeContentLogPO record = this.getPoByUuid(bean.getUuid());;
        return RnrNoticeContentLogConverter.INSTANCE.poToDto(record);
    }
    
     /**
     * 通过查询条件查询集合数据
     *
     * @param bean
     * @return 集合对象
     */
    @Override
    public List<RnrNoticeContentLogDTO> queryByList(RnrNoticeContentLogDTO bean) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        queryWrapper.orderByDesc("create_time");
        List<RnrNoticeContentLogPO> record = this.list(queryWrapper);
        return RnrNoticeContentLogConverter.INSTANCE.poListToDtoList(record);
    }

    /**
     * 新增数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public RnrNoticeContentLogDTO insert(RnrNoticeContentLogDTO bean) {
       RnrNoticeContentLogPO rnrNoticeContentLogPO = RnrNoticeContentLogConverter.INSTANCE.dtoToPo(bean);
	   rnrNoticeContentLogPO.setUuid(CuscStringUtils.generateUuid());
        this.save(rnrNoticeContentLogPO);
		bean.setUuid(rnrNoticeContentLogPO.getUuid());
        return bean;
    }

    /**
     * 修改数据
     *
     * @param bean 实例对象
     * @return 实例对象
     */
    @Override
    @Transactional
    public RnrNoticeContentLogDTO update(RnrNoticeContentLogDTO bean) {
        RnrNoticeContentLogPO rnrNoticeContentLogPO = this.getPoByUuid(bean.getUuid());
		 if(rnrNoticeContentLogPO == null){
            return null;
        }
		RnrNoticeContentLogPO tmpBean = RnrNoticeContentLogConverter.INSTANCE.dtoToPo(bean);
		tmpBean.setId(rnrNoticeContentLogPO.getId());
        this.updateById(tmpBean);
        return bean;
    }

    /**
     * 通过主键删除数据
     * @param bean 实例对象
     * @return 是否成功
     */
    @Override
    @Transactional
    public boolean deleteById(RnrNoticeContentLogDTO bean) {
        RnrNoticeContentLogPO rnrNoticeContentLogPO = this.getPoByUuid(bean.getUuid());
		 if (rnrNoticeContentLogPO == null) {
            return false;
        }
        RnrNoticeContentLogPO tmpBean = new RnrNoticeContentLogPO();
        tmpBean.setId(rnrNoticeContentLogPO.getId());
        return this.updateById(tmpBean);
    }
    
    /**
     * 通过UUID查询单条数据
     *
     * @param uuid
     * @return 实例对象
     */
    private RnrNoticeContentLogPO getPoByUuid(String uuid) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("uuid", uuid);
        queryWrapper.eq("is_delete", CommonDeleteEnum.NORMAL.getCode());
        return this.getOne(queryWrapper);
    }
}
