package com.cusc.nirvana.user.rnr.workorder.constants;

import com.cusc.nirvana.user.rnr.mg.constants.RnrOrderType;
import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Arrays;

/**
 * @author stayAnd
 * @date 2022/3/30
 */
@AllArgsConstructor
public enum WorkOrderTypeEnum {
    /**
     * 人工实名认证工单
     */
    REAL_NAME_CERTIFICATION_ORDER(RnrOrderType.NEW_VEHICLE, "real_name_natural_person_new_car", "人工实名认证工单", "自然人实名. %s,手机号:%s,VIN:%s,ICCID:%s", "rnrWorkOrderCallBackHandler"),

    /**
     * 二手车实名认证工单
     */
    SECOND_HAND_VEHICLE_CERTIFICATION(RnrOrderType.SEC_VEHICLE, "real_name_natural_person_used_car", "二手车实名认证工单", "二手车实名. %s,手机号:%s,VIN:%s,ICCID:%s", "rnrWorkOrderCallBackHandler"),

    /**
     * 企业新车实名认证
     */
    COMPANY_NEW_VEHICLE_CERTIFICATION(RnrOrderType.COMPANY_NEW_VEHICLE, "real_name_enterprise_new_car", "企业新车实名认证工单", "企业实名. %s,手机号:%s,VIN:%s,ICCID:%s", "rnrWorkOrderCallBackHandler"),

    /**
     * 车企新车实名认证
     */
    CARMAKER_NEW_VEHICLE_CERTIFICATION(RnrOrderType.CARMAKER_NEW_VEHICLE, "real_name_carenterprise_new_car", "车企新车实名认证工单", "车企实名. %s,手机号:%s,VIN:%s,ICCID:%s", "manufacturerRnrCallBackHandler"),

    /**
     * 二手车主解绑
     */
    SECOND_VEHICLE_UNBIND_ORDER(RnrOrderType.SEC_UNBIND, "real_name_unbound_used_car", "二手车主解绑工单", "二手车解绑. %s,手机号:%s,VIN:%s,ICCID:%s", "unbindWorkOrderCallBackHandler"),

    /**
     * 企业责任人变更
     */
    COMPANY_CORPORATION_UNBIND_ORDER(RnrOrderType.COMPANY_CORPORATION_CHANGE, "real_name_enterpriselegalperson", "企业责任人变更工单", "企业责任人变更. %s,手机号:%s", "enterpriseChangeCallBackHandler"),
    ;

    @Getter
    private RnrOrderType rnrOrderType;

    @Getter
    private String key;

    @Getter
    private String name;

    @Getter
    private String workOrderNamePattern;

    @Getter
    private String workOrderCallBackServiceName;

    public static WorkOrderTypeEnum getWorkOrderTypeByKey(String key) {
        return Arrays.stream(WorkOrderTypeEnum.values()).filter(workOrderTypeEnum -> workOrderTypeEnum.getKey().equals(key))
                .findFirst().orElse(null);
    }

    public String getWorkOrderName(Object... args) {
        return String.format(workOrderNamePattern, args);
    }

    public static WorkOrderTypeEnum getWorkOrderTypeEnumByRnrOrderType(RnrOrderType rnrOrderType){
    	return Arrays.stream(WorkOrderTypeEnum.values()).filter(workOrderTypeEnum -> workOrderTypeEnum.getRnrOrderType().equals(rnrOrderType)).findFirst().orElse(null);
	}
}
