package com.cusc.nirvana.user.rnr.workorder.controller;

import com.cusc.nirvana.common.result.BaseEnum;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.rnr.workorder.constants.WorkOrderTypeEnum;
import com.cusc.nirvana.user.rnr.workorder.context.WorkOrderContext;
import com.cusc.nirvana.user.rnr.workorder.dto.WorkOrderClaimRequestDTO;
import com.cusc.nirvana.user.rnr.workorder.dto.WorkOrderInfoDTO;
import com.cusc.nirvana.user.rnr.workorder.dto.WorkOrderQueryRequestDTO;
import com.cusc.nirvana.user.rnr.workorder.dto.WorkOrderReviewDTO;
import com.cusc.nirvana.user.rnr.workorder.dto.WorkOrderStarRequestDTO;
import com.cusc.nirvana.user.rnr.workorder.handler.WorkOrderHandler;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author stayAnd
 * @date 2022/3/30
 */
@RestController
@RequestMapping("/rnr/worktest")
@Slf4j
public class WorkTestController {

	@Resource
	private WorkOrderContext workOrderContext;

	@GetMapping("/startWork")
	public Response<String> startWork(@RequestParam("id") String id){
		WorkOrderHandler handler = workOrderContext.getHandler();
		WorkOrderStarRequestDTO dto = new WorkOrderStarRequestDTO();
		dto.setTenantUuid("test1");
		dto.setApplicationUuid("b05ccb27c2d54113bf32a7203ef4b7a7");
		dto.setBusinessObjectId("test"+id);
		dto.setName("test"+id);
		dto.setStartUserId("test");
		dto.setWorkOrderKey(WorkOrderTypeEnum.REAL_NAME_CERTIFICATION_ORDER.getKey());
		String workOrderNo = handler.startOrder(dto);
		return Response.createSuccess(BaseEnum.SUCCESS.getMsg(),workOrderNo);
	}


	@GetMapping("/queryUnClaimedOrders")
	public Response<List<WorkOrderInfoDTO>> queryUnClaimedOrders(){
		WorkOrderHandler handler = workOrderContext.getHandler();
		WorkOrderQueryRequestDTO dto = new WorkOrderQueryRequestDTO();
		dto.setApplicationUuid("b05ccb27c2d54113bf32a7203ef4b7a7");
		dto.setTenantUuid("test1");
		dto.setWorkOrderKey(WorkOrderTypeEnum.REAL_NAME_CERTIFICATION_ORDER.getKey());
		dto.setCurrPage(1);
		dto.setPageSize(30);
		List<WorkOrderInfoDTO> list = handler.queryUnClaimedOrders(dto);
		return Response.createSuccess(list);
	}

	@GetMapping("/claimOrder")
	public Response<Boolean> claimOrder(@RequestParam("taskNo")String taskNo,
										@RequestParam("claimUserId") String claimUserId){
		WorkOrderHandler handler = workOrderContext.getHandler();
		WorkOrderClaimRequestDTO dto = new WorkOrderClaimRequestDTO();
		dto.setApplicationUuid("b05ccb27c2d54113bf32a7203ef4b7a7");
		dto.setTenantUuid("test1");
		dto.setWorkOrderKey(WorkOrderTypeEnum.REAL_NAME_CERTIFICATION_ORDER.getKey());
		dto.setTaskNo(taskNo);
		dto.setClaimUserId(claimUserId);
		return Response.createSuccess(handler.claimOrder(dto));
	}


	@GetMapping("/queryClaimedOrders")
	public Response<List<WorkOrderInfoDTO>> queryClaimedOrders(@RequestParam("claimUserId") String claimUserId){
		WorkOrderHandler handler = workOrderContext.getHandler();
		WorkOrderQueryRequestDTO dto = new WorkOrderQueryRequestDTO();
		dto.setApplicationUuid("b05ccb27c2d54113bf32a7203ef4b7a7");
		dto.setTenantUuid("test1");
		dto.setWorkOrderKey(WorkOrderTypeEnum.REAL_NAME_CERTIFICATION_ORDER.getKey());
		dto.setCurrPage(1);
		dto.setPageSize(30);
		dto.setClaimUserId(claimUserId);
		List<WorkOrderInfoDTO> list = handler.queryClaimedOrders(dto);
		return Response.createSuccess(list);
	}

	@GetMapping("/reviewWorkOrder")
	public Response reviewWorkOrder(@RequestParam("reviewUserId") String reviewUserId,
									@RequestParam("taskNo") String taskNo,
									@RequestParam("auditResult") Integer auditResult,
									@RequestParam("auditNote") String auditNote){
		WorkOrderHandler handler = workOrderContext.getHandler();
		WorkOrderReviewDTO dto = new WorkOrderReviewDTO();
		dto.setApplicationUuid("b05ccb27c2d54113bf32a7203ef4b7a7");
		dto.setTenantUuid("test1");
		dto.setReviewUserId(reviewUserId);
		dto.setTaskNo(taskNo);
		dto.setAuditResult(auditResult);
		dto.setAuditNote(auditNote);
		Boolean success = handler.reviewWorkOrder(dto);
		return Response.createSuccess(success);
	}

}
