package com.cusc.nirvana.user.rnr.workorder.handler.impl;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.cusc.nirvana.user.rnr.mg.constants.RnrOrderStatusEnum;
import com.cusc.nirvana.user.rnr.mg.constants.RnrStatus;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgRnrCardInfoPO;
import com.cusc.nirvana.user.rnr.mg.dto.*;
import com.cusc.nirvana.user.rnr.mg.service.*;
import com.cusc.nirvana.user.rnr.workorder.dto.WorkOrderReviewCallBackRequestDTO;
import com.cusc.nirvana.user.rnr.workorder.handler.WorkOrderCallBackHandler;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author stayAnd
 * @date 2022/4/26
 */
@Component
@Slf4j
public class EnterpriseChangeCallBackHandler implements WorkOrderCallBackHandler {

	@Resource
	private IRnrOrderService orderService;

	@Resource
	private IMgRnrInfoService mgRnrInfoService;

	@Resource
	private IMgRnrCardInfoService cardInfoService;

	@Resource
	private IRnrResultProcessService processService;

	@Resource
	private IMgVehicleCompanyService vehicleCompanyService;

	@Resource
	private IMgRnrCompanyInfoService companyInfoService;


	@Override
	public void claimAssignWorkOrder(String workNo) {

	}

	@Override
	public void reviewCallBack(WorkOrderReviewCallBackRequestDTO dto) {

		boolean auditResult = StringUtils.equalsIgnoreCase(dto.getAuditResult(), "1");

		String orderId = dto.getBusinessObjectId();
		//查询orderDto
		RnrOrderDTO orderQuery = new RnrOrderDTO();
		orderQuery.setUuid(orderId);
		RnrOrderDTO orderDTO = orderService.getByUuid(orderQuery);
		if (null == orderDTO) {
			log.error("EnterpriseChangeCallBackHandler reviewCallBack orderDTO is null,dto = {} ", JSONObject.toJSONString(dto));
			return;
		}

		//查询rnr_info
		MgRnrInfoDTO infoQuery = new MgRnrInfoDTO();
		infoQuery.setUuid(orderDTO.getRnrId());
		MgRnrInfoDTO rnrInfo = mgRnrInfoService.getByUuid(infoQuery);
		if (null == rnrInfo) {
			log.error("EnterpriseChangeCallBackHandler reviewCallBack rnrInfo is null,dto = {} ", JSONObject.toJSONString(dto));
			return;
		}

		//查询卡信息
		MgRnrCardInfoDTO cardQuery = new MgRnrCardInfoDTO();
		cardQuery.setRnrId(rnrInfo.getUuid());
		List<MgRnrCardInfoDTO> cardInfoDTOList = cardInfoService.queryByList(cardQuery);
		if (CollectionUtils.isEmpty(cardInfoDTOList)) {
			log.error("EnterpriseChangeCallBackHandler reviewCallBack cardInfoDTOList is empty,dto = {} ", JSONObject.toJSONString(dto));
			return;
		}

		processService.processRnrResult(orderId, rnrInfo.getUuid(), auditResult ? RnrOrderStatusEnum.PASS : RnrOrderStatusEnum.NOT_PASS,dto.getAuditNote());

		if (auditResult) {
			//解绑老的卡信息
			unBindOldCard(cardInfoDTOList);


			//修改mg_vehicle_company的first_rnr_id
			log.info("企业责任人变更 修改firstRnrId 开始,orderId = {}",orderId);
			MgRnrCompanyInfoDTO companyQuery = new MgRnrCompanyInfoDTO();
			companyQuery.setRnrId(rnrInfo.getUuid());
			MgRnrCompanyInfoDTO companyInfoDTO = companyInfoService.getByRnrid(companyQuery);

			if (null == companyInfoDTO) {
				log.info("企业责任人变更 修改firstRnrId 未查询到 MgRnrCompanyInfoDTO,orderId = {}",orderId);
				return;
			}

			MgVehicleCompanyDTO vehicleQuery = new MgVehicleCompanyDTO();
			vehicleQuery.setTenantNo(orderDTO.getTenantNo());
			vehicleQuery.setCompanyName(companyInfoDTO.getCompanyName());
			MgVehicleCompanyDTO vehicleCompany = vehicleCompanyService.getVehicleCompany(vehicleQuery);

			if (null == vehicleCompany) {
				log.info("企业责任人变更 修改firstRnrId 未查询到 MgVehicleCompanyDTO,orderId = {}",orderId);
				return;
			}

			MgVehicleCompanyDTO vehicleUpdateDto = new MgVehicleCompanyDTO();
			vehicleUpdateDto.setUuid(vehicleCompany.getUuid());
			vehicleUpdateDto.setFirstRnrId(rnrInfo.getUuid());
			vehicleCompanyService.update(vehicleUpdateDto);

			log.info("企业责任人变更 修改firstRnrId 成功,orderId = {}",orderId);
		}
	}

	private void unBindOldCard(List<MgRnrCardInfoDTO> cardInfoDTOList) {
		cardInfoDTOList.parallelStream().forEach(card -> {

			if (StringUtils.isNotBlank(card.getOldCardId())) {
				MgRnrCardInfoPO updateCardPo = new MgRnrCardInfoPO();
				updateCardPo.setRnrStatus(RnrStatus.UNBOUND.getCode());

				LambdaQueryWrapper<MgRnrCardInfoPO> cardQuery = new LambdaQueryWrapper<>();
				cardQuery.eq(MgRnrCardInfoPO::getUuid, card.getOldCardId());
				cardInfoService.update(updateCardPo, cardQuery);
			}
		});

	}

}
