package com.cusc.nirvana.user.rnr.workorder.handler.impl;

import com.alibaba.fastjson.JSONObject;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.exception.CuscUserException;
import com.cusc.nirvana.user.rnr.common.constants.ResponseCode;
import com.cusc.nirvana.user.rnr.mg.constants.NoticeStatusEnum;
import com.cusc.nirvana.user.rnr.mg.constants.RnrOrderStatusEnum;
import com.cusc.nirvana.user.rnr.mg.constants.RnrOrderType;
import com.cusc.nirvana.user.rnr.mg.constants.RnrStatus;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrCardInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.MgRnrInfoDTO;
import com.cusc.nirvana.user.rnr.mg.dto.RnrOrderDTO;
import com.cusc.nirvana.user.rnr.mg.dto.RnrUnbindDTO;
import com.cusc.nirvana.user.rnr.mg.service.*;
import com.cusc.nirvana.user.rnr.workorder.dto.WorkOrderReviewCallBackRequestDTO;
import com.cusc.nirvana.user.rnr.workorder.handler.WorkOrderCallBackHandler;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 实名成功工单回调
 *
 * @author yubo
 * @since 2022-04-19 20:25
 */
@Service("rnrWorkOrderCallBackHandler")
@Slf4j
public class RnrWorkOrderCallBackHandler implements WorkOrderCallBackHandler {

    @Autowired
    IRnrOrderService orderService;

    @Autowired
    IMgRnrCardInfoService cardInfoService;

    @Autowired
    @Lazy
    IMgRnrCardNoticeService cardNoticeService;

    @Autowired
    IMgRnrInfoService mgRnrInfoService;

    @Autowired
    IRnrUnboundService iRnrUnboundService;

    @Resource
	private IRnrResultProcessService processService;

    @Resource
    private IOrgSimRelService iOrgSimRelService;

    @Override
    public void claimAssignWorkOrder(String workNo) {
        //todo
    }

    @Override
    public void reviewCallBack(WorkOrderReviewCallBackRequestDTO dto) {
        String orderId = dto.getBusinessObjectId();
        RnrOrderStatusEnum statusEnum =
                StringUtils.equalsIgnoreCase(dto.getAuditResult(), "1") ? RnrOrderStatusEnum.PASS : RnrOrderStatusEnum.NOT_PASS;

        //获取rnrId
        RnrOrderDTO rnrOrderDTO = new RnrOrderDTO();
        rnrOrderDTO.setUuid(orderId);
        RnrOrderDTO orderDTO = orderService.getByUuid(rnrOrderDTO);

        if (null == orderDTO) {
            log.error("RnrWorkOrderCallBackHandler reviewCallBack orderDTO is null,dto = {} ", JSONObject.toJSONString(dto));
            return;
        }

        String rnrId = orderDTO.getRnrId();


        if (statusEnum == RnrOrderStatusEnum.PASS) {
            if (RnrOrderType.SEC_VEHICLE.getCode().equals(orderDTO.getOrderType())) {
                unboundCards(orderId, rnrId);
            }
            //更新orderId查询carInfo
            MgRnrCardInfoDTO mgRnrCardInfoDTO = new MgRnrCardInfoDTO();
            mgRnrCardInfoDTO.setOrderId(orderId);
            List<MgRnrCardInfoDTO> mgRnrCardInfoDTOList = cardInfoService.queryByList(mgRnrCardInfoDTO);
            iOrgSimRelService.updateVin(mgRnrCardInfoDTOList);
        }

		processService.processRnrResult(orderId,rnrId,statusEnum,dto.getAuditNote());
    }




    /**
     * 解绑卡
     */
    @Transactional
    public void unboundCards(String orderId, String rnrId) {
        //查询所有的待审核的card
        MgRnrCardInfoDTO query = new MgRnrCardInfoDTO();
        query.setOrderId(orderId);
        query.setRnrId(rnrId);
        List<MgRnrCardInfoDTO> mgRnrCardInfoDTOS = cardInfoService.queryByList(query);

        //查询所有已经实名的卡
        List<String> iccids = mgRnrCardInfoDTOS.stream().map(card -> card.getIccid()).collect(Collectors.toList());
        query = new MgRnrCardInfoDTO();
        query.setIccidList(iccids);
        query.setRnrStatus(RnrStatus.RNR.getCode());
        mgRnrCardInfoDTOS = cardInfoService.queryByList(query);

        if (!CollectionUtils.isEmpty(mgRnrCardInfoDTOS)) {
            RnrUnbindDTO unbindDTO;
            Response response;
            for (MgRnrCardInfoDTO cardDto : mgRnrCardInfoDTOS) {
                //获取实名主体信息
                MgRnrInfoDTO mgRnrInfoDTO = new MgRnrInfoDTO();
                mgRnrInfoDTO.setUuid(cardDto.getRnrId());
                MgRnrInfoDTO rnrInfoDTO = mgRnrInfoService.getByUuid(mgRnrInfoDTO);
                if (rnrInfoDTO == null) {
                    throw new CuscUserException("", "实名业务【" + cardDto.getRnrId() + "】不存在");
                }

                unbindDTO = new RnrUnbindDTO();
                unbindDTO.setIccid(cardDto.getIccid());
                unbindDTO.setVin(cardDto.getIotId());
                unbindDTO.setCertNumber(rnrInfoDTO.getCertNumber());
                unbindDTO.setFullName(rnrInfoDTO.getFullName());
                unbindDTO.setCertType(rnrInfoDTO.getCertType());
                unbindDTO.setPhone(rnrInfoDTO.getPhone());
                unbindDTO.setReason(3);
                unbindDTO.setManualUnbind(false);
                response = iRnrUnboundService.rnrUnbound(unbindDTO);
                if (null == response || (!response.getSuccess() && response.getCode() != ResponseCode.ICCID_RNR_INFO_NOT_MATCHED.getCode())) {
                    throw new CuscUserException("", "解绑卡[" + cardDto.getIccid() + "]失败");
                }
            }

        }
    }
}
