package com.cusc.nirvana.user.rnr.workorder.job;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.cache.CacheFactory;
import com.cusc.nirvana.common.loader.CollectionUtils;
import com.cusc.nirvana.common.result.Response;
import com.cusc.nirvana.user.eiam.client.UserClient;
import com.cusc.nirvana.user.eiam.dto.UserDTO;
import com.cusc.nirvana.user.rnr.common.constants.RedisConstant;
import com.cusc.nirvana.user.rnr.mg.dao.entity.MgOrderApproverPO;
import com.cusc.nirvana.user.rnr.mg.service.IMgOrderApproverService;
import com.cusc.nirvana.user.rnr.workorder.constants.WorkOrderTypeEnum;
import com.cusc.nirvana.user.rnr.workorder.context.WorkOrderContext;
import com.cusc.nirvana.user.rnr.workorder.dto.WorkOrderAssignDTO;
import com.cusc.nirvana.user.rnr.workorder.dto.WorkOrderInfoDTO;
import com.cusc.nirvana.user.rnr.workorder.dto.WorkOrderQueryRequestDTO;
import com.cusc.nirvana.user.rnr.workorder.handler.WorkOrderHandler;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Comparator;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author stayAnd
 * @date 2022/3/31
 * 工单定时任务
 */
@Component
@Slf4j
public class WorkOrderJob {

	@Resource
	private WorkOrderContext workOrderContext;

	@Resource
	private IMgOrderApproverService mgOrderApproverService;

	@Resource
	private CacheFactory cacheFactory;

	@Resource
	private UserClient userClient;

	/**
	 * 工单指派
	 */
	public void assignWorkOrderJob() {
		try {
			Boolean lock = cacheFactory.getLockService().lock(RedisConstant.RNR_WORK_ORDER_CONFIG, "assginWorkOrderJob", 60 * 10);
			if (!lock) {
				log.error("WorkOrderJob assignWorkOrderJob has lock");
				return;
			}
			WorkOrderHandler handler = workOrderContext.getHandler();
			int pageNumber = 1;
			int pageSize = 50;
			int returnSize;
			String applicationUuid = "b05ccb27c2d54113bf32a7203ef4b7a7";
			do {
				//获取未认领的工单列表
				WorkOrderQueryRequestDTO dto = new WorkOrderQueryRequestDTO();
				dto.setApplicationUuid(applicationUuid);
				dto.setWorkOrderKey(WorkOrderTypeEnum.REAL_NAME_CERTIFICATION_ORDER.getKey());
				dto.setCurrPage(pageNumber);
				dto.setPageSize(pageSize);
				List<WorkOrderInfoDTO> workOrderList = handler.queryUnClaimedOrders(dto);
				returnSize = workOrderList.size();

				//工单分派
				doAssignWorkOrder(workOrderList,handler);

				pageNumber++;

			} while (returnSize == pageSize);
		} catch (Exception e) {
			log.error("WorkOrderJob assignWorkOrderJob has error", e);
		} finally {
			try {
				cacheFactory.getLockService().unLock(RedisConstant.RNR_WORK_ORDER_CONFIG);
			} catch (Exception e) {
				log.error("WorkOrderJob assignWorkOrderJob unLock has error", e);
			}
		}


	}

	private void doAssignWorkOrder(List<WorkOrderInfoDTO> workOrderList,WorkOrderHandler workOrderHandler) {
		if (CollectionUtils.isEmpty(workOrderList)) {
			return;
		}

		//按照租户分组
		Map<String, List<WorkOrderInfoDTO>> groupByTenantUuidMap = workOrderList.stream().collect(Collectors.groupingBy(WorkOrderInfoDTO::getTenantUuid));

		groupByTenantUuidMap.forEach((tenantUuid, list) -> {
			//查询该租户下面的所有审批员工并过滤掉停止接单的员工
			LambdaQueryWrapper<MgOrderApproverPO> query = new LambdaQueryWrapper<>();
			query.eq(MgOrderApproverPO::getTenantNo, tenantUuid).eq(MgOrderApproverPO::getStopAcceptOrder, 0);
			List<MgOrderApproverPO> userApprovalList = mgOrderApproverService.list(query);
			if (CollectionUtils.isEmpty(userApprovalList)) {
				return;
			}

			//过滤掉不在线的 并按照id升序
			List<MgOrderApproverPO> onLineUserList = userApprovalList.stream().filter(mgUserApprovalPo -> {
				UserDTO userDto = new UserDTO();
				userDto.setUuid(mgUserApprovalPo.getUserId());
				userDto.setApplicationId("4");
				userDto.setTenantNo(mgUserApprovalPo.getTenantNo());
				Response<Boolean> userOnline = userClient.getUserOnline(userDto);
				return null != userOnline && userOnline.getData();
			}).sorted(Comparator.comparing(MgOrderApproverPO::getId)).collect(Collectors.toList());
			log.info("WorkOrderJob doAssignWorkOrder,tenantUuid = {},onLineList = {}", tenantUuid, JSONObject.toJSONString(onLineUserList));
			if (CollectionUtils.isEmpty(onLineUserList)) {
				return;
			}

			Long lastAssignUserId = getLastAssignUserId(tenantUuid);

			//onLineUserList中获取比lastAssignUserId大 但是差值最小的审批人员
			MgOrderApproverPO startApprovalUser = onLineUserList.stream().filter(mgUserApproval -> mgUserApproval.getId().compareTo(lastAssignUserId) > 0)
					.min(Comparator.comparing(MgOrderApproverPO::getId)).orElse(null);
			Integer startIndex;
			if (null == startApprovalUser) {
				startIndex = 0;
			} else {
				startIndex = onLineUserList.indexOf(startApprovalUser);
			}

			//本次最后一个审批人
			Long lastApprovalUserId = 0L;
			for (int i = 0; i < list.size(); i++) {
				WorkOrderInfoDTO workOrderInfoDTO = list.get(i);
				if (startIndex > onLineUserList.size() - 1) {
					startIndex = 0;
				}
				//指派人
				MgOrderApproverPO mgOrderApproverPo = onLineUserList.get(startIndex);

				//指派工单
				WorkOrderAssignDTO assignRequest = new WorkOrderAssignDTO();
				assignRequest.setApplicationUuid(workOrderInfoDTO.getApplicationUuid());
				assignRequest.setTenantUuid(workOrderInfoDTO.getTenantUuid());
				assignRequest.setTaskNo(workOrderInfoDTO.getTaskNo());
				assignRequest.setWorkOrderNo(workOrderInfoDTO.getWorkOrderNo());
				assignRequest.setWorkOrderKey(workOrderInfoDTO.getWorkOrderKey());
				assignRequest.setAssignUserId(mgOrderApproverPo.getUserId());
				workOrderHandler.assignWorkOrder(assignRequest);

				if (i == list.size() - 1) {
					lastApprovalUserId = mgOrderApproverPo.getId();
				}
				startIndex++;
			}
			//记录本次审批最后一个人id
			saveLastAssignUserId(tenantUuid, lastApprovalUserId);
		});

	}


	private Long getLastAssignUserId(String tenantUuid) {
		Long lastAssignUserId;
		try {
			lastAssignUserId = cacheFactory.getStringService().getValue(RedisConstant.RNR_WORK_ORDER_ASSIGN_CONFIG + tenantUuid, Long.class);
		} catch (Exception e) {
			log.error("WorkOrderJob getLastAssignUserId has error,tenantUuid = {}", tenantUuid, e);
			lastAssignUserId = 0L;
		}
		return lastAssignUserId;
	}

	private void saveLastAssignUserId(String tenantUuid, Long lastApprovalUserId) {
		try {
			cacheFactory.getStringService().setValue(RedisConstant.RNR_WORK_ORDER_ASSIGN_CONFIG + tenantUuid, lastApprovalUserId);
		} catch (Exception e) {
			log.error("WorkOrderJob saveLastAssignUserId has error,tenantUuid = {},lastApprovalUserId = {}", tenantUuid, lastApprovalUserId, e);
		}
	}


}
